<?php

/**
 * Better Social Counter Shortcode
 */
class Better_Social_Banner_Shortcode extends BF_Shortcode{

    function __construct(  $id , $options  ){

        $id = 'better-social-banner';

        $this->widget_id = 'better-social-banner';

        $this->name = __( 'Better Social Banner', 'better-studio' );

        $this->description = __( 'BetterSocial Banner Add-on', 'better-studio' );

        $this->icon = BETTER_SOCIAL_COUNTER_DIR_URL . 'img/vc-social-counter.png';

        $options = array_merge( array(
            'defaults'      => array(
                'title'     => '',
                'show_title'=> 0,
                'site'      => 'facebook',
            ),
            'have_widget'   => true,
            'have_vc_add_on'=> true,
        ), $options );

        parent::__construct( $id , $options );

    }


    /**
     * Filter custom css codes for shortcode widget!
     *
     * @param $fields
     * @return array
     */
    function register_custom_css( $fields ){
        return $fields;
    }


    /**
     * Handle displaying of shortcode
     *
     * @param array $atts
     * @param string $content
     * @return string
     */
    function display( array $atts  , $content = '' ){

        ob_start();

        // If title is set and this is not in sidebar!
        if( $atts['title'] && ! Better_Framework::widget_manager()->get_current_sidebar() && $atts['show_title']){
            $atts['element-type'] = $this->id;
            $result = apply_filters( 'better-framework/shortcodes/title', $atts );

            if( is_string( $result ) )
                echo $result;
        }


        ?>
        <div class="better-studio-shortcode better-social-banner bsc-clearfix">

            <?php
            $data = Better_Social_Counter_Data_Manager::get_full_data( $atts['site'] );

            // If data is valid
            if( $data ){

                ?>
                <a href="<?php echo $data['link']; ?>" class="banner-item item-<?php echo $atts['site']; ?>">
                    <i class="item-icon bsfi-<?php echo $atts['site']; ?>" aria-label="<?php echo $atts['site']; ?>"></i>
                    <span class="item-count"><?php echo $data['count']; ?></span>
                    <span class="item-title"><?php echo $data['title']; ?></span>
                    <span class="item-button"><?php echo $data['button']; ?></span>
                </a>
                <?php

            }

            ?>

        </div>
        <?php
        return ob_get_clean();
    }


    /**
     * Registers Visual Composer Add-on
     */
    function register_vc_add_on(){

        vc_map( array(
            "name"          =>  $this->name,
            "base"          =>  $this->id,
            "icon"          =>  $this->icon,
            "description"   =>  $this->description,
            "weight"        =>  1,
            "php_class_name"=>  'WPBakeryShortCode_better_social_banner',

            "wrapper_height"=>  'full',

            "category"      =>  __( 'Content', 'better-studio' ),

            "params"        => array(

                array(
                    "type"          =>  'textfield',
                    "admin_label"   =>  true,
                    "heading"       =>  __( 'Title', 'better-studio' ),
                    "param_name"    =>  'title',
                    "value"         =>  $this->defaults['title'],
                ),

                array(
                    "type"          =>  'bf_switchery',
                    "heading"       =>  __( 'Show Title?', 'better-studio'),
                    "param_name"    =>  'show_title',
                    "value"         =>  $this->defaults['show_title'],
                ),

                array(
                    'heading'       =>  __( 'Site', 'better-studio'),
                    'type'          =>  'bf_select',
                    "admin_label"   =>  true,
                    "param_name"    =>  'site',
                    "value"         =>  $this->defaults['site'],
                    'options'       =>  Better_Social_Counter_Data_Manager::self()->get_select_options_for_banner( true ),

                )
            )

        ) );

    }
}

class WPBakeryShortCode_better_social_banner extends BF_VC_Shortcode_Extender { }