<?php
/**
 * comments.php
 *---------------------------
 * The template for displaying comments.
 *
 * Content of each comment will be output with the type of comment.
 * You can view and/or edit the comment file in "views/general/comments"
 *
 */

/* If a post password is required, return. */
if( post_password_required() )
	return;

// Comment Form Location
$form_location = better_get_option( 'post_comments_form_position' );

// Comment Form Arguments
$form_args = array(
	'title_reply'           =>  '<h4 class="section-heading" ><span class="h-text">' . Better_Translation()->_get( 'comments_leave_reply' ) . '</span></h4>',
	'title_reply_to'        =>  '<h4 class="section-heading" ><span class="h-text">' . Better_Translation()->_get( 'comments_reply_to' ) . '</span></h4>',
	'comment_notes_before'  =>  wpautop( Better_Translation()->_get( 'comment_notes_before' ) ),
	'comment_notes_after'   =>  wpautop( Better_Translation()->_get( 'comment_notes_after' ) ),

	'logged_in_as'          =>  '<p class="logged-in-as">' . sprintf(
			Better_Translation()->_get( 'comments_logged_as' ) . ' <a href="%1$s">%2$s</a>. <a href="%3$s" title="' . Better_Translation()->_get_esc_attr( 'comments_logout_this' ) . '"> ' . Better_Translation()->_get( 'comments_logout' ) . '</a>' ,
			admin_url( 'profile.php' ),
			$user_identity,
			wp_logout_url( get_permalink() )
		) . '</p>',

	'comment_field'         =>  '<p><textarea name="comment" id="comment" cols="45" rows="10" aria-required="true" placeholder="'. Better_Translation()->_get_esc_attr( 'comments_your_comment' ) .'"></textarea></p>',
	'id_submit'             =>  'comment-submit',
	'label_submit'          =>  Better_Translation()->_get_esc_attr( 'comments_post_comment' ),
	'cancel_reply_link'     =>  Better_Translation()->_get_esc_attr( 'comments_cancel_reply' ),
	'fields'                =>  array(
		'author'        =>  '<p><input name="author" id="author" type="text" value="" size="45" aria-required="true" placeholder="'. Better_Translation()->_get_esc_attr( 'comments_your_name' ) .'" /></p>',
		'email'         =>  '<p><input name="email" id="email" type="text" value="" size="45" aria-required="true" placeholder="'. Better_Translation()->_get_esc_attr( 'comments_your_email' ) .'" /></p>',
	),
);

// Removes url field from form
if( better_get_option( 'post_comments_form_remove_url' ) == 'no' ){
	$form_args['fields']['url'] = '<p><input name="url" id="url" type="text" value="" size="45" placeholder="'. Better_Translation()->_get_esc_attr( 'comments_your_website' ) .'" /></p>';
}

// Comments Number
$num_comments = get_comments_number();

// Prepare comment text
if( $num_comments == 0 ){
	$comments_text = Better_Translation()->_get( 'no_comment_title' );
} elseif ( $num_comments > 1 ) {
	$comments_text = str_replace( '%s', number_format_i18n( $num_comments ), Better_Translation()->_get( 'comments_count_title' ) );
} else {
	$comments_text = Better_Translation()->_get( 'comments_1_comment' );
}

?>
<section id="comments-template" class="comments-template">
	<?php

	// Shows comment form
	if( $form_location == 'top' || $form_location == 'both' ){
		comment_form( $form_args );
	}

	if( have_comments() ) : // Check if there are any comments. ?>

		<div id="comments" class="comments-wrap clearfix">
			<h4 class="section-heading" ><span class="h-text"><?php echo esc_html( $comments_text ); ?></span></h4>

			<ol class="comment-list">
				<?php wp_list_comments( better_list_comments_args() ); ?>
			</ol><!-- .comment-list -->

			<?php better_get_view( 'comments', '_nav' ); ?>

		</div><!-- .comments-wrap-->

	<?php endif; // End check for comments. ?>

	<?php better_get_view( 'comments', '_messages' ); ?>

	<?php
	// Shows comment form
	if( $form_location == 'bottom' || $form_location == 'both' ){
		comment_form( $form_args );
	}
	?>
</section><!-- .comments-template -->