<?php
/**
 * functions.php
 *---------------------------
 * This file contains general functions that used inside theme to
 * do important sections.
 *
 * We create them in a way that you can override them in child them simply!
 * Simply copy the function into child theme and remove the "if( ! function_exists( '*****' ) ){".
 */


/**
 * Used to get theme panel id
 *
 * @return string
 */
function better_theme_panel_id(){
	return 'bs_patricia_theme_options';
}


if( ! function_exists( 'better_get_option' ) ){
	/**
	 * Used to get theme panel options
	 *
	 * @param $field_id
	 *
	 * @return mixed|null
	 */
	function better_get_option( $field_id ){
		return bf_get_option( $field_id, 'bs_patricia_theme_options' );
	} // better_get_option
} // if


if( ! function_exists( 'better_echo_option' ) ){
	/**
	 * Used to get theme panel options
	 *
	 * @param $field_id
	 *
	 * @return mixed|null
	 */
	function better_echo_option( $field_id ){
		echo better_get_option( $field_id ) ;
	} // better_echo_option
} // if


if( ! function_exists( 'patricia_get_main_slider_config' ) ){
	/**
	 * Prepare main slider config
	 *
	 * @return array|mixed
	 */
	function patricia_get_main_slider_config(){

		// return from cache
		if( better_get_global( 'main-slider-config' ) != NULL )
			return better_get_global( 'main-slider-config' );

		$config = array();

		// Show or not
		$config['show'] = better_get_option( 'home_slider' ) != 'no';

		// Slider style
		$config['style'] = better_get_option( 'better_slider_style' );

		// Posts count
		if( better_get_option( 'better_slider_posts_count' ) )
			$config['args']['posts_per_page'] = better_get_option( 'better_slider_posts_count' );
		else
			$config['args']['posts_per_page'] = 6;

		// Category include
		if( better_get_option( 'better_slider_inc_cats' ) != '' )
			$config['args']['cat'] = better_get_option( 'better_slider_inc_cats' );

		// Category exclude
		if( better_get_option( 'better_slider_exc_cats' ) != '' )
			$config['args']['category__not_in'] = explode( ',', better_get_option( 'better_slider_exc_cats' ) );

		// Tags
		if( better_get_option( 'better_slider_inc_tags' ) != '' )
			$config['args']['tag__in'] = better_get_option( 'better_slider_inc_tags' );

		// Custom post types
		if( better_get_option( 'better_slider_post_type' ) != '' )
			$config['args']['post_type'] = explode( ',', better_get_option( 'better_slider_post_type' ) );

		// Posts with a featured image
//		$config['args']['meta_query'] = array(
//			array( 'key' => '_thumbnail_id' )
//		);

		// Slider Animation
		//$config['animation'] = better_get_option( 'better_slider_animation' );

		// Slider Slide Show Speed
		$config['slideshowSpeed'] = better_get_option( 'better_slider_slideshowSpeed' );

		// Slider Animation Speed
		$config['animationSpeed'] = better_get_option( 'better_slider_animationSpeed' );

		// Save it to cache
		better_set_global( 'main-slider-config', $config );

		return $config;

	} // patricia_get_main_slider_config

} // if


if( ! function_exists( 'patricia_listing_social_share' ) ){
	/**
	 * Prints listing share buttons
	 *
	 * @param   null    $label
	 * @param   string  $class
	 * @param   bool    $show_title
	 */
	function patricia_listing_social_share( $label = NULL, $class = '', $show_title = false ){

		$sites = better_get_option( 'social_share_sites' );

		if( is_null( $label ) )
			$label = '<i class="fa fa-share-alt"></i>';

		?>
		<div class="post-share <?php echo esc_attr( $class ); ?>">

			<span class="share-handler"><?php echo esc_html( $label ); ?></span>

			<ul class="social-list clearfix">
				<?php

				foreach( (array)$sites as $site_key => $site ){
					if( $site )
						echo bs_shortcode_social_share_get_li( $site_key, $show_title );
				}

				?>
			</ul>

		</div>
		<?php

	} // patricia_listing_social_share
} // patricia_listing_social_share


if( ! function_exists( 'patricia_spe_line' ) ){
	/**
	 * Posts separator line
	 */
	function patricia_spe_line(){

		$icon = '';

		// Category and Tags icon
		if( is_category() || is_tag() ){
			$icon = bf_get_term_meta( 'separator_icon' );
		}
		// User Icon
		elseif( is_author() ){
			$icon = bf_get_user_meta( 'separator_icon' );
		}
		// Search Icon
		elseif( is_search() ){
			$icon = better_get_option( 'search_separator_icon' );
		}

		// General icon
		if( $icon == '' || $icon == 'none'){
			$icon = better_get_option( 'separator_icon' );
		}

		// generate final icon tag
		if( $icon != '' ){
			$icon = "<span class='sep-icon'><i class='fa {$icon}'></i></span>";
		}

		?>
		<div class="separator-line"><?php echo $icon; ?></div>
		<?php

	} // patricia_spe_line
} // if


if( ! function_exists( 'patricia_layout_option_list' ) ){
	/**
	 * Panels layout field options
	 *
	 * @param bool $default
	 *
	 * @return array
	 */
	function patricia_layout_option_list( $default = false ){

		$option = array();

		if( $default ){
			$option['default'] = array(
				'img'       =>  bf_get_theme_uri( "includes/admin-assets/images/layout-default.png" ),
				'label'     =>  __( 'Default', 'better-studio' ),
			);
		}

		$option['1-col'] = array(
			'img'       =>  bf_get_theme_uri( 'includes/admin-assets/images/layout-1-col.png' ),
			'label'     =>  __( 'Full Width', 'better-studio' ),
		);
		$option['2-col-right'] = array(
			'img'       =>  bf_get_theme_uri( 'includes/admin-assets/images/layout-2-col-right.png' ),
			'label'     =>  __( 'Right Sidebar', 'better-studio' ),
		);
		$option['2-col-left'] = array(
			'img'       =>  bf_get_theme_uri( 'includes/admin-assets/images/layout-2-col-left.png' ),
			'label'     =>  __( 'Left Sidebar', 'better-studio' ),
		);

		return $option;
	} // patricia_layout_option_list
} // if


if( ! function_exists( 'patricia_is_valid_layout' ) ){
	/**
	 * Check the parameter is theme valid layout or not!
	 *
	 * This is because of multiple theme that have same page_layout id for page layout
	 *
	 * @param $layout
	 *
	 * @return bool
	 */
	function patricia_is_valid_layout( $layout ){
		return in_array( $layout, array(
			'1-col',
			'2-col-left',
			'2-col-right',
		) );
	} // patricia_is_valid_layout
} // if


if( ! function_exists( 'patricia_get_page_layout' ) ){
	/**
	 * Used to get current page layout
	 *
	 * @return bool|mixed|null|string|void
	 */
	function patricia_get_page_layout(){

		// Return from cache
		if( better_get_global( 'page-layout' ) )
			return better_get_global( 'page-layout' );

		$layout = 'default';

		// Homepage layout
		if( is_home() ){
			$layout = better_get_option( 'home_layout' );
		}

		// Post Layout
		elseif( is_singular( 'post' ) ){
			$layout = bf_get_post_meta( 'page_layout' );

			if( $layout == 'default' ){
				$layout = better_get_option( 'post_layout' );
			}
		}

		// Page Layout
		elseif( is_page() ){
			$layout = bf_get_post_meta( 'page_layout' );

			if( $layout == 'default' ){
				$layout = better_get_option( 'page_layout' );
			}
		}

		// Category Layout
		elseif( is_category() ){
			$layout = bf_get_term_meta( 'page_layout' );

			if( $layout == 'default' ){
				$layout = better_get_option( 'cat_layout' );
			}
		}

		// Tag Layout
		elseif( is_tag() ){
			$layout = bf_get_term_meta( 'page_layout' );

			if( $layout == 'default' ){
				$layout = better_get_option( 'tag_layout' );
			}
		}

		// Author Layout
		elseif( is_author() ){
			$layout = bf_get_user_meta( 'page_layout' );

			if( $layout == 'default' ){
				$layout = better_get_option( 'author_layout' );
			}
		}

		// Search Layout
		elseif( is_search() ){
			$layout = better_get_option( 'search_layout' );
		}

		// Return default
		if( $layout == 'default' || ! patricia_is_valid_layout( $layout ) ){
			$layout = better_get_option( 'general_layout' );
		}

		// Cache
		better_set_global( 'page-layout', $layout );

		return $layout;

	} // patricia_get_page_layout
}// if


if( ! function_exists( 'patricia_listing_option_list' ) ){
	/**
	 * Panels posts listing field option
	 *
	 * @param bool $default
	 *
	 * @return array
	 */
	function patricia_listing_option_list( $default = false ){

		$option = array();

		if( $default ){
			$option['default'] = array(
				'img'       =>  bf_get_theme_uri( 'includes/admin-assets/images/listing-default.png' ),
				'label'     =>  __( 'Default', 'better-studio' ),
			);
		}

		$option['blog'] = array(
			'img'       =>  bf_get_theme_uri( 'includes/admin-assets/images/listing-blog.png' ),
			'label'     =>  __( 'Blog Listing', 'better-studio' ),
		);
		$option['grid'] = array(
			'img'       =>  bf_get_theme_uri( 'includes/admin-assets/images/listing-grid.png' ),
			'label'     =>  __( 'Grid Listing', 'better-studio' ),
		);
		$option['modern'] = array(
			'img'       =>  bf_get_theme_uri( 'includes/admin-assets/images/listing-modern.png' ),
			'label'     =>  __( 'Modern Listing', 'better-studio' ),
		);
		$option['complex-1'] = array(
			'img'       =>  bf_get_theme_uri( 'includes/admin-assets/images/listing-complex-1.png' ),
			'label'     =>  __( 'Complex 1', 'better-studio' ),
		);
		$option['complex-2'] = array(
			'img'       =>  bf_get_theme_uri( 'includes/admin-assets/images/listing-complex-2.png' ),
			'label'     =>  __( 'Complex 2', 'better-studio' ),
		);
		$option['complex-3'] = array(
			'img'       =>  bf_get_theme_uri( 'includes/admin-assets/images/listing-complex-3.png' ),
			'label'     =>  __( 'Complex 3', 'better-studio' ),
		);

		return $option;
	} // patricia_listing_option_list
} // if


if( ! function_exists( 'patricia_is_valid_listing' ) ){
	/**
	 * Checks parameter to be a theme valid listing
	 *
	 * @param $listing
	 *
	 * @return bool
	 */
	function patricia_is_valid_listing( $listing ){
		return in_array(
			$listing,
			array(
				'normal',
				'modern',
				'blog',
				'complex-1',
				'complex-2',
				'complex-3',
			)
		);
	} // patricia_is_valid_listing

} // if


if( ! function_exists( 'patricia_get_page_listing' ) ){
	/**
	 * Used to get current page posts listing
	 *
	 * @return mixed|string
	 */
	function patricia_get_page_listing(){

		// Return from cache
		if( better_get_global( 'page-listing' ) )
			return better_get_global( 'page-listing' );

		$listing = 'default';

		// Homepage listing
		if( is_home() ){
			$listing = better_get_option( 'home_listing' );
		}

		// Category Layout
		elseif( is_category() ){
			$listing = bf_get_term_meta( 'page_listing' );

			if( $listing == 'default' ){
				$listing = better_get_option( 'cat_listing' );
			}
		}

		// Tag Layout
		elseif( is_tag() ){
			$listing = bf_get_term_meta( 'page_listing' );

			if( $listing == 'default' ){
				$listing = better_get_option( 'tag_listing' );
			}
		}

		// Author Layout
		elseif( is_author() ){
			$listing = bf_get_user_meta( 'page_listing' );

			if( $listing == 'default' ){
				$listing = better_get_option( 'author_listing' );
			}
		}

		// Search Layout
		elseif( is_search() ){
			$listing = better_get_option( 'search_listing' );
		}


		// check to be valid theme listing or use default
		if( $listing == 'default' || ! patricia_is_valid_listing( $listing ) ){
			$listing = better_get_option( 'general_listing' );
		}

		// Cache
		better_set_global( 'page-listing', 'listing-' . $listing );

		return 'listing-' . $listing;

	} // patricia_get_page_listing
} // if


if( ! function_exists( 'patricia_get_pagination' ) ){
	/**
	 * Used to get pagination
	 */
	function patricia_get_pagination(){

		$pagination = better_get_option( 'pagination_type' );

		switch( $pagination ){

			case 'links':
				better_get_links_pagination();
				break;

			case 'numbered':
				better_get_pagination();
				break;

		}

	}
}


if( ! function_exists( 'patricia_header_style_option_list' ) ){
	/**
	 * Panels header style field options
	 *
	 * @param bool $default
	 *
	 * @return array
	 */
	function patricia_header_style_option_list( $default = false ){

		$option = array();

		if( $default ){
			$option['default'] = array(
				'img'       =>  bf_get_theme_uri( 'includes/admin-assets/images/header-style-default.png' ),
				'label'     =>  __( 'Default', 'better-studio' ),
			);
		}

		$option['style-1'] = array(
			'img'       =>  bf_get_theme_uri( 'includes/admin-assets/images/header-style-1.png' ),
			'label'     =>  __( 'Style 1', 'better-studio' ),
		);
		$option['style-2'] = array(
			'img'       =>  bf_get_theme_uri( 'includes/admin-assets/images/header-style-2.png' ),
			'label'     =>  __( 'Style 2', 'better-studio' ),
		);

		return $option;
	} // patricia_header_style_option_list
} // if


if( ! function_exists( 'patricia_get_header_style' ) ){
	/**
	 * Used to get current page header style
	 *
	 * @return bool|mixed|null|string
	 */
	function patricia_get_header_style(){

		$style = 'default';

		if( is_category() ){
			if( bf_get_term_meta( 'header_style' ) != 'default' )
				$style = bf_get_term_meta( 'header_style' );
		}

		if( $style == 'default' || ! patricia_is_valid_header_style( $style )  )
			$style = better_get_option( 'header_style' );

		return $style;

	} // patricia_get_header_style
} // if


if( ! function_exists( 'patricia_is_valid_header_style' ) ){
	/**
	 * Check the parameter is theme valid layout or not!
	 *
	 * This is because of multiple theme that have same header_style id for page headers
	 *
	 * @param $layout
	 *
	 * @return bool
	 */
	function patricia_is_valid_header_style( $layout ){
		return in_array( $layout, array(
			'style-1',
			'style-2',
		) );
	} // patricia_is_valid_header_style
} // if

