<?php


/**
 * Outputs an HTML element's attributes.
 *
 * @since   1.0.0
 * @access  public
 *
 * @param   string  $slug       Slug/ID of the element/tag
 * @param   string  $class      Extra classes
 * @param   string  $context    Specific context ex: primary
 *
 * @return void
 */
function better_attr( $slug, $class = '', $context = '' ){

    echo better_get_attr( $slug, $class, $context );

}


/**
 * Gets an HTML element's attributes.
 *
 * @since  1.0.0
 * @access public
 *
 * @param   string  $slug       Slug/ID of the element/tag
 * @param   string  $class      Extra classes
 * @param   string  $context    Specific context ex: primary
 *
 * @return string
 */
function better_get_attr( $slug, $class = '', $context = '' ){

    $output = '';

    $attributes   = apply_filters( "better_attr_{$slug}", array(), $class, $context );

    if( empty( $attributes ) ){
        $attributes['class'] = $slug;
    }

    foreach( $attributes as $attr_id => $attr ){
        $output .= ! empty( $attr ) ? sprintf( ' %s="%s"', esc_html( $attr_id ), esc_attr( $attr ) ) : esc_html( " {$attr_id}" );
    }

    return trim( $output );
}


/**
 * Outputs an HTML meta tag.
 *
 * @since   1.0.0
 * @access  public
 *
 * @param   string  $prop       Meta itemprop value
 * @param   string  $content    Meta content value
 *
 * @return void
 */
function better_attr_meta( $prop , $content = '' ){

    echo better_get_attr_meta( $prop, $content );

}


/**
 * Gets an HTML meta tag.
 *
 * @since   1.0.0
 * @access  public
 *
 * @param   string  $prop       Meta itemprop value
 * @param   string  $content    Meta content value
 *
 * @return string
 */
function better_get_attr_meta( $prop, $content = '' ){

    $output = '';

    $attr   = apply_filters( "better_attr_meta_{$prop}", array() );

    if( empty( $attr ) ){

        $attr['itemprop'] = $prop;
        $attr['content'] = $content;

    }

    foreach( $attr as $name => $value ){

        $output .= ! empty( $value ) ? sprintf( ' %s="%s"', esc_html( $name ), esc_attr( $value ) ) : esc_html( " {$name}" );

    }

    return '<meta ' . trim( $output ) . ' />';
}