<?php


//
//
// Header elements attributes
//
//
add_filter( 'better_attr_site',             'better_attr_site',             5, 3 );
add_filter( 'better_attr_site-title',       'better_attr_site_title',       5, 3 );
add_filter( 'better_attr_site-logo',        'better_attr_site_logo',        5, 3 );
add_filter( 'better_attr_site-url',         'better_attr_site_url',         5, 3 );
add_filter( 'better_attr_site-description', 'better_attr_site_description', 5, 3 );


/**
 * Site branding/info
 * Usually this used for a wrapper that contains title and tagline and logo.
 *
 * @since   1.0.0
 * @access  public
 *
 * @param   string  $attr       Default or filtered attributes
 * @param   string  $class      Extra classes
 * @param   string  $context    Specific context ex: primary
 *
 * @return  array
 */
function better_attr_site( $attr, $class = '', $context = '' ) {

    if( ! empty( $context ) ){
        $attr['id'] = "site-branding-{$context}";
    }else{
        $attr['id'] = 'site-branding';
    }

    if( ! empty( $class ) ){
        if( isset( $attr['class'] ) ){
            $attr['class'] .= ' site-branding ' . $class;
        }else{
            $attr['class'] = ' site-branding ' . $class;
        }
    }else{
        $attr['class'] = ' site-branding ' . $class;
    }

    $attr['itemtype'] = 'http://schema.org/Organization';
    $attr['itemscope'] = 'itemscope';

    return $attr;
}


/**
 * Site title attributes.
 *
 * @since   1.0.0
 * @access  public
 *
 * @param   string  $attr       Default or filtered attributes
 * @param   string  $class      Extra classes
 * @param   string  $context    Specific context ex: primary
 *
 * @return  array
 */
function better_attr_site_title( $attr, $class = '', $context = '' ) {

    if( ! empty( $context ) ){
        $attr['id'] = "site-title-{$context}";
    }else{
        $attr['id'] = 'site-title';
    }

    if( ! empty( $class ) ){
        if( isset( $attr['class'] ) ){
            $attr['class'] .= ' ' . $class;
        }else{
            $attr['class'] = $class;
        }
    }

    $attr['itemprop'] = 'headline';

    return $attr;
}


/**
 * Site description attributes.
 *
 * @since   1.0.0
 * @access  public
 *
 * @param   string  $attr       Default or filtered attributes
 * @param   string  $class      Extra classes
 * @param   string  $context    Specific context ex: primary
 *
 * @return  array
 */
function better_attr_site_description( $attr, $class = '', $context = '' ) {

    if( ! empty( $context ) ){
        $attr['id'] = "site-description-{$context}";
    }else{
        $attr['id'] = 'site-description';
    }

    if( ! empty( $class ) ){
        if( isset( $attr['class'] ) ){
            $attr['class'] .= ' ' . $class;
        }else{
            $attr['class'] = $class;
        }
    }

    $attr['itemprop'] = 'description';

    return $attr;
}


/**
 * Site logo attributes.
 *
 * @since   1.0.0
 * @access  public
 *
 * @param   string  $attr       Default or filtered attributes
 * @param   string  $class      Extra classes
 * @param   string  $context    Specific context ex: primary
 *
 * @return  array
 */
function better_attr_site_logo( $attr, $class = '', $context = '' ) {

    if( ! empty( $context ) ){
        $attr['id'] = $context;
    }

    if( ! empty( $class ) ){
        if( isset( $attr['class'] ) ){
            $attr['class'] .= ' ' . $class;
        }else{
            $attr['class'] = $class;
        }
    }

    $attr['itemprop']   = 'logo';

    return $attr;
}


/**
 * Site URL attributes.
 *
 * @since   1.0.0
 * @access  public
 *
 * @param   string  $attr       Default or filtered attributes
 * @param   string  $class      Extra classes
 * @param   string  $context    Specific context ex: primary
 *
 * @return  array
 */
function better_attr_site_url( $attr, $class = '', $context = '' ) {

    if( ! empty( $context ) ){
        $attr['id'] = $context;
    }

    if( ! empty( $class ) ){
        if( isset( $attr['class'] ) ){
            $attr['class'] .= ' ' . $class;
        }else{
            $attr['class'] = $class;
        }
    }

    $attr['itemprop'] = 'url';
    $attr['rel'] = 'home';

    return $attr;
}