<?php
/**
 * category.php
 *---------------------------
 * Registers options for categories
 *
 */

add_filter( 'better-framework/taxonomy/options' , 'patricia_category_options', 100 );

if( ! function_exists( 'patricia_category_options' ) ){
	/**
	 * Setup custom taxonomy options for BetterMag
	 *
	 * @param $options
	 * @return array
	 */
	function patricia_category_options( $options ){

		// contains active menu list
		$menus  = array();
		$menus['default'] = __( 'Default Main Navigation', 'better-studio' );
		$menus[] = array(
			'label'     =>  __( 'Menus', 'better-studio' ),
			'options'   =>  bf_get_menus(),
		);

		/**
		 * => Style
		 */
		$fields[] = array(
			'name'          =>  __( 'Style' , 'better-studio' ),
			'id'            =>  'tab_style',
			'type'          =>  'tab',
			'icon'          =>  'bsai-paint',
		);

		$fields[] = array(
			'name'          =>  __( 'Category Posts Separator Icon', 'better-studio' ),
			'id'            =>  'separator_icon',
			'desc'          =>  __( 'Override separator icon for this category.', 'better-studio' ),
			'type'          =>  'icon_select',
			'options'       =>  array( 'fontawesome' ),
			'std'           =>  'none',
			'default_text'  =>  __( 'Chose an Icon', 'betterstudio' ),
		);

		$fields['term_color'] = array(
			'name'          =>  __( 'Category Highlight Color', 'better-studio' ),
			'id'            =>  'term_color',
			'type'          =>  'color',
			'std'           =>  better_get_option( 'theme_color' ),
			'save-std'      =>  false,
			'desc'          =>  __( 'This color will be used in several areas such as navigation and listing blocks to emphasize category.', 'better-studio' ),
			'css'           =>  array(
				array(
					'selector'  => array(
						'.widget.widget_categories li.cat-item.cat-item-%%id%% > a:hover',
						'.widget.widget_categories li.cat-item.cat-item-%%id%% > a > .post-count',
						'.main-menu.menu li.menu-term-%%id%%:hover > a',
						'.listing-item-blog.main-term-%%id%% .title a:hover',
						'.listing-item-blog.main-term-%%id%% a.read-more:hover',
						'.listing-item-blog.main-term-%%id%% .post-meta a:hover',
						'.listing-item-grid.main-term-%%id%% .post-meta a:hover',
						'.listing-item-grid.main-term-%%id%% .title a:hover',
						'.listing-item-grid.main-term-%%id%% a.read-more:hover',
						'.listing-item-modern.main-term-%%id%% .post-meta a:hover',
						'.listing-item-modern.main-term-%%id%% .title a:hover',
						'.listing-item-modern.main-term-%%id%% a.read-more:hover',
						'.term-badges .term-badge.term-%%id%% a:hover',
					),
					'prop'      => array(
						'color' =>   '%%value%% !important'
					)
				),
				array(
					'selector'  => array(
						'.main-menu.menu > li.menu-term-%%id%%:hover > a:before',
						'.main-menu.menu > li.menu-term-%%id%%.current-menu-item > a:before',
						'.main-menu.menu > li.menu-term-%%id%%.current-menu-parent > a:before',
						'.widget.widget_nav_menu ul.menu li.menu-term-%%id%% > a:hover',
					),
					'prop'      => array(
						'background-color' =>   '%%value%% !important'
					)
				),
				array(
					'selector'  =>  array(
						'body.category-%%id%% ::selection',
					),
					'prop'      =>  array(
						'background' =>   '%%value%% !important'
					)
				),
				array(
					'selector'  =>  array(
						'body.category-%%id%% ::-moz-selection'
					),
					'prop'      =>  array(
						'background' =>   '%%value%% !important'
					)
				),

			),
		);
		$fields['page_layout'] = array(
			'name'          =>  __( 'Page Layout', 'better-studio' ),
			'id'            =>  'page_layout',
			'std'           =>  'default',
			'type'          =>  'image_select',
			'section_class' =>  'style-floated-left bordered',
			'desc'          =>  __( 'Override default layout for this category layout.', 'better-studio' ),
			'options'       =>  patricia_layout_option_list( true )
		);
		$fields['page_listing'] = array(
			'name'          =>  __( 'Posts Listing', 'better-studio' ),
			'id'            =>  'page_listing',
			'std'           =>  'default',
			'type'          =>  'image_select',
			'section_class' =>  'style-floated-left bordered',
			'desc'          =>  __( 'Override default posts listing fot this category.', 'better-studio' ),
			'options'       =>  patricia_listing_option_list( true )
		);
		$fields['term_posts_count'] = array(
			'name'          =>  __( 'Number of Post to Show', 'better-studio' ),
			'id'            =>  'term_posts_count',
			'desc'          =>  sprintf( __( 'Leave this empty for default. <br>Default: %s', 'better-studio' ), better_get_option( 'archive_cat_posts_count' ) != '' ? better_get_option( 'archive_cat_posts_count' ) : get_option( 'posts_per_page' ) ),
			'type'          =>  'text',
			'std'           =>  '',
		);
		$fields[] = array(
			'name'          =>  __( 'Background Style' , 'better-studio' ),
			'type'          =>  'group',
			'state'         =>  'close',
		);
		$fields['bg_color'] = array(
			'name'          =>  __( 'Body Background Color', 'better-studio' ),
			'id'            =>  'bg_color',
			'type'          =>  'color',
			'std'           =>  better_get_option( 'bg_color' ),
			'save-std'      =>  false,
			'desc'          =>  __( 'Setting a body background image below will override it.', 'better-studio' ),
			'css'           =>  array(
				array(
					'selector'  => array(
						'body.category-%%id%%',
					),
					'prop'      => array(
						'background-color' =>   '%%value%%'
					)
				),
			)
		);
		$fields['bg_image'] = array(
			'name'          =>  __('Body Background Image','better-studio'),
			'id'            =>  'bg_image',
			'type'          =>  'background_image',
			'std'           =>  '',
			'upload_label'  =>  __( 'Upload Image', 'better-studio' ),
			'desc'          =>  __( 'Use light patterns in non-boxed layout. For patterns, use a repeating background. Use photo to fully cover the background with an image. Note that it will override the background color option.','better-studio'),
			'css'           =>  array(
				array(
					'selector'  => array(
						'body.category-%%id%%'
					),
					'prop'      => array( 'background-image' ),
					'type'      => 'background-image',
					'after' => '.content-wrap{ -moz-box-shadow:0 0 4px rgba(0,0,0,0.2);-webkit-box-shadow:0 0 4px rgba(0,0,0,0.2);box-shadow:0 0 4px rgba(0,0,0,0.2); }',
				)
			)
		);

		/**
		 * => Title
		 */
		$fields[] = array(
			'name'          =>  __( 'Title' , 'better-studio' ),
			'id'            =>  'tab_title',
			'type'          =>  'tab',
			'icon'          =>  'bsai-title',
		);
		$fields['term_custom_title'] = array(
			'name'          =>  __( 'Custom Category Title', 'better-studio' ),
			'id'            =>  'term_custom_title',
			'type'          =>  'text',
			'std'           =>  '',
			'desc'          =>  __( 'Customize category title in archive page without renaming name of category.', 'better-studio' ),
		);
		$fields['hide_term_title'] = array(
			'name'          =>  __( 'Hide Category Title', 'better-studio' ),
			'id'            =>  'hide_term_title',
			'type'          =>  'switch',
			'std'           =>  '0',
			'on-label'      =>  __( 'Yes', 'better-studio' ),
			'off-label'     =>  __( 'No', 'better-studio' ),
			'desc'          =>  __( 'Enable this for hiding category title.', 'better-studio' ),
		);
		$fields['hide_term_description'] = array(
			'name'          =>  __( 'Hide Category Description', 'better-studio' ),
			'id'            =>  'hide_term_description',
			'type'          =>  'switch',
			'std'           =>  '0',
			'on-label'      =>  __( 'Yes', 'better-studio' ),
			'off-label'     =>  __( 'No', 'better-studio' ),
			'desc'          =>  __( 'Enable this for hiding category description.', 'better-studio' ),
		);


		/**
		 * => Header Options
		 */
		$fields['header_options'] = array(
			'name'          =>  __( 'Header', 'better-studio' ),
			'id'            =>  'header_options',
			'type'          =>  'tab',
			'icon'          =>  'bsai-header',
		);
		$fields[] = array(
			'name'          =>  __( 'Header', 'better-studio' ),
			'type'          =>  'group',
			'state'         =>  'open',
		);
		$fields['header_style'] = array(
			'name'          =>  __( 'Header Style', 'better-studio' ),
			'id'            =>  'header_style',
			'desc'          =>   __( 'Override header style for this category.', 'better-studio' ),
			'std'           =>  'default',
			'type'          =>  'image_select',
			'section_class' =>  'style-floated-left bordered',
			'options'       =>  patricia_header_style_option_list( true ),
		);
		$fields['main_nav_menu'] = array(
			'name'          =>  __( 'Main Navigation Menu', 'better-studio' ),
			'id'            =>  'main_nav_menu',
			'desc'          =>  __( 'Replace & change main menu for this category.', 'better-studio' ),
			'type'          =>  'select',
			'std'           =>  'default',
			'options'       =>  $menus
		);

		$fields[] = array(
			'name'          =>  __( 'Category Custom Logo', 'better-studio' ),
			'type'          =>  'group',
			'state'         =>  'open',
		);
		$fields['logo_image'] = array(
			'name'          =>  __( 'Logo Image', 'better-studio' ),
			'id'            =>  'logo_image',
			'desc'          =>  __( 'You can override default site logo with this option to create fully customized archive pages for each category.', 'better-studio' ),
			'std'           =>  better_get_option( 'logo_image' ),
			'type'          =>  'media_image',
			'media_title'   =>  __( 'Select or Upload Logo', 'better-studio'),
			'media_button'  =>  __( 'Select Image', 'better-studio'),
			'upload_label'  =>  __( 'Upload Logo', 'better-studio'),
			'remove_label'  =>  __( 'Remove Logo', 'better-studio'),
			'save-std'      =>  false,
		);
		$fields['logo_image_retina'] = array(
			'name'          =>  __( 'Logo Image Retina (2x)', 'better-studio' ),
			'id'            =>  'logo_image_retina',
			'desc'          =>  __( 'If you want to upload a Retina Image, It\'s Image Size should be exactly double in compare with your normal Logo. It requires WP Retina 2x plugin.', 'better-studio' ),
			'std'           =>  better_get_option( 'logo_image_retina' ),
			'type'          =>  'media_image',
			'media_title'   =>  __( 'Select or Upload Retina Logo', 'better-studio'),
			'media_button'  =>  __( 'Select Retina Image', 'better-studio'),
			'upload_label'  =>  __( 'Upload Retina Logo', 'better-studio'),
			'remove_label'  =>  __( 'Remove Retina Logo', 'better-studio'),
			'save-std'      =>  false,
		);
		$fields[] = array(
			'name'          =>  __( 'Header Padding', 'better-studio' ),
			'type'          =>  'group',
			'state'         =>  'close',
		);
		$fields['header_top_padding'] = array(
			'name'          =>  __( 'Header Top Padding', 'better-studio' ),
			'id'            =>  'header_top_padding',
			'suffix'        =>  __( 'Pixel', 'better-studio' ),
			'desc'          =>  __( 'In pixels without px, ex: 20. <br>Leave empty for default value.', 'better-studio' ),
			'type'          =>  'text',
			'std'           =>  '',
			'css-echo-default'  => false,
			'css'           =>  array(
				array(
					'selector'  => array(
						'body.category-%%id%% .header.header-style-1 .header-inner',
						'body.category-%%id%% .header.header-style-2 .header-inner',
						'body.category-%%id%% .header.header-style-3 .header-inner',
						'body.category-%%id%% .header.header-style-4 .header-inner',
						'body.category-%%id%% .header.header-style-5 .header-inner',
						'body.category-%%id%% .header.header-style-6 .header-inner',
					),
					'prop'      => array( 'padding-top' => '%%value%%px' ),
				)
			),
		);
		$fields['header_bottom_padding'] = array(
			'name'          =>  __( 'Header Bottom Padding', 'better-studio' ),
			'id'            =>  'header_bottom_padding',
			'suffix'        =>  __( 'Pixel', 'better-studio' ),
			'desc'          =>  __( 'In pixels without px, ex: 20. <br>Leave empty for default value. Values lower than 60px will break the style.', 'better-studio' ),
			'type'          =>  'text',
			'std'           =>  '',
			'css-echo-default'  => false,
			'css'           =>  array(
				array(
					'selector'  => array(
						'body.category-%%id%% .header.header-style-1 .header-inner',
						'body.category-%%id%% .header.header-style-2 .header-inner',
						'body.category-%%id%% .header.header-style-3 .header-inner',
						'body.category-%%id%% .header.header-style-4 .header-inner',
						'body.category-%%id%% .header.header-style-5 .header-inner',
						'body.category-%%id%% .header.header-style-6 .header-inner',
					),
					'prop'      => array( 'padding-bottom' => '%%value%%px' ),
				)
			),
		);

		/**
		 * => Custom Javascript / CSS
		 */
		$fields['custom_css_settings'] = array(
			'name'          =>  __( 'Custom CSS' , 'better-studio' ),
			'id'            =>  'custom_css_settings',
			'type'          =>  'tab',
			'icon'          =>  'bsai-css3',
			'margin-top'    =>  '20',
		);
		$fields['custom_css_code'] = array(
			'name'          =>  __( 'Custom CSS Code', 'better-studio' ),
			'id'            =>  'custom_css_code',
			'type'          =>  'textarea',
			'std'           =>  '',
			'desc'          =>  __( 'Paste your CSS code, do not include any tags or HTML in the field. Any custom CSS entered here will override the theme CSS. In some cases, the !important tag may be needed.', 'better-studio' )
		);
		$fields['custom_css_class'] = array(
			'name'          =>  __( 'Custom Body Class', 'better-studio' ),
			'id'            =>  'custom_css_class',
			'type'          =>  'text',
			'std'           =>  '',
			'desc'          =>  __( 'This classes will be added to body.<br> Separate classes with space.', 'better-studio' )
		);
		$fields[] = array(
			'name'          =>  __( 'Responsive CSS', 'better-studio' ),
			'type'          =>  'group',
			'state'         =>  'close',
			'desc'          =>  'Paste your custom css in the appropriate box, to run only on a specific device',
		);
		$fields['custom_css_desktop_code'] = array(
			'name'          =>  __( 'Desktop', 'better-studio' ),
			'id'            =>  'custom_css_desktop_code',
			'type'          =>  'textarea',
			'std'           =>  '',
			'desc'          =>  __( '1200px +', 'better-studio' )
		);
		$fields['custom_css_tablet_landscape_code'] = array(
			'name'          =>  __( 'Tablet Landscape', 'better-studio' ),
			'id'            =>  'custom_css_tablet_landscape_code',
			'type'          =>  'textarea',
			'std'           =>  '',
			'desc'          =>  __( '1019px - 1199px', 'better-studio' )
		);
		$fields['custom_css_tablet_portrait_code'] = array(
			'name'          =>  __( 'Tablet Portrait', 'better-studio' ),
			'id'            =>  'custom_css_tablet_portrait_code',
			'type'          =>  'textarea',
			'std'           =>  '',
			'desc'          =>  __( '768px - 1018px', 'better-studio' )
		);
		$fields['custom_css_phones_code'] = array(
			'name'          =>  __( 'Phones', 'better-studio' ),
			'id'            =>  'custom_css_phones_code',
			'type'          =>  'textarea',
			'std'           =>  '',
			'desc'          =>  __( '768px - 1018px', 'better-studio' )
		);


		//
		// Support to custom taxonomies
		//
		$cat_taxonomies = array( 'category' );
		if( better_get_option( 'advanced_category_options_tax' ) != '' )
			$cat_taxonomies = array_merge( explode( ',', better_get_option( 'advanced_category_options_tax' ) ), $cat_taxonomies );

		$options[] = array(
			'config'    => array(
				'taxonomies'    => $cat_taxonomies,
				'name'          => __( 'Better Category Options', 'better-studio' )
			),
			'panel-id'  => better_theme_panel_id(),

			'fields'    => $fields
		);

		return $options;

	} // patricia_category_options
} // if