<?php
/**
 * metabox.php
 *---------------------------
 * Registers options for posts and pages
 *
 */

add_filter( 'better-framework/metabox/options' , 'patricia_metabox_options', 100 );


if( ! function_exists( 'patricia_metabox_options' ) ){
	/**
	 * Setup custom metaboxe
	 *
	 * @param $options
	 * @return array
	 */
	function patricia_metabox_options( $options ){

		$fields     = array();

		/**
		 * => Post Options
		 */
		$fields['_post_options'] = array(
			'name'          =>  __( 'Post', 'better-studio' ),
			'id'            =>  '_post_options',
			'type'          =>  'tab',
			'icon'          =>  'bsai-page-text',
		);
		$fields['_featured_embed_code'] = array(
			'name'          =>  __( 'Featured Video/Audio Code', 'better-studio' ),
			'id'            =>  '_featured_embed_code',
			'desc'          =>  __( 'Paste YouTube, Vimeo or self hosted video URL then player automatically will be generated.', 'better-studio' ),
			'type'          =>  'textarea',
			'std'           =>  '',
		);

		$fields['page_layout'] = array(
			'name'          =>  __( 'Page Layout', 'better-studio' ),
			'id'            =>  'page_layout',
			'std'           =>  'default',
			'type'          =>  'image_select',
			'section_class' =>  'style-floated-left bordered',
			'desc'          =>  __( 'Override page layout for this post.', 'better-studio' ),
			'options'       =>  patricia_layout_option_list( true )
		);

		if( ! is_admin() || bf_get_admin_current_post_type() == 'post' ) {

			$fields['_bs_primary_category'] = array(
				'name'      =>  __( 'Primary Category', 'better-studio' ),
				'desc'      =>  __( 'When you have multiple categories for a post, auto detection chooses one in alphabetical order. These used for show an label above image in listings and breadcrumb.', 'better-studio' ),
				'id'        =>  '_bs_primary_category',
				'std'       =>  'auto-detect',
				'type'      =>  'select',
				'options'   =>  array(
					'auto-detect'   =>  __( 'Auto Detect', 'better-studio' ),
					array(
						'label'     =>  __( 'Categories', 'better-studio' ),
						'options'   =>  array( 'category_walker' => 'category_walker' ),
					)
				)
			);
		}


		/**
		 * => Custom Javascript / CSS
		 */
		$fields['_custom_css_settings'] = array(
			'name'          =>  __( 'Custom CSS' , 'better-studio' ),
			'id'            =>  '_custom_css_settings',
			'type'          =>  'tab',
			'icon'          =>  'bsai-css3',
			'margin-top'    =>  '20',
		);
		$fields['_custom_css_code'] = array(
			'name'          =>  __( 'Custom CSS Code', 'better-studio' ),
			'id'            =>  '_custom_css_code',
			'type'          =>  'textarea',
			'std'           =>  '',
			'desc'          =>  __( 'Paste your CSS code, do not include any tags or HTML in the field. Any custom CSS entered here will override the theme CSS. In some cases, the !important tag may be needed.', 'better-studio' )
		);
		$fields['_custom_css_class'] = array(
			'name'          =>  __( 'Custom Body Class', 'better-studio' ),
			'id'            =>  '_custom_css_class',
			'type'          =>  'text',
			'std'           =>  '',
			'desc'          =>  __( 'This classes will be added to body.<br> Separate classes with space.', 'better-studio' )
		);
		$fields[] = array(
			'name'          =>  __( 'Responsive CSS', 'better-studio' ),
			'type'          =>  'group',
			'state'         =>  'close',
			'desc'          =>  'Paste your custom css in the appropriate box, to run only on a specific device',
		);
		$fields['_custom_css_desktop_code'] = array(
			'name'          =>  __( 'Desktop', 'better-studio' ),
			'id'            =>  '_custom_css_desktop_code',
			'type'          =>  'textarea',
			'std'           =>  '',
			'desc'          =>  __( '1200px +', 'better-studio' )
		);
		$fields['_custom_css_tablet_landscape_code'] = array(
			'name'          =>  __( 'Tablet Landscape', 'better-studio' ),
			'id'            =>  '_custom_css_tablet_landscape_code',
			'type'          =>  'textarea',
			'std'           =>  '',
			'desc'          =>  __( '1019px - 1199px', 'better-studio' )
		);
		$fields['_custom_css_tablet_portrait_code'] = array(
			'name'          =>  __( 'Tablet Portrait', 'better-studio' ),
			'id'            =>  '_custom_css_tablet_portrait_code',
			'type'          =>  'textarea',
			'std'           =>  '',
			'desc'          =>  __( '768px - 1018px', 'better-studio' )
		);
		$fields['_custom_css_phones_code'] = array(
			'name'          =>  __( 'Phones', 'better-studio' ),
			'id'            =>  '_custom_css_phones_code',
			'type'          =>  'textarea',
			'std'           =>  '',
			'desc'          =>  __( '768px - 1018px', 'better-studio' )
		);


		//
		// Support custom post types
		//
		$pages = array( 'post', 'page' );
		if( better_get_option( 'advanced_post_options_types' ) != '' )
			$pages = array_merge( explode( ',', better_get_option( 'advanced_post_options_types' ) ), $pages );


		/**
		 * => General Post Options
		 */
		$options['better_post_options'] = array(
			'config' => array(
				'title'         =>  bf_get_admin_current_post_type() == 'page' ? __( 'Better Page Options', 'better-studio' ) : __( 'Better Post Options', 'better-studio' ),
				'pages'         =>  $pages,
				'context'       =>  'normal',
				'prefix'        =>  false,
				'priority'      =>  'high'
			),
			'panel-id'  => better_theme_panel_id(),
			'fields'    => $fields
		);

		return $options;

	} // patricia_metabox_options
} // if