<?php
/**
 * panel.php
 *---------------------------
 * Registers theme option panel
 *
 */

/**
 *
 * => General Options
 *      -> Posts
 *      -> Page
 *      -> Categories Archive
 *      -> Tags Archive
 *      -> Authors Archive
 *      -> Search Results Archive
 *      -> 404 Page
 *
 * => Header Options
 *      -> Responsive Header
 *      -> Topbar
 *      -> Main Menu
 *      -> Header Padding
 *
 * => Slider
 *
 * =>Share Box
 *
 * => Footer Options
 *
 * => Color Options
 *      -> Header Colors
 *
 * => Typography Options
 *      -> General Typography
 *      -> Header Typography
 *      -> Top Bar
 *      -> Blog Listing
 *      -> Grid Listing
 *      -> Widgets
 *
 * => Advanced Options
 *
 * => Custom Javascript / CSS
 *
 * => Analytics & JS
 *
 * => Auto Updates
 *
 * => Import & Export
 *
 */

add_filter( 'better-framework/panel/options' , 'patricia_panel_options', 100 );

if( ! function_exists( 'patricia_panel_options' ) ){

	/**
	 * Setup theme options
	 *
	 * @param $options
	 *
	 * @return array
	 */
	function patricia_panel_options( $options ){

		$fields = array();

		// contains active menu list
		$menus = array();
		$menus['default'] = __( 'Default Main Navigation', 'better-studio' );
		$menus[] = array(
			'label' => __( 'Menus', 'better-studio' ),
			'options' => BF_Query::get_menus(),
		);

		/**
		 * => General Options
		 */
		$fields[] = array(
			'name'          =>  __( 'Templates' , 'better-studio' ),
			'id'            =>  'general_settings',
			'type'          =>  'tab',
			'icon'          =>  'bsai-global'
		);
		$fields[] = array(
			'name'          =>  __( 'General','better-studio' ),
			'type'          =>  'group',
			'state'         =>  'open',
		);
		$fields['general_layout'] = array(
			'name'          =>  __( 'Site Layout', 'better-studio' ),
			'id'            =>  'general_layout',
			'std'           =>  '2-col-right',
			'type'          =>  'image_select',
			'section_class' =>  'style-floated-left bordered',
			'desc'          =>  __( 'Select the layout you want, whether a single column or a 2 column one. It affects every page and the whole layout. This option can be overridden on all sections.', 'better-studio' ),
			'options'       =>  patricia_layout_option_list()
		);
		$fields['general_listing'] = array(
			'name'          =>  __( 'Site Listing', 'better-studio' ),
			'id'            =>  'general_listing',
			'std'           =>  'blog',
			'type'          =>  'image_select',
			'section_class' =>  'style-floated-left bordered',
			'desc'          =>  __( 'Select general listing of site.', 'better-studio' ),
			'options'       =>  patricia_listing_option_list()
		);
		$fields[] = array(
			'id'            =>  'separator_icon',
			'name'          =>  __( 'Site Separator Icon', 'better-studio' ),
			'type'          =>  'icon_select',
			'options'       =>  array( 'fontawesome' ),
			'std'           =>  'fa-fire',
			'default_text'  =>  __( 'Chose an Icon', 'betterstudio' ),
			'desc'          =>  __( 'Select separeator line icon of site.', 'better-studio' ),
		);
		$fields['pagination_type'] = array(
			'name'          =>  __( 'Pagination', 'better-studio' ),
			'id'            =>  'pagination_type',
			'std'           =>  'links',
			'type'          =>  'select',
			'desc'          =>  __( 'Select pagination type of site.', 'better-studio' ),
			'options'       =>  array(
				'links'         =>  __( 'Newer & Older Buttons', 'betterstudio' ),
				'numbered'      =>  __( 'Numbered Pagination Buttons', 'betterstudio' ),
			)
		);
		$fields['back_to_top'] = array(
			'name'          =>  __( 'Show Back To Top Button', 'better-studio' ),
			'id'            =>  'back_to_top',
			'std'           =>  'show',
			'type'          =>  'select',
			'desc'          =>  __( 'Select show or hide back to top button.', 'better-studio' ),
			'options'       =>  array(
				'show'          =>  __( 'Yes, Show.', 'betterstudio' ),
				'hide'          =>  __( 'No.', 'betterstudio' ),
			)
		);
		$fields['light_box_images'] = array(
			'name'          =>  __( 'Light Box For Images', 'better-studio' ),
			'id'            =>  'light_box_images',
			'std'           =>  'enable',
			'type'          =>  'select',
			'desc'          =>  __( 'Activate opening images full size in light box.', 'better-studio' ),
			'options'       =>  array(
				'enable'        =>  __( 'Enable', 'betterstudio' ),
				'disable'       =>  __( 'Disable', 'betterstudio' ),
			)
		);


		/**
		 * -> Homepage
		 **/
		$fields[] = array(
			'name'          =>  __( 'Homepage','better-studio' ),
			'type'          =>  'group',
			'state'         =>  'close',
		);
		$fields['home_layout'] = array(
			'name'          =>  __( 'Homepage Layout', 'better-studio' ),
			'id'            =>  'home_layout',
			'std'           =>  'default',
			'type'          =>  'image_select',
			'section_class' =>  'style-floated-left bordered',
			'desc'          =>  __( 'Override homepage layout.', 'better-studio' ),
			'options'       =>  patricia_layout_option_list( true )
		);
		$fields['home_listing'] = array(
			'name'          =>  __( 'Homepage Posts Listing', 'better-studio' ),
			'id'            =>  'home_listing',
			'std'           =>  'default',
			'type'          =>  'image_select',
			'section_class' =>  'style-floated-left bordered',
			'desc'          =>  __( 'Override homepage listing.', 'better-studio' ),
			'options'       =>  patricia_listing_option_list( true )
		);
		$fields[] = array(
			'name'          =>  __( 'Hide Posts in Homepage', 'better-studio' ),
			'id'            =>  'home_hide_posts',
			'desc'          =>  __( 'You can hide posts in homepage to show only slider and footer.', 'better-studio' ),
			'type'          =>  'select',
			'std'           =>  'no',
			'options'       =>  array(
				'no'            =>  __( 'No', 'better-studio' ),
				'yes'           =>  __( 'Yes, Hide them.', 'better-studio' ),
			)
		);
		$fields['home_cat_include'] = array(
			'name'          =>  __( 'Categories', 'better-studio' ),
			'id'            =>  'home_cat_include',
			'std'           =>  '',
			'desc'          =>  __( 'Show posts associated with certain categories in homepage.', 'better-studio' ),
			'type'          =>  'ajax_select',
			"callback"      =>  'BF_Ajax_Select_Callbacks::cats_callback' ,
			"get_name"      =>  'BF_Ajax_Select_Callbacks::cat_name',
			'placeholder'   =>  __("Search and find category...", 'better-studio'),
		);
		$fields['home_cat_exclude'] = array(
			'name'          =>  __( 'Exclude Categories', 'better-studio' ),
			'id'            =>  'home_cat_exclude',
			'std'           =>  '',
			'desc'          =>  __( 'Exclude showing posts of specific categories in home page.', 'better-studio' ),
			'type'          =>  'ajax_select',
			"callback"      =>  'BF_Ajax_Select_Callbacks::cats_callback' ,
			"get_name"      =>  'BF_Ajax_Select_Callbacks::cat_name',
			'placeholder'   =>  __( "Search and find category...", 'better-studio'),
		);
		$fields['home_tag_include'] = array(
			'name'          =>  __( 'Tags', 'better-studio' ),
			'id'            =>  'home_tag_include',
			'std'           =>  '',
			'desc'          =>  __( 'Show posts associated with certain tags in homepage.', 'better-studio' ),
			'type'          =>  'ajax_select',
			"callback"      =>  'BF_Ajax_Select_Callbacks::tags_callback' ,
			"get_name"      =>  'BF_Ajax_Select_Callbacks::tag_name',
			'placeholder'   =>  __("Search and find tag...", 'better-studio'),
		);
		$fields['home_custom_post_type'] = array(
			'name'          =>  __( 'Custom Post Type', 'better-studio' ),
			'id'            =>  'home_custom_post_type',
			'std'           =>  '',
			'desc'          =>  __( 'You can show custom post types in home page by adding them into this field. please don\'t forgot to add "post" to it if you changed this and need to default post type shown also.', 'better-studio' ),
			'type'          =>  'text',
			'input-desc'    =>  'Separate by ","',
		);

		$fields[] = array(
			'name'          =>  __( 'Number Of Post To Show', 'better-studio' ),
			'id'            =>  'home_posts_count',
			'desc'          =>  sprintf( __( 'Enter number of posts to show in homepage per page. <br>Default: %s', 'better-studio' ), get_option( 'posts_per_page' ) ),
			'type'          =>  'text',
			'std'           =>  '',
		);

		/**
		 * -> Posts
		 **/
		$fields[] = array(
			'name'          =>  __( 'Posts','better-studio' ),
			'type'          =>  'group',
			'state'         =>  'close',
		);
		$fields['post_layout'] = array(
			'name'          =>  __( 'Posts Page Layout', 'better-studio' ),
			'id'            =>  'post_layout',
			'std'           =>  'default',
			'type'          =>  'image_select',
			'section_class' =>  'style-floated-left bordered',
			'desc'          =>  __( 'Override posts page layout.', 'better-studio' ),
			'options'       =>  patricia_layout_option_list( true )
		);
		$fields[] = array(
			'name'          =>  __( 'Show Author Box', 'better-studio' ),
			'id'            =>  'post_author_box',
			'desc'          =>  __( 'Enabling this will be adds post author box to bottom of post content.', 'better-studio' ),
			'type'          =>  'select',
			'std'           =>  'show',
			'options'       =>  array(
				'show'          =>  __( 'Show', 'better-studio' ),
				'hide'          =>  __( 'Hide', 'better-studio' ),
			)
		);
		$fields[] = array(
			'name'          =>  __( 'Show Related Posts', 'better-studio' ),
			'id'            =>  'post_related',
			'desc'          =>  __( 'Enabling this will be adds related posts in in bottom of post content.', 'better-studio' ),
			'type'          =>  'select',
			'std'           =>  'show',
			'options'       =>  array(
				'show'          =>  __( 'Show', 'better-studio' ),
				'hide'          =>  __( 'Hide', 'better-studio' ),
			),
		);
		$fields[] = array(
			'name'          =>  __( 'Related Posts Algorithm', 'better-studio' ),
			'id'            =>  'post_related_type',
			'desc'          =>  __( 'Chose the algorithm of related posts.', 'better-studio' ),
			'type'          =>  'select',
			'options'       =>  array(
				'cat'           =>  __( 'by Category', 'better-studio' ),
				'tag'           =>  __( 'by Tag', 'better-studio' ),
				'author'        =>  __( 'by Author', 'better-studio' ),
				'cat-tag'       =>  __( 'by Category & Tag', 'better-studio' ),
				'cat-tag-author'=>  __( 'by Category ,Tag & Author', 'better-studio' ),
			),
			'std'           =>  'cat',
			'filter-field'  =>  'post_related',
			'filter-field-value'  =>  'show',
		);
		$fields[] = array(
			'name'          =>  __( 'Related Posts Count', 'better-studio' ),
			'id'            =>  'post_related_count',
			'desc'          =>  __( 'Enter related posts count.', 'better-studio' ),
			'type'          =>  'text',
			'std'           =>  3,
			'filter-field'  =>  'post_related',
			'filter-field-value'  =>  'show',
		);
		$fields[] = array(
			'name'          =>  __( 'Show Comments In Posts', 'better-studio' ),
			'id'            =>  'post_comments',
			'desc'          =>  __( 'Select to show or hide comments in bottom of post content.', 'better-studio' ),
			'type'          =>  'select',
			'std'           =>  'show',
			'options'       =>  array(
				'show'          =>  __( 'Show', 'better-studio' ),
				'hide'          =>  __( 'Hide', 'better-studio' ),
			),
		);
		$fields[] = array(
			'name'          =>  __( 'Comment Form Position', 'better-studio' ),
			'id'            =>  'post_comments_form_position',
			'std'           =>  'bottom',
			'type'          =>  'select',
			'desc'          =>  __( 'Chose comment form inputs position.', 'better-studio' ),
			'options'       =>  array(
				'top'   =>  __( 'Top of comments list.', 'better-studio' ),
				'bottom'=>  __( 'Bottom of comments list', 'better-studio' ),
				'both'  =>  __( 'Top & Bottom', 'better-studio' ),
			),
			'filter-field'  =>  'post_comments',
			'filter-field-value'  =>  'show',
		);
		$fields[] = array(
			'name'          =>  __( 'Remove URL Field from Comment Form', 'better-studio' ),
			'id'            =>  'post_comments_form_remove_url',
			'desc'          =>  __( 'With enabling this URL will removed from comments form.', 'better-studio' ),
			'type'          =>  'select',
			'std'           =>  'no',
			'options'       =>  array(
				'yes'          =>  __( 'Yes, Remove it.', 'better-studio' ),
				'no'            =>  __( 'No', 'better-studio' ),
			),
			'filter-field'  =>  'post_comments',
			'filter-field-value'  =>  'show',
		);


		/**
		 * -> Page
		 **/
		$fields[] = array(
			'name'          =>  __( 'Page','better-studio' ),
			'type'          =>  'group',
			'state'         =>  'close',
		);
		$fields['page_layout'] = array(
			'name'          =>  __( 'Static Pages Layout', 'better-studio' ),
			'id'            =>  'page_layout',
			'std'           =>  'default',
			'type'          =>  'image_select',
			'section_class' =>  'style-floated-left bordered',
			'desc'          =>  __( 'Override static pages layout.', 'better-studio' ),
			'options'       =>  patricia_layout_option_list( true )
		);
		$fields[] = array(
			'name'          =>  __( 'Show Comments In Static Pages', 'better-studio' ),
			'id'            =>  'page_comments',
			'desc'          =>  __( 'Select to show or hide comments in bottom of page content.', 'better-studio' ),
			'type'          =>  'select',
			'std'           =>  'show',
			'options'       =>  array(
				'show'          =>  __( 'Show', 'better-studio' ),
				'hide'          =>  __( 'Hide', 'better-studio' ),
			),
		);

		/**
		 * -> Categories Archive
		 **/
		$fields[] = array(
			'name'          =>  __( 'Categories Archive','better-studio' ),
			'type'          =>  'group',
			'state'         =>  'close',
		);
		$fields['cat_layout'] = array(
			'name'          =>  __( 'Categories Archive Page Layout', 'better-studio' ),
			'id'            =>  'cat_layout',
			'std'           =>  'default',
			'type'          =>  'image_select',
			'section_class' =>  'style-floated-left bordered',
			'desc'          =>  __( 'Override categories archive pages layout. <br>This option can be overridden on each category.', 'better-studio' ),
			'options'       =>  patricia_layout_option_list( true )
		);
		$fields['cat_listing'] = array(
			'name'          =>  __( 'Categories Archive Posts Listing', 'better-studio' ),
			'id'            =>  'cat_listing',
			'std'           =>  'default',
			'type'          =>  'image_select',
			'section_class' =>  'style-floated-left bordered',
			'desc'          =>  __( 'Override page listing for all categories. <br>This option can be overridden on each category.', 'better-studio' ),
			'options'       =>  patricia_listing_option_list( true )
		);
		$fields[] = array(
			'name'          =>  __( 'Number Of Post To Show', 'better-studio' ),
			'id'            =>  'cat_posts_count',
			'desc'          =>  sprintf( __( 'Enter number of posts to show in category archive pages. <br>Default: %s', 'better-studio' ), get_option( 'posts_per_page' ) ),
			'type'          =>  'text',
			'std'           =>  '',
		);


		/**
		 * -> Tags Archive
		 **/
		$fields[] = array(
			'name'          =>  __( 'Tags Archive','better-studio' ),
			'type'          =>  'group',
			'state'         =>  'close',
		);
		$fields['tag_layout'] = array(
			'name'          =>  __( 'Tags Archive Page Layout', 'better-studio' ),
			'id'            =>  'tag_layout',
			'std'           =>  'default',
			'type'          =>  'image_select',
			'section_class' =>  'style-floated-left bordered',
			'desc'          =>  __( 'Override tags archive pages layout. <br>This option can be overridden on each tag.', 'better-studio' ),
			'options'       =>  patricia_layout_option_list( true )
		);
		$fields['tag_listing'] = array(
			'name'          =>  __( 'Tags Archive Posts Listing', 'better-studio' ),
			'id'            =>  'tag_listing',
			'std'           =>  'default',
			'type'          =>  'image_select',
			'section_class' =>  'style-floated-left bordered',
			'desc'          =>  __( 'Override page listing for all tags. <br>This option can be overridden on each tag.', 'better-studio' ),
			'options'       =>  patricia_listing_option_list( true )
		);
		$fields[] = array(
			'name'          =>  __( 'Number Of Post To Show', 'better-studio' ),
			'id'            =>  'tag_posts_count',
			'desc'          =>  sprintf( __( 'Enter number of posts to show in category archive pages. <br>Default: %s', 'better-studio' ), get_option( 'posts_per_page' ) ),
			'type'          =>  'text',
			'std'           =>  '',
		);


		/**
		 * -> Authors Archive
		 **/
		$fields[] = array(
			'name'          =>  __( 'Authors Archive','better-studio' ),
			'type'          =>  'group',
			'state'         =>  'close',
		);
		$fields['author_layout'] = array(
			'name'          =>  __( 'Authors Profile Page Layout', 'better-studio' ),
			'id'            =>  'author_layout',
			'std'           =>  'default',
			'type'          =>  'image_select',
			'section_class' =>  'style-floated-left bordered',
			'desc'          =>  __( 'Override authors profile pages layout. <br>This option can be overridden on each author.', 'better-studio' ),
			'options'       =>  patricia_layout_option_list( true )
		);
		$fields['author_listing'] = array(
			'name'          =>  __( 'Authors Profile Posts Listing', 'better-studio' ),
			'id'            =>  'author_listing',
			'std'           =>  'default',
			'type'          =>  'image_select',
			'section_class' =>  'style-floated-left bordered',
			'desc'          =>  __( 'Override page listing for all authors. <br>This option can be overridden on each author.', 'better-studio' ),
			'options'       =>  patricia_listing_option_list( true )
		);
		$fields[] = array(
			'name'          =>  __( 'Number Of Posts To Show', 'better-studio' ),
			'id'            =>  'author_posts_count',
			'desc'          =>  sprintf( __( 'Leave this empty for default. <br>Default: %s', 'better-studio' ), get_option( 'posts_per_page' ) ),
			'type'          =>  'text',
			'std'           =>  '',
		);

		/**
		 * -> Search Results Archive
		 **/
		$fields[] = array(
			'name'          =>  __( 'Search Results Archive','better-studio' ),
			'type'          =>  'group',
			'state'         =>  'close',
		);
		$fields['search_layout'] = array(
			'name'          =>  __( 'Search Page Layout', 'better-studio' ),
			'id'            =>  'search_layout',
			'std'           =>  'default',
			'type'          =>  'image_select',
			'section_class' =>  'style-floated-left bordered',
			'desc'          =>  __( 'Override search result pages layout.', 'better-studio' ),
			'options'       =>  patricia_layout_option_list( true )
		);
		$fields['search_listing'] = array(
			'name'          =>  __( 'Search Result Posts Listing', 'better-studio' ),
			'id'            =>  'search_listing',
			'std'           =>  'default',
			'type'          =>  'image_select',
			'section_class' =>  'style-floated-left bordered',
			'desc'          =>  __( 'Override search result posts listing.', 'better-studio' ),
			'options'       =>  patricia_listing_option_list( true )
		);
		$fields['search_separator_icon'] = array(
			'id'            =>  'search_separator_icon',
			'name'          =>  __( 'Search Page Posts Separator Icon', 'better-studio' ),
			'desc'          =>  __( 'Select posts separator icon.', 'better-studio' ),
			'type'          =>  'icon_select',
			'options'       =>  array( 'fontawesome' ),
			'std'           =>  'fa-search',
			'default_text'  =>  __( 'Chose an Icon', 'betterstudio' ),
		);
		$fields['search_menu'] = array(
			'name'          =>  __( 'Search Page Navigation Menu', 'better-studio' ),
			'id'            =>  'search_menu',
			'desc'          =>  __( 'Select which menu displays on search results page.', 'better-studio' ),
			'type'          =>  'select',
			'std'           =>  'default',
			'options'       =>  $menus
		);
		$fields['search_menu'] = array(
			'name'          =>  __( 'Result Content Type', 'better-studio' ),
			'id'            =>  'search_result_content',
			'std'           =>  'post',
			'type'          =>  'select',
			'desc'          =>  __( 'Select the type of content to display in search results.', 'better-studio' ),
			'options'       => array(
				'post'  =>  __( 'Only Posts', 'better-studio' ),
				'page'  =>  __( 'Only Pages', 'better-studio' ),
				'both'  =>  __( 'Posts and Pages', 'better-studio' ),
			)
		);
		$fields['search_posts_count'] = array(
			'name'          =>  __( 'Number Of Post To Show', 'better-studio' ),
			'id'            =>  'search_posts_count',
			'desc'          =>  sprintf( __( 'Leave this empty for default. <br>Default: %s', 'better-studio' ), get_option( 'posts_per_page' ) ),
			'type'          =>  'text',
			'std'           =>  '',
		);


		/**
		 * -> 404 Page
		 **/
		$fields[] = array(
			'name'          =>  __( '404 Page','better-studio' ),
			'type'          =>  'group',
			'state'         =>  'close',
		);
		$fields['archive_404_menu'] = array(
			'name'          =>  __( '404 Page Navigation Menu', 'better-studio' ),
			'id'            =>  'archive_404_menu',
			'desc'          =>  __( 'Select which menu displays on 404 page.', 'better-studio' ),
			'type'          =>  'select',
			'std'           =>  'default',
			'options'       =>  $menus
		);


		/**
		 * => Header Options
		 */
		$fields[] = array(
			'name'          =>  __( 'Header', 'better-studio' ),
			'id'            =>  'header_settings',
			'type'          =>  'tab',
			'icon'          =>  'bsai-header'
		);

		$fields[] = array(
			'name'          =>  __( 'Header', 'better-studio' ),
			'type'          =>  'group',
			'state'         => 'open',
		);
		$fields['header_style'] = array(
			'name'          =>   __( 'Header Style', 'better-studio' ),
			'id'            =>  'header_style',
			'desc'          =>   __( 'Select header style.', 'better-studio' ),
			'std'           =>  'style-2',
			'type'          =>  'image_select',
			'section_class' =>  'style-floated-left bordered',
			'options'       =>  patricia_header_style_option_list(),
		);
		$fields['logo_image'] = array(
			'name'          =>  __( 'Logo', 'better-studio' ),
			'id'            =>  'logo_image',
			'desc'          =>  __( 'By default, a text-based logo is created using your site title. But you can also upload an image-based logo here.', 'better-studio' ),
			'std'           =>  '',
			'type'          =>  'media_image',
			'media_title'   =>  __( 'Select or Upload Logo', 'better-studio'),
			'media_button'  =>  __( 'Select Image', 'better-studio'),
			'upload_label'  =>  __( 'Upload Logo', 'better-studio'),
			'remove_label'  =>  __( 'Remove', 'better-studio'),
		);
		$fields['logo_image_retina'] = array(
			'name'          =>  __( 'Retina Logo (2x)', 'better-studio' ),
			'id'            =>  'logo_image_retina',
			'desc'          =>  __( 'If you want to upload a Retina Image, It\'s Image Size should be exactly double in compare with your normal Logo. It requires WP Retina 2x plugin.', 'better-studio' ),
			'std'           =>  '',
			'type'          =>  'media_image',
			'media_title'   =>  __( 'Select or Upload Retina Logo', 'better-studio'),
			'media_button'  =>  __( 'Select @2x Image', 'better-studio'),
			'upload_label'  =>  __( 'Upload @2x Logo', 'better-studio'),
			'remove_label'  =>  __( 'Remove', 'better-studio'),
		);

		$fields['menu_sticky'] = array(
			'name'          =>   __( 'Main Menu Sticky', 'better-studio' ),
			'id'            =>  'menu_sticky',
			'desc'          =>   __( 'Enable or disable sticky effect for main menu.', 'better-studio' ),
			'std'           =>  'smart',
			'type'          =>  'select',
			'options'       => array(
				'smart'         =>  __( 'Smart Sticky', 'better-studio' ),
				'sticky'        =>  __( 'Simple Sticky', 'better-studio' ),
				'no-sticky'     =>  __( 'No Sticky', 'better-studio' ),
			),
		);
		$fields['topbar_show_search_box'] = array(
			'name'          =>   __( 'Show Search Box In Topbar', 'better-studio' ),
			'id'            =>  'topbar_show_search_box',
			'desc'          =>   __( 'Chose to show or hide search form in topbar.', 'better-studio' ),
			'std'           =>  'show',
			'type'          =>  'select',
			'options'       => array(
				'show'          =>  __( 'Show', 'better-studio' ),
				'hide'          =>  __( 'Hide', 'better-studio' ),
			),
		);
		$fields['topbar_show_social_icons'] = array(
			'name'          =>   __( 'Show Social Icons In Topbar', 'better-studio' ),
			'id'            =>  'topbar_show_social_icons',
			'desc'          =>   __( 'Chose to show or hide social icons in header.', 'better-studio' ),
			'std'           =>  'show',
			'type'          =>  'select',
			'options'       => array(
				'show'          =>  __( 'Show', 'better-studio' ),
				'hide'          =>  __( 'Hide', 'better-studio' ),
			),
		);
		if( class_exists( 'Better_Social_Counter' ) && class_exists( 'Better_Social_Counter_Data_Manager' ) ){
			$fields[] = array(
				'name'              =>  __( 'Sort and Active Sites', 'better-studio' ),
				'id'                =>  'topbar_socials',
				'desc'              =>
					sprintf( __( 'Select & sort sites you will to show them in topbar. <br><br>
For activating site you should enter your information in <a href="%s" target="_blank">Better Social Counter</a> Panel.
', 'better-studio' ), get_admin_url( null, 'admin.php?page=better-studio/better-social-counter' ) )
			,
				'type'              =>  'sorter_checkbox',
				'options'           =>  Better_Social_Counter_Data_Manager::self()->get_deferred_widget_options_list(),
				'section_class'     =>  'better-social-counter-sorter',
				'std'               =>  array(
					'instagram'         =>  1,
					'dribbble'          =>  1,
					'pinterest'         =>  1,
					'envato'            =>  1,
					'github'            =>  1,
					'vimeo'             =>  1,
				)
			);
		}else{
			$fields[] = array(
				'name'              =>  __( 'Social Icons Instructions', 'better-studio' ),
				'id'                =>  'social-icons-help',
				'type'              =>  'info',
				'std'               =>  __('<p>For adding social icons in top bar you should first install and active <strong>Better Social Counter</strong> plugin.</p>', 'better-studio' ),
				'state'             =>  'open',
				'info-type'         =>  'help',
				'section_class'     =>  'widefat',
			);
		}



		/**
		 * -> Responsive Header
		 */
		$fields[] = array(
			'name'          =>  __( 'Responsive Header', 'better-studio' ),
			'type'          =>  'group',
			'state'         =>  'open',
		);
		$fields['resp_logo_image'] = array(
			'name'          =>  __( 'Responsive Header Logo', 'better-studio' ),
			'id'            =>  'resp_logo_image',
			'desc'          =>  __( 'By default, a text-based logo is created using your site title. But you can also upload an image-based logo here.', 'better-studio' ),
			'std'           =>  '',
			'type'          =>  'media_image',
			'media_title'   =>  __( 'Select or Upload Logo', 'better-studio'),
			'media_button'  =>  __( 'Select Image', 'better-studio'),
			'upload_label'  =>  __( 'Upload Logo', 'better-studio'),
			'remove_label'  =>  __( 'Remove', 'better-studio'),
		);
		$fields['resp_logo_image_retina'] = array(
			'name'          =>  __( 'Responsive Header Retina Logo(2x)', 'better-studio' ),
			'id'            =>  'resp_logo_image_retina',
			'desc'          =>  __( 'If you want to upload a Retina Image, It\'s Image Size should be exactly double in compare with your normal Logo. It requires WP Retina 2x plugin.', 'better-studio' ),
			'std'           =>  '',
			'type'          =>  'media_image',
			'media_title'   =>  __( 'Select or Upload Retina Logo', 'better-studio'),
			'media_button'  =>  __( 'Select @2x Image', 'better-studio'),
			'upload_label'  =>  __( 'Upload @2x Logo', 'better-studio'),
			'remove_label'  =>  __( 'Remove', 'better-studio'),
		);


		/**
		 * -> Header Padding
		 */
		$fields[] = array(
			'name'          =>  __( 'Header Padding', 'better-studio' ),
			'type'          => 'group',
			'state'         => 'close',
		);
		$fields['header_top_padding'] = array(
			'name'          =>  __( 'Header Top Padding', 'better-studio' ),
			'id'            =>  'header_top_padding',
			'suffix'        =>  __( 'Pixel', 'better-studio' ),
			'desc'          =>  __( 'In pixels without px, ex: 20.', 'better-studio' ),
			'type'          =>  'text',
			'std'           =>  '',
			'css-echo-default'  => false,
			'ltr'           =>  true,
			'css'           =>  array(
				array(
					'selector'  => array(
						'.header.header-style-1 .header-inner',
						'.header.header-style-2 .header-inner',
					),
					'prop'      => array( 'padding-top' => '%%value%%px'),
				)
			),
		);
		$fields['header_bottom_padding'] = array(
			'name'          =>  __( 'Header Bottom Padding', 'better-studio' ),
			'id'            =>  'header_bottom_padding',
			'suffix'        =>  __( 'Pixel', 'better-studio' ),
			'desc'          =>  __( 'In pixels without ex: 20.', 'better-studio' ),
			'type'          =>  'text',
			'std'           =>  '',
			'css-echo-default'  => false,
			'ltr'           =>  true,
			'css'           =>  array(
				array(
					'selector'  => array(
						'.header.header-style-1 .header-inner',
						'.header.header-style-2 .header-inner',
					),
					'prop'      => array( 'padding-bottom' => '%%value%%px' ),
				)
			),
		);

		/**
		 * => Slider
		 */
		$fields[] = array(
			'name'          =>  __( 'Slider', 'better-studio' ),
			'id'            =>  'slider_settings',
			'type'          =>  'tab',
			'icon'          =>  'bsai-slider'
		);
		$fields[] = array(
			'name'          =>  __( 'Home Page Slider', 'better-studio' ),
			'desc'          =>  __( 'Select the type of slider for display.', 'better-studio' ),
			'id'            =>  'home_slider',
			'std'           =>  'better' ,
			'type'          =>  'select',
			'options'       => array(
				'no'            =>  __( 'No Slider', 'better-studio' ),
				'better'        =>  __( 'BetterSlider', 'better-studio' ),
			)
		);
		$fields[] = array(
			'name'          =>  __( 'BetterSlider Settings', 'better-studio' ),
			'type'          => 'group',
			'state'         => 'open',
		);
		$fields['better_slider_style'] = array(
			'name'          =>   __( 'Slider Style', 'better-studio' ),
			'id'            =>  'better_slider_style',
			'desc'          =>   __( 'Select slider style.', 'better-studio' ),
			'std'           =>  'style-2',
			'type'          =>  'image_select',
			'section_class' =>  'style-floated-left bordered',
			'options'       => array(
				'style-1'  =>  array(
					'img'   =>  bf_get_theme_uri( 'includes/admin-assets/images/slider-style-1.png' ),
					'label' =>  __( 'Style 1', 'better-studio' ),
				),
				'style-2'  =>  array(
					'img'   =>  bf_get_theme_uri( 'includes/admin-assets/images/slider-style-2.png' ),
					'label' =>  __( 'Style 2', 'better-studio' ),
				),
				'style-3'  =>  array(
					'img'   =>  bf_get_theme_uri( 'includes/admin-assets/images/slider-style-3.png' ),
					'label' =>  __( 'Style 3', 'better-studio' ),
				),

			),
		);
		$fields[] = array(
			'name'          =>  __( 'Posts Count', 'better-studio' ),
			'id'            =>  'better_slider_posts_count',
			'type'          =>  'text',
			'std'           =>  6,
			'desc'          =>  __( 'Enter number of posts to show in homepage.', 'better-studio' ),
		);
		$fields[] = array(
			'name'          =>  __( 'Categories', 'better-studio' ),
			'id'            =>  'better_slider_inc_cats',
			'type'          =>  'ajax_select',
			'desc'          =>  __( 'Show posts associated with certain categories in slider.', 'better-studio' ),
			'placeholder'   =>  __("Search and find category...", 'better-studio'),
			"callback"      => 'BF_Ajax_Select_Callbacks::cats_callback',
			"get_name"      => 'BF_Ajax_Select_Callbacks::cat_name',
		);
		$fields[] = array(
			'name'          =>  __( 'Exclude Categories', 'better-studio' ),
			'id'            =>  'better_slider_exc_cats',
			'type'          =>  'ajax_select',
			'desc'          =>  __( 'Exclude posts from specific categories in home slider.', 'better-studio' ),
			'placeholder'   =>  __( "Search and find category...", 'better-studio'),
			"callback"      =>  'BF_Ajax_Select_Callbacks::cats_callback',
			"get_name"      =>  'BF_Ajax_Select_Callbacks::cat_name',
		);
		$fields[] = array(
			'name'          =>  __( 'Tags', 'better-studio' ),
			'id'            =>  'better_slider_inc_tags',
			'type'          =>  'ajax_select',
			'desc'          =>  __( 'Show posts associated with certain tags in slider.', 'better-studio' ),
			'placeholder'   =>  __("Search and find tag...", 'better-studio'),
			"callback"      => 'BF_Ajax_Select_Callbacks::tags_callback',
			"get_name"      => 'BF_Ajax_Select_Callbacks::tag_name',
		);
		$fields[] = array(
			'name'          =>  __( 'Slider Custom Post Type', 'better-studio' ),
			'desc'          =>  __( 'Enter your custom post types here. Separate with ",".', 'better-studio' ),
			'id'            =>  'better_slider_post_type',
			'type'          =>  'text',
			'std'           =>  '',
		);
//		$fields[] = array(
//			'name'          =>  __( 'Animation Type', 'better-studio' ),
//			'desc'          =>  __( 'Select your animation type, "fade" or "slide".', 'better-studio' ),
//			'id'            =>  'better_slider_animation',
//			'std'           =>  'slide' ,
//			'type'          =>  'select',
//			'options'       => array(
//				'fade'          => __( 'Fade', 'better-studio' ),
//				'slide'         => __( 'Slide', 'better-studio' ),
//			)
//		);
		$fields[] = array(
			'name'          =>  __( 'Slide Show Speed', 'better-studio' ),
			'desc'          =>  __( 'Set the speed of the slideshow cycling, in milliseconds.', 'better-studio' ),
			'id'            =>  'better_slider_slideshowSpeed',
			'std'           =>  '2750' ,
			'type'          =>  'text',
			'suffix'        =>  'ms',
			'ltr'           =>  true,
		);
		$fields[] = array(
			'name'          =>  __( 'Animation Speed', 'better-studio' ),
			'desc'          =>  __( 'Set the speed of animations, in milliseconds.', 'better-studio' ),
			'id'            =>  'better_slider_animationSpeed',
			'std'           =>  '600' ,
			'type'          =>  'text',
			'suffix'        =>  'ms',
			'ltr'           =>  true,
		);

		/**
		 * => Featured Boxes
		 */
		$fields[] = array(
			'name'          =>  __( 'Featured Boxes', 'better-studio' ),
			'id'            =>  'featured_settings',
			'type'          =>  'tab',
			'icon'          =>  'bsai-slider-new'
		);

		$fields[] = array(
			'name'          =>  __( 'Featured Box 1', 'better-studio' ),
			'type'          => 'group',
			'state'         => 'open',
		);
		$fields[] = array(
			'name'          =>  __( 'Heading', 'better-studio' ),
			'id'            =>  'featured_1_heading',
			'std'           =>  'Instagram' ,
			'type'          =>  'text',
		);
		$fields[] = array(
			'name'          =>  __( 'Link', 'better-studio' ),
			'id'            =>  'featured_1_link',
			'std'           =>  '#' ,
			'type'          =>  'text',
		);
		$fields['featured_1_image'] = array(
			'name'          =>  __( 'Image', 'better-studio' ),
			'id'            =>  'featured_1_image',
			'type'          =>  'background_image',
			'std'           =>  '',
			'upload_label'  =>  __( 'Upload Image', 'better-studio' ),
			'desc'          =>  __( 'Upload box background image.', 'better-studio' ),
			'css'           =>  array(
				array(
					'selector'  => '#featured-box-1 .featured-box-inner',
					'prop'      => array( 'background-image' ),
					'type'      => 'background-image',
				)
			)
		);
		$fields['featured_1_bg_color'] = array(
			'name'          =>  __( 'Background Color', 'better-studio' ),
			'id'            =>  'featured_1_bg_color',
			'type'          =>  'color',
			'std'           =>  '',
			'desc'          =>  __( 'you can change box background color with this option.', 'better-studio' ),
			'css'           =>  array(
				array(
					'selector'  => array(
						'.featured-boxes #featured-box-1 .featured-box-inner',
					),
					'prop'      => array(
						'background-color' => '%%value%%'
					)
				),
			)
		);


		$fields[] = array(
			'name'          =>  __( 'Featured Box 2', 'better-studio' ),
			'type'          => 'group',
			'state'         => 'open',
		);
		$fields[] = array(
			'name'          =>  __( 'Heading', 'better-studio' ),
			'id'            =>  'featured_2_heading',
			'std'           =>  'Contact Me' ,
			'type'          =>  'text',
		);
		$fields[] = array(
			'name'          =>  __( 'Link', 'better-studio' ),
			'id'            =>  'featured_2_link',
			'std'           =>  '#' ,
			'type'          =>  'text',
		);
		$fields['featured_2_image'] = array(
			'name'          =>  __( 'Image', 'better-studio' ),
			'id'            =>  'featured_2_image',
			'type'          =>  'background_image',
			'std'           =>  '',
			'upload_label'  =>  __( 'Upload Image', 'better-studio' ),
			'desc'          =>  __( 'Upload box background image.', 'better-studio' ),
			'css'           =>  array(
				array(
					'selector'  => '#featured-box-2 .featured-box-inner',
					'prop'      => array( 'background-image' ),
					'type'      => 'background-image',
				)
			)
		);
		$fields['featured_2_bg_color'] = array(
			'name'          =>  __( 'Background Color', 'better-studio' ),
			'id'            =>  'featured_2_bg_color',
			'type'          =>  'color',
			'std'           =>  '',
			'desc'          =>  __( 'you can change box background color with this option.', 'better-studio' ),
			'css'           =>  array(
				array(
					'selector'  => array(
						'.featured-boxes #featured-box-2 .featured-box-inner',
					),
					'prop'      => array(
						'background-color' => '%%value%%'
					)
				),
			)
		);

		$fields[] = array(
			'name'          =>  __( 'Featured Box 3', 'better-studio' ),
			'type'          => 'group',
			'state'         => 'open',
		);
		$fields[] = array(
			'name'          =>  __( 'Heading', 'better-studio' ),
			'id'            =>  'featured_3_heading',
			'std'           =>  'About Me' ,
			'type'          =>  'text',
		);
		$fields[] = array(
			'name'          =>  __( 'Link', 'better-studio' ),
			'id'            =>  'featured_3_link',
			'std'           =>  '#' ,
			'type'          =>  'text',
		);
		$fields['featured_3_image'] = array(
			'name'          =>  __( 'Image', 'better-studio' ),
			'id'            =>  'featured_3_image',
			'type'          =>  'background_image',
			'std'           =>  '',
			'upload_label'  =>  __( 'Upload Image', 'better-studio' ),
			'desc'          =>  __( 'Upload box background image.', 'better-studio' ),
			'css'           =>  array(
				array(
					'selector'  => '#featured-box-3 .featured-box-inner',
					'prop'      => array( 'background-image' ),
					'type'      => 'background-image',
				)
			)
		);
		$fields['featured_3_bg_color'] = array(
			'name'          =>  __( 'Background Color', 'better-studio' ),
			'id'            =>  'featured_3_bg_color',
			'type'          =>  'color',
			'std'           =>  '',
			'desc'          =>  __( 'you can change box background color with this option.', 'better-studio' ),
			'css'           =>  array(
				array(
					'selector'  => array(
						'.featured-boxes #featured-box-3 .featured-box-inner',
					),
					'prop'      => array(
						'background-color' => '%%value%%'
					)
				),
			)
		);

		$fields[] = array(
			'name'          =>  __( 'Featured Box 4', 'better-studio' ),
			'type'          => 'group',
			'state'         => 'open',
		);
		$fields[] = array(
			'name'          =>  __( 'Heading', 'better-studio' ),
			'id'            =>  'featured_4_heading',
			'std'           =>  'Lifestyle' ,
			'type'          =>  'text',
		);
		$fields[] = array(
			'name'          =>  __( 'Link', 'better-studio' ),
			'id'            =>  'featured_4_link',
			'std'           =>  '#' ,
			'type'          =>  'text',
		);
		$fields['featured_4_image'] = array(
			'name'          =>  __( 'Image', 'better-studio' ),
			'id'            =>  'featured_4_image',
			'type'          =>  'background_image',
			'std'           =>  '',
			'upload_label'  =>  __( 'Upload Image', 'better-studio' ),
			'desc'          =>  __( 'Upload box background image.', 'better-studio' ),
			'css'           =>  array(
				array(
					'selector'  => '#featured-box-4 .featured-box-inner',
					'prop'      => array( 'background-image' ),
					'type'      => 'background-image',
				)
			)
		);
		$fields['featured_4_bg_color'] = array(
			'name'          =>  __( 'Background Color', 'better-studio' ),
			'id'            =>  'featured_4_bg_color',
			'type'          =>  'color',
			'std'           =>  '',
			'desc'          =>  __( 'you can change box background color with this option.', 'better-studio' ),
			'css'           =>  array(
				array(
					'selector'  => array(
						'.featured-boxes #featured-box-4 .featured-box-inner',
					),
					'prop'      => array(
						'background-color' => '%%value%%'
					)
				),
			)
		);


		/**
		 * =>Share Box
		 */
		$fields[] = array(
			'name'          =>  __( 'Share Box','better-studio' ),
			'type'          =>  'tab',
			'icon'          =>  'bsai-share-alt',
			'id'            =>  'share-box-options',
		);
		$fields[] = array(
			'name'          =>  __( 'Show Share Box In Single', 'better-studio' ),
			'desc'          =>  __( 'Enabling this will adds share links in posts single page. You can change design and social sites will following options.', 'better-studio' ),
			'id'            =>  'social_share_single',
			'type'          =>  'select',
			'std'           =>  'show',
			'options'       =>  array(
				'show'          =>  __( 'Show', 'better-studio' ),
				'hide'          =>  __( 'Hide', 'better-studio' ),
			),
		);
		$fields[] = array(
			'name'          =>  __( 'Show Share Box In Pages', 'better-studio' ),
			'desc'          =>  __( 'Enabling this will adds share links in pages. You can change design and social sites will following options.', 'better-studio' ),
			'id'            =>  'social_share_page',
			'type'          =>  'select',
			'std'           =>  'hide',
			'options'       =>  array(
				'show'          =>  __( 'Show', 'better-studio' ),
				'hide'          =>  __( 'Hide', 'better-studio' ),
			),
		);
		$fields[] = array(
			'name'          =>  __( 'Drag and Drop To Sort The Items', 'better-studio' ),
			'id'            =>  'social_share_sites',
			'desc'          =>  __( 'Select active social share links and sort them.', 'better-studio' ),
			'type'          =>  'sorter_checkbox',
			'std'           =>  array(
				'facebook'      =>  true,
				'twitter'       =>  true,
				'google_plus'   =>  true,
				'pinterest'     =>  false,
				'linkedin'      =>  false,
				'tumblr'        =>  false,
				'email'         =>  true,
			),
			'options'       =>  array(
				'facebook'      =>  array(
					'label'         =>  '<i class="fa fa-facebook"></i> ' . __( 'Facebook', 'better-studio' ),
					'css-class'     =>  'active-item'
				),
				'twitter'       =>  array(
					'label'         =>  '<i class="fa fa-twitter"></i> ' . __( 'Twitter', 'better-studio' ),
					'css-class'     =>  'active-item'
				),
				'google_plus'   =>  array(
					'label'         =>  '<i class="fa fa-google-plus"></i> ' . __( 'Google+', 'better-studio' ),
					'css-class'     =>  'active-item'
				),
				'pinterest'     =>  array(
					'label'         =>  '<i class="fa fa-pinterest"></i> ' . __( 'Pinterest', 'better-studio' ),
					'css-class'     =>  'active-item'
				),
				'linkedin'      =>  array(
					'label'         =>  '<i class="fa fa-linkedin"></i> ' . __( 'Linkedin', 'better-studio' ),
					'css-class'     =>  'active-item'
				),
				'tumblr'        =>  array(
					'label'         =>  '<i class="fa fa-tumblr"></i> ' . __( 'Tumblr', 'better-studio' ),
					'css-class'     =>  'active-item'
				),
				'email'         =>  array(
					'label'         =>  '<i class="fa fa-envelope "></i> ' . __( 'Email', 'better-studio' ),
					'css-class'     =>  'active-item'
				),
			),
			'section_class'     =>  'bs-theme-social-share-sorter',
		);


		/**
		 * => Footer Options
		 */
		$fields[] = array(
			'name'          =>  __( 'Footer', 'better-studio' ),
			'id'            =>  'footer_settings',
			'type'          =>  'tab',
			'icon'          =>  'bsai-footer'
		);

		$fields[] = array(
			'name'          =>  __( 'Footer Copyright Text', 'better-studio' ),
			'desc'          =>  __( 'Enter the copy right text of footer.<br>
You can use following pattern to make replace them with real data:<br><br>
<strong>%%year%%</strong>: Will replcae with current year, ex: 2015<br>
<strong>%%date%%</strong>: Will replcae with current year, ex: 2015<br>
<strong>%%sitename%%</strong>: Will replace with site title.<br>
<strong>%%title%%</strong>: Will replace with site title.<br>
<strong>%%siteurl%%</strong>: Will replace with site homepage url.', 'better-studio' ),
			'id'            =>  'footer_copy',
			'std'           =>  '© %%year%% - %%sitename%%. All Rights Reserved.' ,
			'type'          =>  'textarea',
		);
		$fields[] = array(
			'name'          =>  __( 'Show Footer Widgets', 'better-studio' ),
			'desc'          =>  __( 'Chose to show or hide widgets in footer.', 'better-studio' ),
			'id'            =>  'footer_widgets',
			'std'           =>  'show' ,
			'type'          =>  'select',
			'options'       => array(
				'show'          =>  __( 'Show', 'better-studio' ),
				'hide'          =>  __( 'Hide', 'better-studio' ),
			)
		);
		$fields[] = array(
			'name'          =>  __( 'Footer Instagram Feeds Username', 'better-studio' ),
			'desc'          =>  __( 'Enter your instagram user name if you will to show instagram feed in footer.', 'better-studio' ),
			'id'            =>  'footer_instagram',
			'std'           =>  'passionpassport' ,
			'type'          =>  'text',
		);
		$fields[] = array(
			'name'          =>  __( 'Show Footer Social Icons', 'better-studio' ),
			'desc'          =>  __( 'Chose to show or hide social icons in footer..', 'better-studio' ),
			'id'            =>  'footer_social',
			'std'           =>  'show' ,
			'type'          =>  'select',
			'options'       => array(
				'show'          =>  __( 'Show', 'better-studio' ),
				'hide'          =>  __( 'Hide', 'better-studio' ),
			)
		);

		if( class_exists( 'Better_Social_Counter' ) && class_exists( 'Better_Social_Counter_Data_Manager' ) ){
			$fields[] = array(
				'name'              =>  __( 'Sort and Active Sites', 'better-studio' ),
				'id'                =>  'footer_social_sites',
				'desc'              =>
					sprintf( __( 'Select sites you will to show them in footer and sort them. <br><br>
For activating sites you should enter your information in <a href="%s" target="_blank">Better Social Counter</a> Panel.
', 'better-studio' ), get_admin_url( null, 'admin.php?page=better-studio/better-social-counter' ) )
					,
				'type'              =>  'sorter_checkbox',
				'options'           =>  Better_Social_Counter_Data_Manager::self()->get_deferred_widget_options_list(),
				'section_class'     =>  'better-social-counter-sorter',
				'std'               =>  array(
					'instagram'         =>  1,
					'dribbble'          =>  1,
					'pinterest'         =>  1,
					'envato'            =>  1,
					'github'            =>  1,
					'vimeo'             =>  1,
				),

			);
		}else{
			$fields[] = array(
				'name'              =>  __( 'Social Icons Instructions', 'better-studio' ),
				'id'                =>  'footer-social-icons-help',
				'type'              =>  'info',
				'std'               =>  __('<p>For adding social icons in top bar you should first install and active <strong>Better Social Counter</strong> plugin.</p>', 'better-studio' ),
				'state'             =>  'open',
				'info-type'         =>  'help',
				'section_class'     =>  'widefat',
			);
		}


		/**
		 * => Color Options
		 */
		$fields[] = array(
			'name'          =>  __( 'Color & Style', 'better-studio' ),
			'id'            =>  'color_settings',
			'type'          =>  'tab',
			'icon'          =>  'bsai-paint'
		);
		$fields[] = array(
			'name'          =>  __( 'Reset Color Settings', 'better-studio' ),
			'id'            =>  'reset_color_settings',
			'type'          =>  'ajax_action',
			'button-name'   =>  '<i class="fa fa-refresh"></i> ' . __( 'Reset Color Settings', 'better-studio' ),
			'callback'      =>  'Patricia::reset_color_options',
			'confirm'       =>  __( 'Are you sure for resetting all color settings?', 'better-studio' ),
			'desc'          =>  __( 'This allows you to reset all color settings to default.', 'better-studio' )
		);
		$fields[] = array(
			'name'          =>  __( 'General Colors', 'better-studio' ),
			'type'          =>  'group',
			'state'         =>  'open',
		);
		$fields['theme_color'] = array(
			'name'          =>   __( 'Theme Highlight Color', 'better-studio' ),
			'id'            =>  'theme_color',
			'type'          =>  'color',
			'std'           =>  '#A95437',
			'desc'          =>  __( 'It is the contrast color for the theme. It will be used for all links, menu, category overlays, main page and many contrasting elements.', 'better-studio' ),
			'css'           =>  array(
				array(
					'selector'  => array(
						// Global Themes
						'.main-bg-color',
						'.btn',
						'button',
						'html input[type="button"]',
						'input[type="reset"]',
						'input[type="submit"]',
						'input[type="button"]',
						'.btn:focus',
						'.btn:hover',
						'button:focus',
						'button:hover',
						'html input[type="button"]:focus',
						'html input[type="button"]:hover',
						'input[type="reset"]:focus',
						'input[type="reset"]:hover',
						'input[type="submit"]:focus',
						'input[type="submit"]:hover',
						'input[type="button"]:focus',
						'input[type="button"]:hover',
						'.widget.widget_tag_cloud .tagcloud a:hover',
						'.pagination.bs-numbered-pagination > span',
						'.pagination.bs-numbered-pagination .wp-pagenavi a:hover',
						'.pagination.bs-numbered-pagination .page-numbers:hover',
						'.pagination.bs-numbered-pagination .current',
						'.comment-list .comment-footer .comment-reply-link:hover',
						'span.dropcap.square',
						'span.dropcap.circle',
						'.bs-tab-shortcode .nav-tabs>li>a:focus',
						'.bs-tab-shortcode .nav-tabs>li>a:hover',
						'.bs-tab-shortcode .nav-tabs>li.active>a',

						// This Theme
						'.better-control-nav li a.better-active',
						'.better-control-nav li:hover a',
						'.main-menu.menu > li:hover > a:before',
						'.main-menu.menu > li.current-menu-parent > a:before',
						'.main-menu.menu > li.current-menu-item > a:before',
						'.main-slider .better-control-nav li a.better-active',
						'.main-slider .better-control-nav li:hover a',
						'.site-footer.color-scheme-dark .footer-widgets .widget.widget_tag_cloud .tagcloud a:hover',
						'.site-footer.color-scheme-dark .footer-widgets .widget.widget_nav_menu ul.menu li a:hover',
						'.single-post-content > .post-tags a:hover',
					),
					'prop'      => array(
						'background-color' =>   '%%value%%',
					)
				),
				array(
					'selector'  =>  array(
						// Global Themes
						'.main-color',
						'.screen-reader-text:hover',
						'.screen-reader-text:active',
						'.screen-reader-text:focus',
						'.responsive-header .menu-container .resp-menu li:hover > a',
						'.widget.widget_archive .post-count',
						'.widget.widget_calendar table td a',
						'.widget.widget_categories .post-count',
						'.widget.widget_nav_menu ul.menu li > a:hover',
						'.widget.widget_nav_menu .menu .better-custom-badge',
						'.widget.widget_recent_comments a:hover',
						'.bs-about .about-link a',
						'.pagination.bs-links-pagination a:hover',
						'.section-heading a:hover',
						'.comment-list li.bypostauthor > article > .comment-meta .comment-author a',
						'.comment-list li.bypostauthor > article > .comment-meta .comment-author',
						'.comment-list .comment-footer .comment-edit-link:hover',
						'.comment-respond #cancel-comment-reply-link',
						'span.dropcap.square-outline',
						'span.dropcap.circle-outline',

						// This Theme
						'a.read-more:hover',
						'a:hover',
						'.post-meta a:hover',
						'.term-badges .term-badge a',
						'.term-badges .format-badge a',
						'.top-menu.menu li:hover > a',
						'.main-menu.menu li:hover > a',
						'.top-menu.menu .sub-menu > li:hover > a',
						'.main-menu.menu .sub-menu > li:hover > a',
						'.mega-menu.mega-type-link-list .mega-links > li > a:hover',
						'.mega-menu.mega-type-link-list .mega-links > li:hover > a',
						'.mega-grid-posts .post.listing-item-grid-simple .heading-container .title a:hover',
						'.main-menu-wrapper.menu-schema-dark .main-menu.menu > li:hover > a',
						'.topbar .better-social-counter.style-button .social-item:hover .item-icon',
						'.topbar .search-container.open .search-handler',
						'.topbar .search-container:hover .search-handler',
						'.topbar .search-container:hover .search-handler',
						'.listing-item .post-footer .post-share:hover .share-handler',
						'.listing-item-blog .title a:hover',
						'.widget .widget-heading a:hover',
						'.site-footer.color-scheme-dark a:hover',
						'.single-post-content > .post-author .pre-head a:hover',
						'.entry-content a',
						'.top-menu.menu .sub-menu li.current-menu-item > a',
						'.top-menu.menu li.current-menu-item > a',
						'.main-menu.menu .sub-menu li.current-menu-item > a',
						'.main-menu.menu li.current-menu-item > a',
						'.top-menu.menu > li.current-menu-item:hover > a',
						'.header .better-social-counter.style-button .social-item:hover .item-icon',
						'.header .search-container.open .search-handler',
						'.header .search-container:hover .search-handler',
					),
					'prop'      =>  array( 'color' )
				),
				array(
					'selector'  =>  array(
						// Global Themes
						'textarea:focus',
						'input[type="url"]:focus',
						'input[type="search"]:focus',
						'input[type="password"]:focus',
						'input[type="email"]:focus',
						'input[type="number"]:focus',
						'input[type="week"]:focus',
						'input[type="month"]:focus',
						'input[type="time"]:focus',
						'input[type="datetime-local"]:focus',
						'input[type="date"]:focus',
						'input[type="color"]:focus',
						'input[type="text"]:focus',
						'.widget.widget_nav_menu .menu .better-custom-badge:after',
						'.widget.widget_bs-theme-subscribe-newsletter .bs-subscribe-newsletter form .feedburner-email:focus',
						'.better-gallery .fotorama__thumb-border',
						'span.dropcap.square-outline',
						'span.dropcap.circle-outline',
						'.bs-tab-shortcode .nav.nav-tabs',

						// This Theme
					),
					'prop'      =>  array( 'border-color' )
				),
			),
		);
		$fields['site_bg_color'] = array(
			'name'          =>  __( 'Site Background Color', 'better-studio' ),
			'id'            =>  'site_bg_color',
			'type'          =>  'color',
			'std'           =>  '#e6e6e6',
			'desc'          =>  __( 'Setting a body background image below will override it.', 'better-studio' ),
			'css'           =>  array(
				array(
					'selector'  => array(
						'body'
					),
					'prop'      => array(
						'background-color' => '%%value%%'
					),
				)
			)
		);
		$fields['site_bg_image'] = array(
			'name'          =>  __( 'Body Background Image', 'better-studio' ),
			'id'            =>  'site_bg_image',
			'type'          =>  'background_image',
			'std'           =>  '',
			'upload_label'  =>  __( 'Upload Image', 'better-studio' ),
			'desc'          =>  __( 'Use light patterns in non-boxed layout. For patterns, use a repeating background. Use photo to fully cover the background with an image. Note that it will override the background color option.', 'better-studio' ),
			'css'           =>  array(
				array(
					'selector'  => array(
						'body'
					),
					'prop'      => array( 'background-image' ),
					'type'      => 'background-image',
				)
			)
		);


		/**
		 * -> Header Colors
		 */
		$fields[] = array(
			'name'          =>  __( 'Header', 'better-studio' ),
			'type'          =>  'group',
			'state'         =>  'open',
		);
		$fields['header_color_scheme'] = array(
			'name'          =>   __( 'Header Color Scheme', 'better-studio' ),
			'id'            =>  'header_color_scheme',
			'desc'          =>   __( 'Select color scheme of header.', 'better-studio' ),
			'std'           =>  'light',
			'type'          =>  'select',
			'options'       => array(
				'light'         =>  __( 'Light', 'better-studio' ),
				'dark'          =>  __( 'Dark', 'better-studio' ),
			),
		);
		$fields['resp_scheme'] = array(
			'name'          =>   __( 'Responsive Header Color Scheme', 'better-studio' ),
			'id'            =>  'resp_scheme',
			'desc'          =>   __( 'Select responsive header color scheme.', 'better-studio' ),
			'std'           =>  'dark',
			'type'          =>  'image_select',
			'section_class' =>  'style-floated-left bordered',
			'options'       =>  array(
				'dark'  =>  array(
					'img'   =>  bf_get_theme_uri( 'includes/admin-assets/images/resp-header-dark.png' ),
					'label' =>  __( 'Dark Style', 'better-studio' ),
				),
				'light'  =>  array(
					'img'   =>  bf_get_theme_uri( 'includes/admin-assets/images/resp-header-light.png' ),
					'label' =>  __( 'Light Style', 'better-studio' ),
				),
			),
		);
		$fields['header_bg_color'] = array(
			'name'          =>  __( 'Header Background Color', 'better-studio' ),
			'id'            =>  'header_bg_color',
			'type'          =>  'color',
			'std'           =>  '',
			'desc'          =>  __( 'You can change header background color with this option.', 'better-studio' ),
			'css'           =>  array(
				array(
					'selector'  => array(
						'.header.header-style-1',
						'.header.header-style-2 .main-menu-wrapper'
					),
					'prop'      => array(
						'background-color' => '%%value%%'
					)
				)
			)
		);
		$fields['header_bg_image'] = array(
			'name'          =>  __( 'Header Background Image', 'better-studio' ),
			'id'            =>  'header_bg_image',
			'type'          =>  'background_image',
			'std'           =>  '',
			'upload_label'  =>  __( 'Upload Image', 'better-studio' ),
			'desc'          =>  __( 'Use light patterns in non-boxed layout. For patterns, use a repeating background. Use photo to fully cover the background with an image. Note that it will override the background color option.', 'better-studio' ),
			'css'           =>  array(
				array(
					'selector'  => array(
						'.header.header-style-1',
						'.header.header-style-2 .main-menu-wrapper'
					),
					'prop'      => array( 'background-image' ),
					'type'      => 'background-image'
				)
			)
		);

		/**
		 * -> Footer Colors
		 */
		$fields[] = array(
			'name'          =>  __( 'Footer', 'better-studio' ),
			'type'          =>  'group',
			'state'         =>  'open',
		);
		$fields['footer_scheme'] = array(
			'name'          =>  __( 'Footer Color Scheme', 'better-studio' ),
			'desc'          =>  __( 'Select footer color scheme.', 'better-studio' ),
			'id'            =>  'footer_scheme',
			'std'           =>  'light' ,
			'type'          =>  'select',
			'options'       => array(
				'light'         =>  __( 'Light', 'better-studio' ),
				'dark'          =>  __( 'Dark', 'better-studio' ),
			)
		);
		$fields['footer_bg_color'] = array(
			'name'          =>  __( 'Footer Background Color', 'better-studio' ),
			'id'            =>  'footer_bg_color',
			'type'          =>  'color',
			'std'           =>  '',
			'desc'          =>  __( 'you can change footer background color with this option.', 'better-studio' ),
			'css'           =>  array(
				array(
					'selector'  => array(
						'.site-footer',
						'.site-footer.color-scheme-dark',
						'.site-footer .widget .widget-heading .h-text',
						'.site-footer.color-scheme-dark .widget .widget-heading .h-text',
						'.site-footer .widget.widget_calendar table td.pad:hover',
						'.site-footer .widget.widget_calendar table td.pad',
					),
					'prop'      => array(
						'background-color' => '%%value%%'
					)
				),
				array(
					'selector'  => array(
						'.widget.widget_calendar table td',
						'.widget.widget_calendar table th',
					),
					'prop'      => array(
						'border-color' => '%%value%%'
					)
				),

			)
		);
		$fields['footer_bg_image'] = array(
			'name'          =>  __( 'Footer Background Image', 'better-studio' ),
			'id'            =>  'footer_bg_image',
			'type'          =>  'background_image',
			'std'           =>  '',
			'upload_label'  =>  __( 'Upload Image', 'better-studio' ),
			'desc'          =>  __( 'Use light patterns in non-boxed layout. For patterns, use a repeating background. Use photo to fully cover the background with an image. Note that it will override the background color option.', 'better-studio' ),
			'css'           =>  array(
				array(
					'selector'  => array(
						'.site-footer'
					),
					'prop'      => array( 'background-image' ),
					'type'      => 'background-image'
				)
			)
		);


		/**
		 * => Typography Options
		 */
		$fields[] = array(
			'name'          =>  __( 'Typography' , 'better-studio' ),
			'id'            =>  'typo_settings',
			'type'          =>  'tab',
			'icon'          =>  'bsai-typography'
		);
		$fields[] = array(
			'name'          =>  __( 'Reset Typography settings', 'better-studio' ),
			'id'            =>  'reset_typo_settings',
			'type'          =>  'ajax_action',
			'button-name'   =>  '<i class="fa fa-refresh"></i> ' . __( 'Reset Typography', 'better-studio' ),
			'callback'      =>  'Patricia::reset_typography_options',
			'confirm'       =>  __( 'Are you sure for resetting typography?', 'better-studio' ),
			'desc'          =>  __( 'This allows you to reset all typography fields to default.', 'better-studio' )
		);

		/**
		 * -> General Typography
		 */
		$fields[] = array(
			'name'          =>  __( 'General Typography', 'better-studio' ),
			'type'          =>  'group',
			'state'         =>  'open',
		);
		$fields['typo_body'] = array(
			'name'          =>  __( 'Base Font (Body)', 'better-studio' ),
			'id'            =>  'typo_body',
			'type'          =>  'typography',
			'std'           =>  array(
				'family'    =>  'Merriweather',
				'variant'   =>  '400',
				'subset'    =>  'latin',
				'size'      =>  '13',
				'align'     =>  'inherit',
				'transform' =>  'initial',
				'color'     =>  '#5f6569',
			),
			'desc'          =>  __( 'Base typography for body that will affect all elements that haven\'t specified typography style. ', 'better-studio' ),
			'preview'       =>  true,
			'preview_tab'   => 'paragraph',
			'css-echo-default'  => true,
			'css'           => array(
				array(
					'selector'  =>  'body',
					'type'      =>  'font',
				)
			),
		);
		$fields['typo_heading'] = array(
			'name'          =>  __( 'Base Heading Typography', 'better-studio' ),
			'id'            =>  'typo_heading',
			'type'          =>  'typography',
			'std'           =>  array(
				'family'        => 'Alegreya Sans',
				'variant'       => '500',
				'subset'        => 'latin',
				'transform'     => 'initial',
			),
			'desc'          =>  __( 'Base heading typography that will be set to all headings (h1,h2 etc) and all titles of sections and pages that must be bolder than other texts.', 'better-studio' ),
			'preview'       =>  true,
			'preview_tab'   =>  'title',
			'css-echo-default'  => true,
			'css'           =>  array(
				array(
					'selector'  => array(
						'.heading-typo',
						'h1,h2,h3,h4,h5,h6',
						'.header .site-branding .logo',
						'.search-form input[type="submit"]',
						'.widget.widget_categories ul li',
						'.widget.widget_archive ul li',
						'.widget.widget_nav_menu ul.menu',
						'.widget.widget_pages ul li',
						'.widget.widget_recent_entries li a',
						'.widget .tagcloud a',
						'.widget.widget_calendar table caption',
						'.listing-widget .listing-item .title',
						'button,html input[type="button"],input[type="reset"],input[type="submit"],input[type="button"]',
						'.pagination',
						'.site-footer .footer-social-icons .better-social-counter.style-name .social-item',
						'.site-footer .copy-footer .container',
						'.section-heading .h-text',
						'.single-container .post-tags a',
						'.single-container .post-share a',
						'.comment-list .comment-meta .comment-author',
						'.comments-wrap .comments-nav',
						'.main-slider .content-container .read-more',
						'a.read-more',
						'.single-page-content > .post-share li',
						'.single-container > .post-share li',
					),
					'type'      => 'font',
				),
			),
		);
		$fields['typo_meta'] = array(
			'name'          =>  __( 'Posts Meta', 'better-studio' ),
			'id'            =>  'typo_meta',
			'type'          =>  'typography',
			'std'           =>  array(
				'family'        => 'Open Sans',
				'variant'       => '300',
				'size'          => '12',
				'subset'        => 'latin',
				'transform'     => 'capitalize',
				'color'         => '#8b8b8b'
			),
			'desc'          =>  __( 'Typography of posts info in post meta.', 'better-studio' ),
			'preview'       =>  true,
			'preview_tab'   =>  'title',
			'css-echo-default'  => true,
			'css'           => array(
				array(
					'selector'  => array(
						'.post-meta',
						'.post-meta a',
					),
					'type'      => 'font',
				),
			),
		);
		$fields['typo_badges'] = array(
			'name'          =>  __( 'Posts Badges', 'better-studio' ),
			'id'            =>  'typo_badges',
			'type'          =>  'typography',
			'std'           =>  array(
				'family'        => 'Open Sans',
				'variant'       => '400italic',
				'size'          => '13',
				'subset'        => 'latin',
				'transform'     => 'capitalize',
			),
			'desc'          =>  __( 'Typography of category and post format badges.', 'better-studio' ),
			'preview'       =>  true,
			'preview_tab'   =>  'title',
			'css-echo-default'  => true,
			'css'           =>  array(
				array(
					'selector'  => array(
						'.term-badges a',
					),
					'type'      => 'font',
				),
			),
		);


		/**
		 * -> Post & Page Typography
		 */
		$fields[] = array(
			'name'          =>  __( 'Post & Page', 'better-studio' ),
			'type'          =>  'group',
			'state'         =>  'close',
		);
		$fields['typo_post_heading'] = array(
			'name'          =>  __( 'Post Title', 'better-studio' ),
			'id'            =>  'typo_post_heading',
			'type'          =>  'typography',
			'std'           =>  array(
				'family'        =>  'Alegreya Sans',
				'variant'       =>  '500',
				'size'          =>  '22',
				'subset'        =>  'latin',
				'transform'     =>  'capitalize',
				'align'         =>  'center',
			),
			'desc'          =>  __( 'Typography of post title in single pages.', 'better-studio' ),
			'preview'       =>  true,
			'preview_tab'   =>  'title',
			'css-echo-default'  => true,
			'css'           =>  array(
				array(
					'selector'  => array(
						'.single-post-content > .title',
					),
					'type'      => 'font',
				),
			),
		);
		$fields['typo_page_heading'] = array(
			'name'          =>  __( 'Page Title', 'better-studio' ),
			'id'            =>  'typo_page_heading',
			'type'          =>  'typography',
			'std'           =>  array(
				'family'        =>  'Alegreya Sans',
				'variant'       =>  '500',
				'size'          =>  '22',
				'subset'        =>  'latin',
				'transform'     =>  'capitalize',
				'align'         =>  'center',
			),
			'desc'          =>  __( 'Typography of static pages title', 'better-studio' ),
			'preview'       =>  true,
			'preview_tab'   =>  'title',
			'css-echo-default'  => true,
			'css'           =>  array(
				array(
					'selector'  => array(
						'.single-page-content > .page-title',
					),
					'type'      => 'font',
				),
			),
		);
		$fields['typo_entry_content'] = array(
			'name'          =>  __( 'Posts & Pages Content', 'better-studio' ),
			'id'            =>  'typo_entry_content',
			'type'          =>  'typography',
			'std'           =>  array(
				'family'    =>  'Merriweather',
				'variant'   =>  '200',
				'subset'    =>  'latin',
				'size'      =>  '14',
				'align'     =>  'inherit',
				'transform' =>  'initial',
				'color'     =>  '#4A4A4A',
			),
			'desc'          =>  __( 'Base typography for content of posts and static pages.', 'better-studio' ),
			'preview'       =>  true,
			'preview_tab'   => 'paragraph',
			'css-echo-default'  => true,
			'css'           => array(
				array(
					'selector'  =>  '.entry-content',
					'type'      =>  'font',
				)
			),
		);
		$fields['typo_post_summary'] = array(
			'name'          =>  __( 'Post Summary', 'better-studio' ),
			'id'            =>  'typo_post_summary',
			'type'          =>  'typography',
			'std'           =>  array(
				'family'        =>  'Merriweather',
				'variant'       =>  '200',
				'subset'        =>  'latin',
				'size'          =>  '14',
				'align'         =>  'inherit',
				'transform'     =>  'initial',
				'color'         =>  '#4A4A4A',
			),
			'desc'          =>  __( 'Base typography for posts summary in all listings.', 'better-studio' ),
			'preview'       =>  true,
			'preview_tab'   => 'paragraph',
			'css-echo-default'  => true,
			'css'           => array(
				array(
					'selector'  =>  '.post-summary',
					'type'      =>  'font',
				)
			),
		);
		$fields['post_author'] = array(
			'name'          =>  __( 'Post Author Links', 'better-studio' ),
			'id'            =>  'post_author',
			'type'          =>  'typography',
			'std'           =>  array(
				'family'    =>  'Open Sans',
				'variant'   =>  '600',
				'subset'    =>  'latin',
			),
			'desc'          =>  __( 'Typography of post author box in bottom post content.', 'better-studio' ),
			'preview'       =>  true,
			'preview_tab'   => 'paragraph',
			'css-echo-default'  => true,
			'css'           => array(
				array(
					'selector'  =>  '.single-container .post-author',
					'type'      =>  'font',
				)
			),
		);


		/**
		 * -> Header Typography
		 */
		$fields[] = array(
			'name'          =>  __( 'Header', 'better-studio' ),
			'type'          =>  'group',
			'state'         =>  'close',
		);
		$fields['typ_header_menu'] = array(
			'name'          =>  __( 'Menu Typography', 'better-studio' ),
			'id'            =>  'typ_header_menu',
			'type'          =>  'typography',
			'std'           =>  array(
				'family'        =>  'Alegreya Sans',
				'variant'       =>  '500',
				'subset'        =>  'latin',
				'size'          =>  '16',
				'align'         =>  'inherit',
				'transform'     =>  'uppercase',
			),
			'preview'           =>  true,
			'preview_tab'       =>  'title',
			'css-echo-default'  => true,
			'css'               =>  array(
				array(
					'selector' => array(
						'.main-menu a',
						'.main-menu li',
					),
					'type'  => 'font',
				)
			),
		);
		$fields['typ_header_sub_menu'] = array(
			'name'          =>  __( 'Sub Menu Typography', 'better-studio' ),
			'id'            =>  'typ_header_sub_menu',
			'type'          =>  'typography',
			'std'           =>  array(
				'family'        =>  'Alegreya Sans',
				'variant'       =>  '500',
				'subset'        =>  'latin',
				'size'          =>  '15',
				'align'         =>  'inherit',
				'transform'     =>  'capitalize',
				'color'         =>  '#c0c0c0'
			),
			'preview'       =>  true,
			'preview_tab'   =>  'title',
			'css-echo-default'  => true,
			'css'           =>  array(
				array(
					'selector' => array(
						'.main-menu.menu .sub-menu > li > a',
						'.main-menu.menu .sub-menu > li',
						'.responsive-header .menu-container .resp-menu li > a',
						'.responsive-header .menu-container .resp-menu li',
					),
					'type'  => 'font',
				)
			),
		);


		/**
		 * -> Archive Title
		 */
		$fields[] = array(
			'name'          =>  __( 'Archive Pages Title', 'better-studio' ),
			'type'          =>  'group',
			'state'         =>  'close',
		);
		$fields['typo_archive_title_pre'] = array(
			'name'          =>  __( 'Archive Pre Title', 'better-studio' ),
			'id'            =>  'typo_archive_title_pre',
			'type'          =>  'typography',
			'std'           =>  array(
				'family'        =>  'Open Sans',
				'variant'       =>  '400italic',
				'subset'        =>  'latin',
				'size'          =>  '14',
				'align'         =>  'inherit',
				'transform'     =>  'capitalize',
			),
			'preview'       =>  true,
			'preview_tab'   =>  'title',
			'css-echo-default'  => true,
			'css'           =>  array(
				array(
					'selector' => array(
						'.archive-title .pre-title',
					),
					'type'  => 'font',
				)
			),
		);
		$fields['typo_archive_title'] = array(
			'name'          =>  __( 'Archive Title', 'better-studio' ),
			'id'            =>  'typo_archive_title',
			'type'          =>  'typography',
			'std'           =>  array(
				'family'        =>  'Alegreya Sans',
				'variant'       =>  '500',
				'subset'        =>  'latin',
				'size'          =>  '42',
				'align'         =>  'inherit',
				'transform'     =>  'none',
				'color'         =>  '#383838'
			),
			'preview'       =>  true,
			'preview_tab'   =>  'title',
			'css-echo-default'  => true,
			'css'           =>  array(
				array(
					'selector' => array(
						'.archive-title .page-heading',
					),
					'type'  => 'font',
				)
			),
		);


		/**
		 * -> Blog Listing
		 */
		$fields[] = array(
			'name'          =>  __( 'Blog Listing', 'better-studio' ),
			'type'          =>  'group',
			'state'         =>  'close',
		);
		$fields['typo_listing_blog_title'] = array(
			'name'          =>  __( 'Blog Listing Heading', 'better-studio' ),
			'id'            =>  'typo_listing_blog_title',
			'type'          =>  'typography',
			'std'           =>  array(
				'family'        =>  'Alegreya Sans',
				'variant'       =>  '500',
				'subset'        =>  'latin',
				'size'          =>  '23',
				'align'         =>  'center',
				'transform'     =>  'none',
				'color'         =>  '#383838'
			),
			'preview'       =>  true,
			'preview_tab'   =>  'title',
			'css-echo-default'  => true,
			'css'           =>  array(
				array(
					'selector' => array(
						'.listing-item-blog > .title',
					),
					'type'  => 'font',
				)
			),
		);


		/**
		 * -> Grid Listing
		 */
		$fields[] = array(
			'name'          =>  __( 'Grid Listing', 'better-studio' ),
			'type'          =>  'group',
			'state'         =>  'close',
		);
		$fields['typo_listing_grid_title'] = array(
			'name'          =>  __( 'Grid Listing Heading', 'better-studio' ),
			'id'            =>  'typo_listing_grid_title',
			'type'          =>  'typography',
			'std'           =>  array(
				'family'        =>  'Alegreya Sans',
				'variant'       =>  '500',
				'subset'        =>  'latin',
				'size'          =>  '18',
				'line_height'   =>  '18',
				'align'         =>  'center',
				'transform'     =>  'none',
				'color'         =>  '#383838'
			),
			'preview'       =>  true,
			'preview_tab'   =>  'title',
			'css-echo-default'  => true,
			'css'           =>  array(
				array(
					'selector' => array(
						'.listing-grid .listing-item-grid .item-inner > .title',
					),
					'type'  => 'font',
				)
			),
		);


		/**
		 * -> Modern Listing
		 */
		$fields[] = array(
			'name'          =>  __( 'Modern Listing', 'better-studio' ),
			'type'          =>  'group',
			'state'         =>  'close',
		);
		$fields['typo_listing_modern_title'] = array(
			'name'          =>  __( 'Modern Listing Heading', 'better-studio' ),
			'id'            =>  'typo_listing_modern_title',
			'type'          =>  'typography',
			'std'           =>  array(
				'family'        =>  'Alegreya Sans',
				'variant'       =>  '500',
				'subset'        =>  'latin',
				'size'          =>  '20',
				'line_height'   =>  '20',
				'align'         =>  'center',
				'transform'     =>  'none',
				'color'         =>  '#383838'
			),
			'preview'       =>  true,
			'preview_tab'   =>  'title',
			'css-echo-default'  => true,
			'css'           =>  array(
				array(
					'selector' => array(
						'.listing-item-modern > .title',
					),
					'type'  => 'font',
				)
			),
		);

		/**
		 * -> Widgets
		 */
		$fields[] = array(
			'name'          =>  __( 'Widgets', 'better-studio' ),
			'type'          =>  'group',
			'state'         =>  'close',
		);
		$fields['typo_widget_title'] = array(
			'name'          =>  __( 'Widget Title', 'better-studio' ),
			'id'            =>  'typo_widget_title',
			'type'          =>  'typography',
			'std'           =>  array(
				'family'        => 'Alegreya Sans',
				'variant'       => '500',
				'subset'        =>  'latin',
				'size'          =>  '18',
				'align'         =>  'center',
				'transform'     =>  'uppercase',
				'color'         =>  '#444444'
			),
			'preview'       =>  true,
			'preview_tab'   =>  'title',
			'css-echo-default'  => true,
			'css'           =>  array(
				array(
					'selector' => array(
						'.widget .widget-heading',
					),
					'type'  => 'font',
				)
			),
		);



		/**
		 * => Advanced Options
		 */
		$fields[] = array(
			'name'          =>  __( 'Advanced' , 'better-studio' ),
			'id'            =>  'advanced_settings',
			'type'          =>  'tab',
			'icon'          =>  'bsai-gear'
		);
		$fields[] = array(
			'name'          =>  __( 'Custom Width', 'better-studio' ),
			'id'            =>  'favicon_heading',
			'type'          =>  'group',
			'state'         =>  'close',
		);
		$fields['site_box_width'] = array(
			'name'      =>  __( 'Site Wrapper Max Width','better-studio'),
			'desc'      =>  __( 'Controls max width of site. In px or %, ex: 100% or 1400px.','better-studio'),
			'input-desc'=>  __( 'This value should have px or %.','better-studio'),
			'id'        =>  'site_box_width',
			'std'       =>  '1200px' ,
			'type'      =>  'text',
			'ltr'       =>  true,
			'css'       =>  array(
				array(
					'selector'  => array(
						'.content-wrap',
					),
					'prop'      => 'max-width'
				),
			),
		);
		$fields['site_single_col_width'] = array(
			'name'      =>  __( 'Single Column Layout Max Width','better-studio'),
			'desc'      =>  __( 'Controls max width of single column layout. In px or %, ex: 100% or 1400px.','better-studio'),
			'input-desc'=>  __( 'This value should have px or %.','better-studio'),
			'id'        =>  'site_single_col_width',
			'std'       =>  '900px' ,
			'type'      =>  'text',
			'ltr'       =>  true,
			'css'       =>  array(
				array(
					'selector'  => array(
						'.container.layout-1-col > .main-section > .content-column',
					),
					'prop'      => 'max-width'
				),
			),
		);


		if ( ! function_exists( 'has_site_icon' ) || ! has_site_icon() ) {
			$fields[] = array(
				'name'          =>  __( 'Favicons', 'better-studio' ),
				'id'            =>  'favicon_heading',
				'type'          =>  'group',
				'state'         =>  'close',
			);
			$fields[] = array(
				'name'          =>  __( 'Favicon (16x16)','better-studio' ),
				'id'            =>  'favicon_16_16',
				'type'          =>  'media_image',
				'std'           =>  '',
				'desc'          =>  __( 'Default Favicon. 16px x 16px', 'better-studio' ),
				'media_title'   =>  __( 'Select or Upload Favicon', 'better-studio' ),
				'media_button'  =>  __( 'Select Favicon', 'better-studio' ),
				'upload_label'  =>  __( 'Upload Favicon', 'better-studio' ),
				'remove_label'  =>  __( 'Remove Favicon', 'better-studio' ),
			);
			$fields[] = array(
				'name'          =>  __( 'Apple iPhone Icon (57x57)', 'better-studio' ),
				'id'            =>  'favicon_57_57',
				'type'          =>  'media_image',
				'desc'          =>  __( 'Icon for Classic iPhone', 'better-studio' ),
				'std'           =>  '',
				'media_title'   =>  __( 'Select or Upload Favicon', 'better-studio' ),
				'media_button'  =>  __( 'Select Favicon', 'better-studio' ),
				'upload_label'  =>  __( 'Upload Favicon', 'better-studio' ),
				'remove_label'  =>  __( 'Remove Favicon', 'better-studio' ),
			);
			$fields[] = array(
				'name'          =>  __( 'Apple iPhone Retina Icon (114x114)', 'better-studio' ),
				'id'            =>  'favicon_114_114',
				'type'          =>  'media_image',
				'desc'          =>  __( 'Icon for Retina iPhone', 'better-studio' ),
				'std'           =>  '',
				'media_title'   =>  __( 'Select or Upload Favicon', 'better-studio'),
				'media_button'  =>  __( 'Select Favicon', 'better-studio' ),
				'upload_label'  =>  __( 'Upload Favicon', 'better-studio' ),
				'remove_label'  =>  __( 'Remove Favicon', 'better-studio' ),
			);
			$fields[] = array(
				'name'          =>  __( 'Apple iPad Icon (72x72)', 'better-studio' ),
				'id'            =>  'favicon_72_72',
				'type'          =>  'media_image',
				'desc'          =>  __( 'Icon for Classic iPad', 'better-studio' ),
				'std'           =>  '',
				'media_title'   =>  __( 'Select or Upload Favicon', 'better-studio' ),
				'media_button'  =>  __( 'Select Favicon', 'better-studio' ),
				'upload_label'  =>  __( 'Upload Favicon', 'better-studio' ),
				'remove_label'  =>  __( 'Remove Favicon', 'better-studio' ),
			);
			$fields[] = array(
				'name'          =>  __( 'Apple iPad Retina Icon (144x144)', 'better-studio' ),
				'id'            =>  'favicon_144_144',
				'type'          =>  'media_image',
				'desc'          =>  __( 'Icon for Retina iPad', 'better-studio' ),
				'std'           =>  '',
				'media_title'   =>  __( 'Select or Upload Favicon', 'better-studio' ),
				'media_button'  =>  __( 'Select Favicon', 'better-studio' ),
				'upload_label'  =>  __( 'Upload Favicon', 'better-studio' ),
				'remove_label'  =>  __( 'Remove Favicon', 'better-studio' ),
			);
		}

		$fields[] = array(
			'name'          =>  __( 'No Duplicate Posts','better-studio' ),
			'type'          =>  'group',
			'state'         =>  'close',
		);
		$fields[] = array(
			'name'          =>  __( 'Enable For Whole Site', 'better-studio' ),
			'id'            =>  'bm_remove_duplicate_posts_full',
			'type'          =>  'switch',
			'on-label'      =>  __( 'Yes', 'better-studio' ),
			'off-label'     =>  __( 'No', 'better-studio' ),
			'desc'          =>  __( 'Enabling this feature will remove duplicate posts in whole site.', 'better-studio'),
			'std'           =>  0,
		);
		$fields[] = array(
			'name'          =>  __( 'Enable In Homepage', 'better-studio' ),
			'id'            =>  'bm_remove_duplicate_posts',
			'type'          =>  'switch',
			'on-label'      =>  __( 'Yes', 'better-studio' ),
			'off-label'     =>  __( 'No', 'better-studio' ),
			'desc'          =>  __( 'Enabling this feature will remove duplicate posts in home page.', 'better-studio'),
			'std'           =>  0,
		);
		$fields[] = array(
			'name'          =>  __( 'Enable In Category Archive Page', 'better-studio' ),
			'id'            =>  'bm_remove_duplicate_posts_categories',
			'type'          =>  'switch',
			'on-label'      =>  __( 'Yes', 'better-studio' ),
			'off-label'     =>  __( 'No', 'better-studio' ),
			'desc'          =>  __( 'Enabling this feature will remove duplicate posts in category archive pages.', 'better-studio'),
			'std'           =>  0,
		);
		$fields[] = array(
			'name'          =>  __( 'Enable In Tag Archive Page', 'better-studio' ),
			'id'            =>  'bm_remove_duplicate_posts_tags',
			'type'          =>  'switch',
			'on-label'      =>  __( 'Yes', 'better-studio' ),
			'off-label'     =>  __( 'No', 'better-studio' ),
			'desc'          =>  __( 'Enabling this feature will remove duplicate posts in tag archive pages.', 'better-studio'),
			'std'           =>  0,
		);

		$fields[] = array(
			'name'          =>  __( 'Customize Post and Page Options', 'better-studio' ),
			'type'          =>  'group',
			'state'         =>  'close',
		);
		$fields[] = array(
			'name'          =>  __( 'Add Post Options To Other Post Types', 'better-studio' ),
			'id'            =>  'advanced_post_options_types',
			'desc'          =>  __( 'Enter custom post types IDs here to adding post meta box to them.', 'better-studio' ),
			'input-desc'    =>  __( 'Separate post types with ","', 'better-studio' ),
			'type'          =>  'text',
			'std'           =>  '',
			'ltr'           =>  true
		);
		$fields[] = array(
			'name'          =>  __( 'Customize Category and Tag Options', 'better-studio' ),
			'type'          =>  'group',
			'state'         =>  'close',
		);
		$fields[] = array(
			'name'          =>  __( 'Add Category Options to Other Taxonomies', 'better-studio' ),
			'id'            =>  'advanced_category_options_tax',
			'desc'          =>  __( 'Enter custom taxonomy IDs here to adding category meta box to them.', 'better-studio' ),
			'input-desc'    =>  __( 'Separate taxonomies with ","', 'better-studio' ),
			'type'          =>  'text',
			'std'           =>  '',
			'ltr'           =>  true
		);
		$fields[] = array(
			'name'          =>  __( 'Add Tag Options to Other Taxonomies', 'better-studio' ),
			'id'            =>  'advanced_tag_options_tax',
			'desc'          =>  __( 'Enter custom taxonomy IDs here to adding tag meta box to them.', 'better-studio' ),
			'input-desc'    =>  __( 'Separate taxonomies with ","', 'better-studio' ),
			'type'          =>  'text',
			'std'           =>  '',
			'ltr'           =>  true
		);


		/**
		 * => Custom Javascript / CSS
		 */
		$fields[] = array(
			'name'          =>  __( 'Custom CSS' , 'better-studio' ),
			'id'            =>  'custom_css_settings',
			'type'          =>  'tab',
			'icon'          =>  'bsai-css3',
			'margin-top'    =>  '20',
		);

		$fields[] = array(
			'name'          =>  __( 'Custom CSS Code', 'better-studio' ),
			'id'            =>  'custom_css_code',
			'type'          =>  'textarea',
			'std'           =>  '',
			'desc'          =>  __( 'Paste your CSS code, do not include any tags or HTML in the field. Any custom CSS entered here will override the theme CSS. In some cases, the !important tag may be needed.', 'better-studio' ),
			'ltr'           =>  true
		);
		$fields[] = array(
			'name'          =>  __( 'Custom Body Class', 'better-studio' ),
			'id'            =>  'custom_css_class_general',
			'type'          =>  'text',
			'std'           =>  '',
			'desc'          =>  __( 'This classes will be added in body of overall site.<br> Separate classes with space.', 'better-studio' )
		);
		$fields[] = array(
			'name'          =>  __( 'Responsive CSS', 'better-studio' ),
			'type'          =>  'group',
			'state'         =>  'close',
			'desc'          =>  'Paste your custom css in the appropriate box, to run only on a specific device',
			'ltr'           =>  true
		);

		$fields[] = array(
			'name'          =>  __( 'Desktop', 'better-studio' ),
			'id'            =>  'custom_css_desktop_code',
			'type'          =>  'textarea',
			'std'           =>  '',
			'desc'          =>  __( '1200px +', 'better-studio' ),
			'ltr'           =>  true,
		);
		$fields[] = array(
			'name'          =>  __( 'Tablet Landscape', 'better-studio' ),
			'id'            =>  'custom_css_tablet_landscape_code',
			'type'          =>  'textarea',
			'std'           =>  '',
			'desc'          =>  __( '1019px - 1199px', 'better-studio' ),
			'ltr'           =>  true,
		);
		$fields[] = array(
			'name'          =>  __( 'Tablet Portrait', 'better-studio' ),
			'id'            =>  'custom_css_tablet_portrait_code',
			'type'          =>  'textarea',
			'std'           =>  '',
			'desc'          =>  __( '768px - 1018px', 'better-studio' ),
			'ltr'           =>  true,
		);
		$fields[] = array(
			'name'          =>  __( 'Phones', 'better-studio' ),
			'id'            =>  'custom_css_phones_code',
			'type'          =>  'textarea',
			'std'           =>  '',
			'desc'          =>  __( '768px - 1018px', 'better-studio' ),
			'ltr'           =>  true,
		);
		$fields[] = array(
			'name'          =>  __( 'Addvanced Custom Body Class', 'better-studio' ),
			'type'          =>  'group',
			'state'         =>  'close',
		);

		$fields[] = array(
			'name'          =>  __( 'Categories Custom Body Class', 'better-studio' ),
			'id'            =>  'custom_css_class_category',
			'type'          =>  'text',
			'std'           =>  '',
			'desc'          =>  __( 'This classes will be added in body of all categories.<br> Separate classes with space.', 'better-studio' ),
			'ltr'           =>  true,
		);
		$fields[] = array(
			'name'          =>  __( 'Tags Custom Body Class', 'better-studio' ),
			'id'            =>  'custom_css_class_tag',
			'type'          =>  'text',
			'std'           =>  '',
			'desc'          =>  __( 'This classes will be added in body of all tags.<br> Separate classes with space.', 'better-studio' ),
			'ltr'           =>  true,
		);
		$fields[] = array(
			'name'          =>  __( 'Authors Custom Body Class', 'better-studio' ),
			'id'            =>  'custom_css_class_author',
			'type'          =>  'text',
			'std'           =>  '',
			'desc'          =>  __( 'This classes will be added in body of all authors.<br> Separate classes with space.', 'better-studio' ),
			'ltr'           =>  true,
		);
		$fields[] = array(
			'name'          =>  __( 'Posts Custom Body Class', 'better-studio' ),
			'id'            =>  'custom_css_class_post',
			'type'          =>  'text',
			'std'           =>  '',
			'desc'          =>  __( 'This classes will be added in body of all posts.<br> Separate classes with space.', 'better-studio' ),
			'ltr'           =>  true,
		);
		$fields[] = array(
			'name'          =>  __( 'Pages Custom Body Class', 'better-studio' ),
			'id'            =>  'custom_css_class_page',
			'type'          =>  'text',
			'std'           =>  '',
			'desc'          =>  __( 'This classes will be added in body of all post.<br> Separate classes with space.', 'better-studio' ),
			'ltr'           =>  true,
		);



		/**
		 * => Analytics & JS
		 */
		$fields[] = array(
			'name'          =>  __( 'Analytics & JS' , 'better-studio' ),
			'id'            =>  'custom_analytics_code',
			'type'          =>  'tab',
			'icon'          =>  'bsai-analytics1',
		);
		$fields[] = array(
			'name'          =>  __( 'Google analytics code', 'better-studio' ),
			'id'            =>  'custom_footer_code',
			'std'           =>  '',
			'type'          =>  'textarea',
			'desc'          =>  __( 'Paste your Google Analytics (or other) tracking code here. This code will be placed before &lt;/body&gt; tag in html. Please put code inside script tags.', 'better-studio' ),
			'ltr'           =>  true,
		);
		$fields[] = array(
			'name'          =>  __( 'Code before &lt;/head&gt;', 'better-studio' ),
			'id'            =>  'custom_header_code',
			'std'           =>  '',
			'type'          =>  'textarea',
			'desc'          =>  __( 'This code will be placed before &lt;/head&gt; tag in html. Useful if you have an external script that requires it.', 'better-studio' ),
			'ltr'           =>  true,
		);

		/**
		 * => Auto Updates
		 */
		$fields[] = array(
			'name'          =>  __( 'Auto Updates' , 'better-studio' ),
			'id'            =>  'auto_update_tab',
			'type'          =>  'tab',
			'icon'          =>  'bsai-refresh',
			'margin-top'    =>  '20',
		);
		$fields[] = array(
			'name'          =>  __( 'ThemeForest Username', 'better-studio' ),
			'id'            =>  'themeforest_user_name',
			'std'           =>  '',
			'type'          =>  'text',
			'ltr'           =>  true,
		);
		$fields[] = array(
			'name'          =>  __( 'ThemeForest API Key', 'better-studio' ),
			'id'            =>  'themeforest_api_key',
			'std'           =>  '',
			'type'          =>  'text',
			'ltr'           =>  true,
		);
		$fields[] = array(
			'name'          =>  __( 'How to setup automatic update?', 'better-studio' ),
			'id'            =>  'twitter-help',
			'type'          =>  'info',
			'std'           =>  '<p>' . __( 'To use the automatic theme updater you must enter your Themeforest username and API key into theme options. They only need to be entered one time. Once they are entered and we issue a theme update, you will receive a notification message in your WordPress admin “Updates” or “Themes” section.', 'better-studio' ) . '</p>'
			                    .'<br><p style="text-align:center;"><img src="'  .  bf_get_theme_uri( 'includes/admin-assets/images/auto-update-help.png' )  . '"></p>',
			'state'         =>  'open',
			'info-type'     =>  'help',
			'section_class' =>  'widefat',
		);


		/**
		 * => Import & Export
		 */
		$fields[] = array(
			'name'          =>  __( 'Backup & Restore' , 'better-studio' ),
			'id'            =>  'backup_restore',
			'type'          =>  'tab',
			'icon'          =>  'bsai-export-import',
			'margin-top'    =>  '20',
		);
		$fields[] = array(
			'name'          =>  __( 'Backup / Export', 'better-studio' ),
			'id'            =>  'backup_export_options',
			'type'          =>  'export',
			'file_name'     =>  'patricia-options-backup',
			'panel_id'      =>  better_theme_panel_id(),
			'desc'          =>  __( 'This allows you to create a backup of your options and settings. Please note, it will not backup anything else.', 'better-studio' )
		);
		$fields[] = array(
			'name'      =>  __( 'Restore / Import', 'better-studio' ),
			'id'        =>  'import_restore_options',
			'type'      =>  'import',
			'panel_id'  =>  better_theme_panel_id(),
			'desc'      =>  __( '<strong>It will override your current settings!</strong> Please make sure to select a valid backup file.', 'better-studio' )
		);


		// Language  name for smart admin texts
		$lang =  bf_get_current_lang();
		if( $lang != 'none' ){
			$lang = bf_get_language_name( $lang );
		}else{
			$lang = '';
		}

		$options[better_theme_panel_id()] = array(
			'panel-name'    =>  _x( 'Patricia Options', 'Panel title', 'better-studio' ),
			'panel-desc'    =>  '<p>' . __( 'Configure theme settings, change colors, typography, layout and more...', 'better-studio' ) . '</p>',
			'panel-desc-lang'       =>  '<p>' . __( 'Theme %s Language Options.', 'better-studio' ) . '</p>',
			'theme-panel'   =>  true,
			'fields'        =>  $fields,

			'texts'         =>  array(

				'panel-desc-lang'       =>  '<p>' . __( '%s Language Options.', 'better-studio' ) . '</p>',
				'panel-desc-lang-all'   =>  '<p>' . __( 'All Languages Options.', 'better-studio' ) . '</p>',

				'reset-button'      => ! empty( $lang ) ? sprintf( __( 'Reset %s Options', 'better-studio' ), $lang ) : __( 'Reset Options', 'better-studio' ),
				'reset-button-all'  => __( 'Reset All Options', 'better-studio' ),

				'reset-confirm'     =>  ! empty( $lang ) ? sprintf( __( 'Are you sure to reset %s options?', 'better-studio' ), $lang ) : __( 'Are you sure to reset options?', 'better-studio' ),
				'reset-confirm-all' => __( 'Are you sure to reset all options?', 'better-studio' ),

				'save-button'       =>  ! empty( $lang ) ? sprintf( __( 'Save %s Options', 'better-studio' ), $lang ) : __( 'Save Options', 'better-studio' ),
				'save-button-all'   =>  __( 'Save All Options', 'better-studio' ),

				'save-confirm-all'  =>  __( 'Are you sure to save all options? this will override specified options per languages', 'better-studio' )

			),

			'config' => array(
				'name' 				  => __( 'Theme Options', 'better-studio' ),
				'parent' 			  => 'better-studio',
				'slug' 			      => 'better-studio/patricia',
				'page_title'		  => __( 'Theme Options', 'better-studio' ),
				'menu_title'		  => __( 'Theme Options', 'better-studio' ),
				'capability' 		  => 'manage_options',
				'menu_slug' 		  => __( 'Patricia Theme Options', 'better-studio' ),
				'icon_url'  		  => null,
				'position'  		  => '20',
				'exclude_from_export' => false,
			),
		);

		return $options;
	} // patricia_panel_options
} // Function Exists


