<?php
/**
 * tag.php
 *---------------------------
 * Registers options for tag
 *
 */

add_filter( 'better-framework/taxonomy/options', 'patricia_tag_options', 100 );

if( ! function_exists( 'patricia_tag_options' ) ){
	/**
	 * Setup custom taxonomy options for BetterMag
	 *
	 * @param $options
	 * @return array
	 */
	function patricia_tag_options( $options ){

		$fields = array();

		/**
		 * => Style
		 */
		$fields[] = array(
			'name'          =>  __( 'Style' , 'better-studio' ),
			'id'            =>  'tab_style',
			'type'          =>  'tab',
			'icon'          =>  'bsai-paint',
		);
		$fields[] = array(
			'name'          =>  __( 'General Separator Icon', 'better-studio' ),
			'id'            =>  'separator_icon',
			'desc'          =>  __( 'Override separator icon for this category.', 'better-studio' ),
			'type'          =>  'icon_select',
			'options'       =>  array( 'fontawesome' ),
			'std'           =>  'none',
			'default_text'  =>  __( 'Chose an Icon', 'betterstudio' ),
		);

		$fields['page_layout'] = array(
			'name'          =>  __( 'Page Layout', 'better-studio' ),
			'id'            =>  'page_layout',
			'std'           =>  'default',
			'type'          =>  'image_select',
			'section_class' =>  'style-floated-left bordered',
			'desc'          =>  __( 'Select and override page layout for this tag.', 'better-studio' ),
			'options'       =>  patricia_layout_option_list( true )
		);
		$fields['page_listing'] = array(
			'name'          =>  __( 'Posts Listing', 'better-studio' ),
			'id'            =>  'page_listing',
			'std'           =>  'default',
			'type'          =>  'image_select',
			'section_class' =>  'style-floated-left bordered',
			'desc'          =>  __( 'Select and override posts listing for this tag.', 'better-studio' ),
			'options'       =>  patricia_listing_option_list( true )
		);
		$fields['term_posts_count'] = array(
			'name'          =>  __( 'Number of Post to Show', 'better-studio' ),
			'id'            =>  'term_posts_count',
			'desc'          =>  sprintf( __( 'Leave this empty for default. <br>Default: %s', 'better-studio' ), better_get_option( 'archive_tag_posts_count' ) != '' ? better_get_option( 'archive_tag_posts_count' ) : get_option( 'posts_per_page' ) ),
			'type'          =>  'text',
			'std'           =>  '',
		);

		/**
		 * => Title
		 */
		$fields[] = array(
			'name'          =>  __( 'Title' , 'better-studio' ),
			'id'            =>  'tab_title',
			'type'          =>  'tab',
			'icon'          =>  'bsai-title',
		);
		$fields['term_custom_title'] = array(
			'name'          =>  __( 'Custom Tag Title', 'better-studio' ),
			'id'            =>  'term_custom_title',
			'type'          =>  'text',
			'std'           =>  '',
			'desc'          =>  __( 'Change tag title or leave empty for default title', 'better-studio' ),
		);
		$fields['hide_term_title'] = array(
			'name'          =>  __( 'Hide Tag Title', 'better-studio' ),
			'id'            =>  'hide_term_title',
			'type'          =>  'switch',
			'std'           =>  '0',
			'on-label'      =>  __( 'Yes', 'better-studio' ),
			'off-label'     =>  __( 'No', 'better-studio' ),
			'desc'          =>  __( 'Enable this for hiding tag title', 'better-studio' ),
		);
		$fields['hide_term_description'] = array(
			'name'          =>  __( 'Hide Tag Description', 'better-studio' ),
			'id'            =>  'hide_term_description',
			'type'          =>  'switch',
			'std'           =>  '0',
			'on-label'      =>  __( 'Yes', 'better-studio' ),
			'off-label'     =>  __( 'No', 'better-studio' ),
			'desc'          =>  __( 'Enable this for hiding tag description', 'better-studio' ),
		);

		/**
		 * => Custom Javascript / CSS
		 */
		$fields['custom_css_settings'] = array(
			'name'          =>  __( 'Custom CSS' , 'better-studio' ),
			'id'            =>  'custom_css_settings',
			'type'          =>  'tab',
			'icon'          =>  'bsai-css3',
			'margin-top'    =>  '20',
		);
		$fields['custom_css_code'] = array(
			'name'          =>  __( 'Custom CSS Code', 'better-studio' ),
			'id'            =>  'custom_css_code',
			'type'          =>  'textarea',
			'std'           =>  '',
			'desc'          =>  __( 'Paste your CSS code, do not include any tags or HTML in the field. Any custom CSS entered here will override the theme CSS. In some cases, the !important tag may be needed.', 'better-studio' )
		);
		$fields['custom_css_class'] = array(
			'name'          =>  __( 'Custom Body Class', 'better-studio' ),
			'id'            =>  'custom_css_class',
			'type'          =>  'text',
			'std'           =>  '',
			'desc'          =>  __( 'This classes will be added to body.<br> Separate classes with space.', 'better-studio' )
		);
		$fields[] = array(
			'name'          =>  __( 'Responsive CSS', 'better-studio' ),
			'type'          =>  'group',
			'state'         =>  'close',
			'desc'          =>  'Paste your custom css in the appropriate box, to run only on a specific device',
		);
		$fields['custom_css_desktop_code'] = array(
			'name'          =>  __( 'Desktop', 'better-studio' ),
			'id'            =>  'custom_css_desktop_code',
			'type'          =>  'textarea',
			'std'           =>  '',
			'desc'          =>  __( '1200px +', 'better-studio' )
		);
		$fields['custom_css_tablet_landscape_code'] = array(
			'name'          =>  __( 'Tablet Landscape', 'better-studio' ),
			'id'            =>  'custom_css_tablet_landscape_code',
			'type'          =>  'textarea',
			'std'           =>  '',
			'desc'          =>  __( '1019px - 1199px', 'better-studio' )
		);
		$fields['custom_css_tablet_portrait_code'] = array(
			'name'          =>  __( 'Tablet Portrait', 'better-studio' ),
			'id'            =>  'custom_css_tablet_portrait_code',
			'type'          =>  'textarea',
			'std'           =>  '',
			'desc'          =>  __( '768px - 1018px', 'better-studio' )
		);
		$fields['custom_css_phones_code'] = array(
			'name'          =>  __( 'Phones', 'better-studio' ),
			'id'            =>  'custom_css_phones_code',
			'type'          =>  'textarea',
			'std'           =>  '',
			'desc'          =>  __( '768px - 1018px', 'better-studio' )
		);

		//
		// Support to custom taxonomies
		//
		$tag_taxonomies = array( 'post_tag' );

		if( better_get_option( 'advanced_tag_options_tax' ) != '' )
			$tag_taxonomies = array_merge( explode( ',', better_get_option( 'advanced_tag_options_tax' ) ), $tag_taxonomies );

		$options[] = array(
			'config' => array(
				'taxonomies'    => $tag_taxonomies,
				'name'          => __( 'Better Tag Options', 'better-studio' )
			),
			'panel-id'  => better_theme_panel_id(),
			'fields' => $fields
		);

		return $options;

	} // patricia_tag_options
} // if