<?php

/**
 * Setup Theme
 */
class Patricia_Setup {

	function __construct(){

		// Register included BF to loader ( After Plugins )
		add_filter( 'better-framework/loader', array( $this, 'register_better_framework' ), 100 );

		// Enable needed sections
		add_filter( 'better-framework/sections' , array( $this , 'setup_bf_features' ), 100 );

		// Admin panel options
		include BS_THEME_PATH . 'includes/options/panel.php';

		// Meta box options
		include BS_THEME_PATH . 'includes/options/metabox.php';

		// User Meta box options
		include BS_THEME_PATH . 'includes/options/user.php';

		// Category options
		include BS_THEME_PATH . 'includes/options/category.php';

		// Tag options
		include BS_THEME_PATH . 'includes/options/tag.php';

		// Menus options
		include BS_THEME_PATH . 'includes/options/menu.php';

		// Active and new shortcodes
		add_filter( 'better-framework/shortcodes', array( $this, 'setup_shortcodes' ), 100 );

		// Define special sidebars to BF
		add_filter( 'better-framework/sidebars/locations/top-bar' , array( $this , 'special_top_bar_sidebar_locations' ), 100 );

		// Define general widget fields and values
		add_filter( 'better-framework/widgets/options/general' , array( $this , 'widgets_general_fields' ), 100 );

		// Init Better Translation Panel
		add_filter( 'better-translation/config', array( $this, 'filter_translations_config' ) );
		include BS_THEME_PATH . 'includes/options/translation.php';
		include BS_THEME_PATH . 'includes/libs/better-translation/class-better-translation.php';

		// Initialize no duplicate posts option
		include BS_THEME_PATH . 'includes/libs/better-duplicate-posts/better-duplicate-posts.php';
		add_action( 'better-duplicate-posts/active-pages', array( $this, 'setup_no_duplicate_posts' ) );

	} // __construct


	/**
	 * Registers included version of BF to BF loader
	 *
	 * @param $frameworks
	 * @return array
	 */
	function register_better_framework( $frameworks ){

		$frameworks[] = array(
			'version'   =>  '2.3.4',
			'path'      =>  dirname( __FILE__ ) . '/libs/better-framework/',
			'uri'       =>  get_template_directory_uri() . '/includes/libs/better-framework/',
		);

		return $frameworks;

	} // register_better_framework


	/**
	 * Setups features of BetterFramework for BetterMag
	 *
	 * @param $features
	 * @return array
	 */
	function setup_bf_features($features){

		/**
		 * 1. => BetterFramework Features
		 */
		$features['admin_panel']        = true;
		$features['meta_box']           = true;
		$features['taxonomy_meta_box']  = true;
		$features['load_in_frontend']   = false;
		$features['better-menu']        = true;
		$features['custom-css-pages']   = true;
		$features['user-meta-box']      = true;
		$features['custom-css-users']   = true;

		return $features;
	} // setup_bf_features


	/**
	 * Filter BetterMag special top-bar sidebar locations for widgets
	 */
	function special_top_bar_sidebar_locations( $locations ){

		$locations[] = 'aside-logo';

		return $locations;

	} // special_top_bar_sidebar_locations


	/**
	 * Filter BetterMag widgets general fields
	 *
	 * @param $fields
	 * @return array
	 */
	function widgets_general_fields( $fields ){

		$fields[] = 'bf-widget-title-icon';
		$fields[] = 'bf-widget-title-link';

		$fields[] = 'bf-widget-show-desktop';
		$fields[] = 'bf-widget-show-tablet';
		$fields[] = 'bf-widget-show-mobile';

		return $fields;

	} // widgets_general_fields


	/**
	 * Setups Shortcodes for BetterMag
	 *
	 * 6. => Setup Shortcodes
	 *
	 * @param $shortcodes
	 */
	function setup_shortcodes( $shortcodes ){

		require bf_get_theme_dir( 'includes/shortcodes/bs-theme-social-share.php' );
		$shortcodes['bs-theme-social-share'] = array(
			'shortcode_class'   =>  'BS_Theme_Social_Share_Shortcode',
			'widget_class'      =>  'BS_Theme_Social_Share_Widget',
		);

		require bf_get_theme_dir( 'includes/shortcodes/bs-theme-recent-posts.php' );
		$shortcodes['bs-theme-recent-posts'] = array(
			'shortcode_class'   =>  'BS_Theme_Recent_Posts_Shortcode',
			'widget_class'      =>  'BS_Theme_Recent_Posts_Widget',
		);

		require bf_get_theme_dir( 'includes/shortcodes/bs-theme-about.php' );
		$shortcodes['bs-theme-about'] = array(
			'shortcode_class'   =>  'BS_Theme_About_Shortcode',
			'widget_class'      =>  'BS_Theme_About_Widget',
		);

		require bf_get_theme_dir( 'includes/shortcodes/bs-theme-subscribe-newsletter.php' );
		$shortcodes['bs-theme-subscribe-newsletter'] = array(
			'shortcode_class'   =>  'BS_Theme_Subscribe_Newsletter_Shortcode',
			'widget_class'      =>  'BS_Theme_Subscribe_Newsletter_Widget',
		);

		require bf_get_theme_dir( 'includes/shortcodes/bs-theme-flickr.php' );
		$shortcodes['bs-theme-flickr'] = array(
			'shortcode_class'   =>  'BS_Theme_Flickr_Shortcode',
			'widget_class'      =>  'BS_Theme_Flickr_Widget',
		);

		require bf_get_theme_dir( 'includes/shortcodes/bs-theme-likebox.php' );
		$shortcodes['bs-theme-likebox'] = array(
			'shortcode_class'   =>  'BS_Theme_Likebox_Shortcode',
			'widget_class'      =>  'BS_Theme_Likebox_Widget',
		);

		require bf_get_theme_dir( 'includes/shortcodes/bs-theme-dribbble.php' );
		$shortcodes['bs-theme-dribbble'] = array(
			'shortcode_class'   =>  'BS_Theme_Dribbble_Shortcode',
			'widget_class'      =>  'BS_Theme_Dribbble_Widget',
		);

		require bf_get_theme_dir( 'includes/shortcodes/bs-theme-google-plus.php' );
		$shortcodes['bs-theme-google-plus'] = array(
			'shortcode_class'   =>  'BS_Theme_Google_Plus_Shortcode',
			'widget_class'      =>  'BS_Theme_Google_Plus_Widget',
		);

		require bf_get_theme_dir( 'includes/shortcodes/bs-theme-embed.php' );
		$shortcodes['bs-theme-embed'] = array(
			'shortcode_class'   =>  'BS_Theme_Embed_Shortcode',
			'widget_class'      =>  'BS_Theme_Embed_Widget',
		);

		require bf_get_theme_dir( 'includes/shortcodes/bs-theme-instagram.php' );
		$shortcodes['bs-theme-instagram'] = array(
			'shortcode_class'   =>  'BS_Theme_Instagram_Shortcode',
			'widget_class'      =>  'BS_Theme_Instagram_Widget',
		);

		return $shortcodes;

	} // setup_shortcodes


	/**
	 * @param $config
	 *
	 * @return mixed
	 */
	function filter_translations_config( $config ){

		$config['dir-url']  = BS_THEME_URI . 'includes/libs/better-translation/';
		$config['dir-path'] = BS_THEME_PATH . 'includes/libs/better-translation/';
		$config['theme-id'] = 'patricia';
		$config['theme-name'] = 'Patricia';

		$config['translations'] = array(
			'en_US' => array(
				'name'  =>  __( 'English - US', 'better-studio' ),
				'url'   =>  BS_THEME_URI . 'includes/admin-assets/translations/en_US.json',
			),
			'fa_IR' => array(
				'name'  =>  __( 'Persian - Iran', 'better-studio' ),
				'url'   =>  BS_THEME_URI . 'includes/admin-assets/translations/fa_IR.json',
			),
		);

		return $config;
	} // filter_translations_config


	/**
	 * Callback: Activate BetterStudio Duplicate Posts
	 *
	 * @param $active_pages
	 *
	 * @return array
	 */
	function setup_no_duplicate_posts( $active_pages ){

		if( better_get_option( 'bm_remove_duplicate_posts_full' ) ){
			$active_pages[] = 'full';
		}else{

			if( better_get_option( 'bm_remove_duplicate_posts' ) ){
				$active_pages[] = 'home';
			}

			if( better_get_option( 'bm_remove_duplicate_posts_categories' ) ){
				$active_pages[] = 'categories';
			}

			if( better_get_option( 'bm_remove_duplicate_posts_tags' ) ){
				$active_pages[] = 'tags';
			}

		}

		return $active_pages;

	} // setup_no_duplicate_posts

} // Patricia_Setup