<?php
/**
 * patricia.php
 *---------------------------
 * The Inscribe class that handles main functionality of theme.
 *
 */


/**
 * Patricia Theme Class
 */
class Patricia {

	/**
	 * Inner array of objects live instances like generator
	 *
	 * @var array
	 */
	protected static $instances = array();


	/**
	 *
	 */
	function __construct(){

		// Performs the Bf setup
		add_action( 'better-framework/after_setup', array( $this, 'theme_init' )  );

		// Clears BF caches
		add_action( 'after_switch_theme', array( $this, 'after_theme_switch' ) );
		add_action( 'switch_theme', array( $this, 'after_theme_switch' ) );

	} // __construct


	/**
	 * clears last BF caches for avoiding conflict
	 */
	function after_theme_switch(){

		// Clears BF transients for preventing of happening any problem
		delete_transient( '__better_framework__widgets_css' );
		delete_transient( '__better_framework__panel_css' );
		delete_transient( '__better_framework__menu_css' );
		delete_transient( '__better_framework__terms_css' );
		delete_transient( '__better_framework__final_fe_css' );
		delete_transient( '__better_framework__final_fe_css_version' );
		delete_transient( '__better_framework__backend_css' );

		// Delete all pages css transients
		global $wpdb;
		$wpdb->query( $wpdb->prepare( "DELETE FROM $wpdb->postmeta WHERE meta_key LIKE %s", '_bf_post_css_%' ) );

	} // after_theme_switch


	/**
	 * Used for extending gallery slider
	 *
	 * @return Better_Gallery_Slider
	 */
	public static function gallery_slider(){

		if( isset( self::$instances['gallery-slider'] ) ) {
			return self::$instances['gallery-slider'];
		}

		include bf_get_theme_dir( 'includes/libs/class-better-gallery-slider.php' );

		$generator = 'Better_Gallery_Slider';

		self::$instances['gallery-slider'] = new $generator;
		return self::$instances['gallery-slider'];

	} // gallery_slider


	/**
	 * Initialize theme
	 */
	function theme_init(){

		// Fire ups gallery slider
		$this->gallery_slider();

		// Setup plugins before WP and BF init
		$this->setup_plugins();

		/*
		 * Enqueue assets (css, js)
		 */
		add_action( 'wp_enqueue_scripts', array( $this, 'register_assets' ) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list', 'gallery', 'caption' ) );

		/*
		 * Featured images settings
		 */
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size( 90, 60, array( 'center', 'center' ));                                // Image Thumbnail Size
		add_image_size( 'patricia-slider-1',         750,    490,     array( 'center', 'center' ) );  // Main Post Image In Full Width
		add_image_size( 'patricia-modern',           260,    210,     array( 'center', 'center' ) );  // Main Post Image In Full Width
		add_image_size( 'patricia-grid',             500,    440,     array( 'center', 'center' ) );  // Main Post Image In Full Width
		add_image_size( 'patricia-menu-post',        280,    250,     array( 'center', 'center' ) );  // Main Post Image In Full Width
		add_image_size( 'patricia-blog-free',        880,    0,       array( 'center', 'center' ) );  // Post Image In Normal ( With Sidebar )

		/*
		 * Post formats ( All )
		 */
		add_theme_support( 'post-formats', array( 'video', 'gallery', 'audio', 'aside', 'image', 'quote', 'status', 'chat', 'link' ) );

		/*
		 * This feature enables post and comment RSS feed links to head.
		 */
		add_theme_support( 'automatic-feed-links' );

		/*
		 * i18n
		 */
		load_theme_textdomain( 'better-studio', bf_get_theme_dir( 'languages' ) );

		/*
		 * Register menus
		 */
		register_nav_menu( 'main-menu',     __( 'Main Navigation', 'better-studio'      )   );
		register_nav_menu( 'resp-menu',     __( 'Responsive Navigation', 'better-studio')   );

		// In 3.5 content_width removed, add it for oebmed
		global $content_width;

		if( ! isset( $content_width ) )
			$content_width = 1170;

		// Implements editor styling
		add_editor_style();

		// Add filters to generating custom menus
		add_filter( 'better-framework/menu/mega/end_lvl', array( $this, 'generate_better_menu' ) );

		// enqueue in header
		add_action( 'wp_head', array( $this, 'wp_head' ));

		// enqueue in footer
		add_action( 'wp_footer', array( $this, 'wp_footer' ));

		// add custom classes to body
		add_filter( 'body_class' , array( $this, 'filter_body_class' ) );

		// Enqueue admin scripts
		add_action( 'admin_enqueue_scripts', array( $this , 'admin_enqueue' ) );

		// Used for adding order by rand to WP_User_Query
		add_action( 'pre_user_query', array( $this , 'action_pre_user_query' ) );

		/*
		 * Register Sidebars
		 */
		register_sidebar( array(
			'name'          =>  __( 'Primary', 'better-studio' ),
			'id'            =>  'primary-sidebar',
			'description'   =>  __( 'Widgets in this area will be shown in the default sidebar.', 'better-studio' ),
			'before_title'  =>  '<h4 class="widget-heading"><span class="h-text">',
			'after_title'   =>  '</span></h4>',
			'before_widget' =>  '<div id="%1$s" class="primary-sidebar-widget widget %2$s">',
			'after_widget'  =>  '</div>'
		) );
		register_sidebar( array(
			'name'          =>  __( 'Aside Logo', 'better-studio' ),
			'id'            =>  'aside-logo',
			'description'   =>  __( ' Widgets in this area will shown in logo aside. Please place only one line widgets.', 'better-studio'),
			'before_title'  =>  '',
			'after_title'   =>  '',
			'before_widget' =>  '<div  id="%1$s" class="aside-brand-widget widget %2$s">',
			'after_widget'  =>  '</div>'
		) );

		// Footer Larger Sidebars
		register_sidebar( array(
			'name'          =>  __( 'Footer - Column 1', 'better-studio'),
			'id'            =>  'footer-1',
			'description'   =>   __( 'Widgets in this area will be shown in the footer column 1.', 'better-studio' ),
			'before_title'  =>  '<h4 class="widget-heading"><span class="h-text">',
			'after_title'   =>  '</span></h4>',
			'before_widget' =>  '<div id="%1$s" class="footer-widget footer-column-1 widget %2$s">',
			'after_widget'  =>  '</div>'
		));
		register_sidebar( array(
			'name'          =>  __( 'Footer - Column 2', 'better-studio'),
			'id'            =>  'footer-2',
			'description'   =>   __( 'Widgets in this area will be shown in the footer column 2.', 'better-studio' ),
			'before_title'  =>  '<h4 class="widget-heading"><span class="h-text">',
			'after_title'   =>  '</span></h4>',
			'before_widget' =>  '<div id="%1$s" class="footer-widget footer-column-2 widget %2$s">',
			'after_widget'  =>  '</div>'
		));
		register_sidebar( array(
			'name'          =>  __( 'Footer - Column 3', 'better-studio'),
			'id'            =>  'footer-3',
			'description'   =>   __( 'Widgets in this area will be shown in the footer column 3.', 'better-studio' ),
			'before_title'  =>  '<h4 class="widget-heading"><span class="h-text">',
			'after_title'   =>  '</span></h4>',
			'before_widget' =>  '<div id="%1$s" class="footer-widget footer-column-3 widget %2$s">',
			'after_widget'  =>  '</div>'
		));

		// Add social sites meta tags
		$this->social_meta_tags();

		// Setup theme update
		if( is_admin() && better_get_option( 'themeforest_user_name' ) && better_get_option( 'themeforest_api_key' ) ){

			include bf_get_theme_dir( 'includes/libs/better-theme-updater/init.php' );
			add_filter( 'better-theme-updater/update-data', array( $this, 'filter_theme_update_manager_data' ) );

		}

		// Theme options into admin bar
		add_action( 'admin_bar_menu', array( $this, 'admin_bar_menu' ), 1000);

		// Initialize Better Studio Rebuild Thumbnails
		if( is_admin() ){

			include bf_get_theme_dir( 'includes/libs/better-studio-rebuild-thumbnails/class-better-studio-rebuild-thumbnails.php' );
			new Better_Studio_Rebuild_Thumbnails( array(
				'dir-uri'   => bf_get_theme_uri( 'includes/libs/better-studio-rebuild-thumbnails/' )
			) );

			include bf_get_theme_dir( 'includes/demo-content-importer/class-patricia-content-importer.php' );
			new Patricia_Content_Importer( array() );

		}

		// Filter WP_Query
		add_action( 'pre_get_posts', array( $this, 'pre_get_posts' ) );

		// Compatibility with Better Facebook Comments
		add_filter( 'better-facebook-comments/js/global-vars', array( $this, 'better_facebook_comments_vars' ) );

	} // theme_init


	/**
	 * Action Callback: Used for adding theme options into admin bar
	 */
	function admin_bar_menu(){

		global $wp_admin_bar;

		if( ! is_super_admin() || ! is_admin_bar_showing() ){
			return;
		}

		// Theme Options
		$wp_admin_bar->add_menu( array(
			'id'            =>  'bs-theme-options',
			'parent'        =>  'site-name',
			'title'         =>  __( 'Theme Options', 'better-studio' ),
			'href'          =>  admin_url( 'admin.php?page=better-studio/patricia' ),
		) );

		// Theme Translation
		$wp_admin_bar->add_menu( array(
			'id'            =>  'bs-translate-theme',
			'parent'        =>  'site-name',
			'title'         =>  __( 'Translate Theme', 'better-studio' ),
			'href'          =>  admin_url( 'admin.php?page=better-studio/translations/patricia-translation' )
		) );

	} // admin_bar_menu


	/**
	 * Used for adding social site meta tags
	 *
	 * @param array $args
	 * @return  Better_Social_Meta_Tag_Generator
	 */
	public static function social_meta_tags( $args = array() ){

		if( isset( self::$instances['social-meta-tags'] ) ){
			return self::$instances['social-meta-tags'];
		}

		include_once bf_get_theme_dir( 'includes/libs/class-better-social-meta-tag-generator.php' );
		$better_social_tag_generator = new Better_Social_Meta_Tag_Generator( $args );

		self::$instances['social-meta-tags'] = $better_social_tag_generator;
		return self::$instances['social-meta-tags'];

	} // social_meta_tags


	/**
	 * Enqueue css and js files
	 *
	 * Action Callback: wp_enqueue_scripts
	 *
	 */
	function register_assets(){

		$theme_version = BF()->theme()->get( 'Version' );

		// jquery and bootstrap
		wp_enqueue_script( 'patricia-libs', bf_get_theme_uri( 'js/patricia-libs.min.js' ), array( 'jquery' ), $theme_version, true );

		// PrettyPhoto
		if( better_get_option( 'light_box_images' ) ){
		 	bf_enqueue_script( 'pretty-photo' );
			bf_enqueue_style( 'pretty-photo' );
		}

		// Theme libraries
		wp_enqueue_script( 'patricia', bf_get_theme_uri( 'js/patricia.js' ), array( 'jquery' ), $theme_version, true );

		// Theme libraries
		wp_enqueue_style( 'patricia-libs', bf_get_theme_uri( 'css/patricia-libs.css' ), array(), $theme_version );

		// Fontawesome
		bf_enqueue_style( 'fontawesome' );

		// If a child theme is active, add the parent theme's style.
		// this is good for performance and cache.
		if( is_child_theme() ){

			wp_enqueue_style( 'patricia', bf_get_theme_uri( 'style.css' ), array(), $theme_version );

			// adds child theme version to the end of url of child theme style file
			wp_enqueue_style( 'patricia-child', bf_get_child_theme_uri( 'style.css' ), array(), BF()->theme( false, true, false )->get('Version') );

		}
		// Core style
		else{
			wp_enqueue_style( 'patricia', bf_get_theme_uri( 'style.css' ), array(), $theme_version );
		}

		if( is_rtl() ){
			wp_enqueue_style( 'patricia-rtl', bf_get_theme_uri( 'rtl.css' ), array( 'patricia' ), $theme_version );
		}

		if( is_singular() && comments_open() && get_option( 'thread_comments' ) ){
			wp_enqueue_script( 'comment-reply' );
		}

	} // register_assets


	/**
	 * Setup and recommend plugins
	 */
	public function setup_plugins(){

		include bf_get_theme_dir( 'includes/libs/class-tgm-plugin-activation.php' );

		$plugins = array(
			array(
				'name'      =>  'BetterStudio Shortcodes',
				'slug'      =>  'betterstudio-shortcodes',
				'source'    =>   bf_get_theme_uri( 'includes/plugins/betterstudio-shortcodes.zip' ),
				'required'  =>  false,
				'version'   =>  '1.1'
			),
			array(
				'name'      =>  'Better Social Counter Widget',
				'slug'      =>  'better-social-counter',
				'source'    =>  bf_get_theme_uri( 'includes/plugins/better-social-counter.zip' ),
				'required'  =>  false,
				'version'   =>  '1.3.0'
			),
			array(
				'name'      =>  'Better Disqus Comments',
				'slug'      =>  'better-disqus-comments',
				'source'    =>  bf_get_theme_uri( 'includes/plugins/better-disqus-comments.zip' ),
				'required'  =>  false,
				'version'   =>  '1.0.0'
			),
			array(
				'name'      =>  'Better Facebook Comments',
				'slug'      =>  'better-facebook-comments',
				'source'    =>  bf_get_theme_uri( 'includes/plugins/better-facebook-comments.zip' ),
				'required'  =>  false,
				'version'   =>  '1.1'
			),
			array(
				'name'      =>  'Better Ads Manager',
				'slug'      =>  'better-adsmanager',
				'source'    =>  bf_get_theme_uri( 'includes/plugins/better-adsmanager.zip' ),
				'required'  =>  false,
				'version'   =>  '1.1.0'
			),

			// https://wordpress.org/plugins/custom-sidebars/changelog/
			array(
				'name'      =>  'Custom sidebars',
				'slug'      =>  'custom-sidebars',
				'required'  =>  false,
				'version'   =>  '2.1.0.2'
			),

			// https://wordpress.org/plugins/wp-retina-2x/changelog/
			array(
				'name'      =>  'WP Retina 2x',
				'slug'      =>  'wp-retina-2x',
				'required'  =>  false,
				'version'   =>  '3.5.4'
			),

			// https://wordpress.org/plugins/contact-form-7/changelog/
			array(
				'name'      =>  'Contact Form 7',
				'slug'      =>  'contact-form-7',
				'required'  =>  false,
				'version'   =>  '4.3'
			),

		);

		$config = array(
			'is_automatic' => true,
		);

		tgmpa( $plugins, $config );

	} // setup_plugins


	/**
	 *  Enqueue anything in header
	 */
	function wp_head(){

		// Add custom css
		$this->add_panel_custom_css();

		if ( ! function_exists( 'has_site_icon' ) || ! has_site_icon() ) {
			// Favicon
			$favicon_16_16 = better_get_option( 'favicon_16_16' );
			if ( $favicon_16_16 ) {
				?>
				<link rel="shortcut icon" href="<?php echo esc_url( $favicon_16_16 ); ?>"><?php
			}

			$favicon_57_57 = better_get_option( 'favicon_57_57' );
			if ( $favicon_57_57 ) {
				?>
				<link rel="apple-touch-icon" href="<?php echo esc_url( $favicon_57_57 ); ?>"><?php
			}

			$favicon_114_114 = better_get_option( 'favicon_114_114' );
			if ( $favicon_114_114 ) {
				?>
				<link rel="apple-touch-icon" sizes="114x114" href="<?php echo esc_url( $favicon_114_114 ); ?>"><?php
			}

			$favicon_72_72 = better_get_option( 'favicon_72_72' );
			if ( $favicon_72_72 ) {
				?>
				<link rel="apple-touch-icon" sizes="72x72" href="<?php echo esc_url( $favicon_72_72 ); ?>"><?php
			}

			$favicon_144_144 = better_get_option( 'favicon_144_144' );
			if ( $favicon_144_144 ) {
				?>
				<link rel="apple-touch-icon" sizes="144x144" href="<?php echo esc_url( $favicon_144_144 ); ?>"><?php
			}
		}

		// Header HTML Code
		better_echo_option( 'custom_header_code' );

	} // wp_head


	/**
	 * Used for adding theme panels custom css to page
	 */
	function add_panel_custom_css(){

		// Custom CSS Code
		$custom_css_code = better_get_option( 'custom_css_code' );
		if( $custom_css_code ){
			bf_add_css( $custom_css_code, true );
		}

		$custom_css_desktop_code = better_get_option( 'custom_css_desktop_code' );
		if( $custom_css_desktop_code )
			bf_add_css( '/* responsive monitor */ @media(min-width: 1200px){ ' . $custom_css_desktop_code . '}', true );

		$custom_css_tablet_landscape_code = better_get_option( 'custom_css_tablet_landscape_code' );
		if( $custom_css_tablet_landscape_code )
			bf_add_css( '/* responsive landscape tablet */ @media(min-width: 1019px) and (max-width: 1199px){ ' .$custom_css_tablet_landscape_code . '}', true );

		$custom_css_tablet_portrait_code = better_get_option( 'custom_css_tablet_portrait_code' );
		if( $custom_css_tablet_portrait_code )
			bf_add_css( '/* responsive portrait tablet */ @media(min-width: 768px) and (max-width: 1018px){' . $custom_css_tablet_portrait_code . '}', true );

		$custom_css_phones_code = better_get_option( 'custom_css_phones_code' );
		if( $custom_css_phones_code )
			bf_add_css( '/* responsive phone */ @media(max-width: 767px){ ' . $custom_css_phones_code . ' }', true );


		// Custom CSS For Singulars
		if( is_singular() ){

			$post_id = get_the_ID();

			$custom_css_code = bf_get_post_meta( 'custom_css_code', $post_id, '' );
			if( $custom_css_code )
				bf_add_css( $custom_css_code, true );

			$custom_css_desktop_code = bf_get_post_meta( 'custom_css_desktop_code', $post_id, '' );
			if( $custom_css_desktop_code )
				bf_add_css( '/* responsive monitor */ @media(min-width: 1200px){ ' . $custom_css_desktop_code . '}', true );

			$custom_css_tablet_landscape_code = bf_get_post_meta( 'custom_css_tablet_landscape_code', $post_id, '' );
			if( $custom_css_tablet_landscape_code )
				bf_add_css( '/* responsive landscape tablet */ @media(min-width: 1019px) and (max-width: 1199px){ ' .$custom_css_tablet_landscape_code . '}', true );

			$custom_css_tablet_portrait_code = bf_get_post_meta( 'custom_css_tablet_portrait_code', $post_id, '' );
			if( $custom_css_tablet_portrait_code )
				bf_add_css( '/* responsive portrait tablet */ @media(min-width: 768px) and (max-width: 1018px){' . $custom_css_tablet_portrait_code . '}', true );

			$custom_css_phones_code = bf_get_post_meta( 'custom_css_phones_code', $post_id, '' );
			if( $custom_css_phones_code )
				bf_add_css( '/* responsive phone */ @media(max-width: 767px){ ' . $custom_css_phones_code . ' }', true );

		}
		// Custom CSS for categories & Tags
		elseif( is_tag() || is_category() ){

			if( is_category() ){
				$term_id = get_query_var('cat');
			}else{
				$tag = get_term_by( 'slug', get_query_var('tag'), 'post_tag' );
				$term_id = $tag->term_id;
			}

			$custom_css_code = bf_get_term_meta( 'custom_css_code', $term_id, '' );
			if( $custom_css_code )
				bf_add_css( $custom_css_code, true );

			$custom_css_desktop_code = bf_get_term_meta( 'custom_css_desktop_code', $term_id, '' );
			if( $custom_css_desktop_code )
				bf_add_css( '/* responsive monitor */ @media(min-width: 1200px){ ' . $custom_css_desktop_code . '}', true );

			$custom_css_tablet_landscape_code = bf_get_term_meta( 'custom_css_tablet_landscape_code', $term_id, '' );
			if( $custom_css_tablet_landscape_code )
				bf_add_css( '/* responsive landscape tablet */ @media(min-width: 1019px) and (max-width: 1199px){ ' .$custom_css_tablet_landscape_code . '}', true );

			$custom_css_tablet_portrait_code = bf_get_term_meta( 'custom_css_tablet_portrait_code', $term_id, '' );
			if( $custom_css_tablet_portrait_code )
				bf_add_css( '/* responsive portrait tablet */ @media(min-width: 768px) and (max-width: 1018px){' . $custom_css_tablet_portrait_code . '}', true );

			$custom_css_phones_code = bf_get_term_meta( 'custom_css_phones_code', $term_id, '' );
			if( $custom_css_phones_code )
				bf_add_css( '/* responsive phone */ @media(max-width: 767px){ ' . $custom_css_phones_code . ' }', true );

		}
		// Custom CSS for Authors
		elseif( is_author() ){

			$current_user = bf_get_author_archive_user();

			$custom_css_code = bf_get_user_meta( 'custom_css_code', $current_user, '' );
			if( $custom_css_code )
				bf_add_css( $custom_css_code, true );

			$custom_css_desktop_code = bf_get_user_meta( 'custom_css_desktop_code', $current_user, '' );
			if( $custom_css_desktop_code )
				bf_add_css( '/* responsive monitor */ @media(min-width: 1200px){ ' . $custom_css_desktop_code . '}', true );

			$custom_css_tablet_landscape_code = bf_get_user_meta( 'custom_css_tablet_landscape_code', $current_user, '' );
			if( $custom_css_tablet_landscape_code )
				bf_add_css( '/* responsive landscape tablet */ @media(min-width: 1019px) and (max-width: 1199px){ ' .$custom_css_tablet_landscape_code . '}', true );

			$custom_css_tablet_portrait_code = bf_get_user_meta( 'custom_css_tablet_portrait_code', $current_user, '' );
			if( $custom_css_tablet_portrait_code )
				bf_add_css( '/* responsive portrait tablet */ @media(min-width: 768px) and (max-width: 1018px){' . $custom_css_tablet_portrait_code . '}', true );

			$custom_css_phones_code = bf_get_user_meta( 'custom_css_phones_code', $current_user, '' );
			if( $custom_css_phones_code )
				bf_add_css( '/* responsive phone */ @media(max-width: 767px){ ' . $custom_css_phones_code . ' }', true );

		}
	} // add_panel_custom_css


	/**
	 * Callback: Enqueue anything in footer
	 *
	 * Action: wp_footer
	 */
	function wp_footer(){

		// Footer HTML Code
		better_echo_option( 'custom_footer_code' );

	} // wp_footer


	/**
	 *  Enqueue admin scripts
	 */
	function admin_enqueue(){

		wp_enqueue_style( 'patricia-admin', bf_get_theme_uri( 'css/admin-style.css' ), array(), Better_Framework::theme()->get( 'Version' ) );

	} // admin_enqueue


	/**
	 * Callback: Customize body classes
	 *
	 * Filter: body_class
	 *
	 * @param $classes
	 * @return array
	 */
	function filter_body_class( $classes ){

		// Activates light box
		if( better_get_option( 'light_box_images' ) == 'enable' ){
			$classes[] = 'active-light-box';
		}

		// Hide homepage content
		if( is_home() && better_get_option( 'home_hide_posts' ) == 'yes' ){
			$classes[] = 'hide-content-home';
		}

		// Activate Sticky Menu
		if( better_get_option( 'menu_sticky' ) != 'no-sticky' ){
			$classes[] = 'main-menu-sticky' . ( better_get_option( 'menu_sticky' ) == 'smart' ? '-smart' : '' );
		}

		// General Custom Body Class
		$classes[] = better_get_option( 'custom_css_class_general' );

		if( is_singular() ){

			// Pages Custom Body Class
			if( is_page() ){
				$classes[] = better_get_option( 'custom_css_class_page' );
				$classes[] = bf_get_post_meta( 'custom_css_class', get_the_ID(), '' );
			}
			// Posts Custom Body Class
			elseif( is_singular( 'post' ) ){
				$classes[] = better_get_option( 'custom_css_class_post' );
				$classes[] = bf_get_post_meta( 'custom_css_class', get_the_ID(), '' );
			}

		}

		// Categories layout style
		elseif( is_category() ){
			$classes[] = better_get_option( 'custom_css_class_category' );
			$classes[] = bf_get_term_meta( 'custom_css_class', NULL, '' );
		}

		// Tags layout style
		elseif( is_tag() ){
			$classes[] = better_get_option( 'custom_css_class_tag' );
			$classes[] = bf_get_term_meta( 'custom_css_class', NULL, '' );
		}

		// Author layout style
		elseif( is_author() ){
			$classes[] = better_get_option( 'custom_css_class_author' );
			$classes[] = bf_get_user_meta('custom_css_class', NULL, '' );
		}

		return $classes;
	} // filter_body_class


	/**
	 * Generate Custom Mega Menu HTML
	 *
	 * @param array $args
	 * @return string
	 */
	public function generate_better_menu( $args ){

		// Extract arguments that passed from walker
		extract($args);

		switch( $item->mega_menu ){

			case 'link-3-column':
			case 'link-2-column':
			case 'link-4-column':

				better_set_prop( 'mega-menu-sub-menu', $sub_menu );
				better_set_prop( 'mega-menu-columns', $item->mega_menu );

				return better_get_view( 'menu', 'mega-links-columns', 'general', false );

				break;

			case 'link-list':

				better_set_prop( 'mega-menu-sub-menu', $sub_menu );
				better_set_prop( 'mega-menu-columns', $item->mega_menu );

				return better_get_view( 'menu', 'mega-links-list', 'general', false );

				break;

			case 'grid-posts':

				better_set_prop( 'mega-menu-item', $item );
				return better_get_view( 'menu', 'mega-grid-posts', 'general', false );

				break;

		}

		return $sub_menu;

	} // generate_better_menu


	/**
	 * Adds random order by feature to WP_User_Query
	 *
	 * Action: pre_user_query
	 *
	 * @param $class
	 * @return mixed
	 */
	public function action_pre_user_query( $class ){

		if( 'rand' == $class->query_vars['orderby'] )
			$class->query_orderby = str_replace( 'user_login', 'RAND()', $class->query_orderby );

		return $class;

	} // action_pre_user_query


	/**
	 * Resets typography options to default
	 *
	 * Callback
	 *
	 * @return array
	 */
	public static function reset_typography_options(){

		$lang = bf_get_current_language_option_code();

		$theme_options = get_option( better_theme_panel_id() . $lang );

		$fields = BF()->options()->options[better_theme_panel_id()]['fields'];

		// general
		$theme_options['typo_body'] = $fields['typo_body']['std'] ;
		$theme_options['typo_heading'] = $fields['typo_heading']['std'] ;
		$theme_options['typo_meta'] = $fields['typo_meta']['std'] ;
		$theme_options['typo_badges'] = $fields['typo_badges']['std'] ;

		// post & pages
		$theme_options['typo_post_heading'] = $fields['typo_post_heading']['std'] ;
		$theme_options['typo_page_heading'] = $fields['typo_page_heading']['std'] ;
		$theme_options['typo_entry_content'] = $fields['typo_entry_content']['std'] ;
		$theme_options['typo_post_summary'] = $fields['typo_post_summary']['std'] ;
		$theme_options['post_author'] = $fields['post_author']['std'] ;

		// Header
		$theme_options['typ_header_menu'] = $fields['typ_header_menu']['std'] ;
		$theme_options['typ_header_sub_menu'] = $fields['typ_header_sub_menu']['std'] ;

		// Archive Title
		$theme_options['typo_archive_title_pre'] = $fields['typo_archive_title_pre']['std'] ;
		$theme_options['typo_archive_title'] = $fields['typo_archive_title']['std'] ;

		// Blog Listing
		$theme_options['typo_listing_blog_title'] = $fields['typo_listing_blog_title']['std'] ;

		// Grid Listing
		$theme_options['typo_listing_grid_title'] = $fields['typo_listing_grid_title']['std'] ;

		// Modern Listing
		$theme_options['typo_listing_modern_title'] = $fields['typo_listing_modern_title']['std'] ;

		// Widgets
		$theme_options['typo_widget_title'] = $fields['typo_widget_title']['std'] ;

		// Updates option
		update_option( better_theme_panel_id() . $lang, $theme_options );

		// clear caches
		delete_transient( '__better_framework__panel_css' );
		delete_transient( '__better_framework__final_fe_css' );
		delete_transient( '__better_framework__final_fe_css_version' );

		BF()->admin_notices()->add_notice( array(
			'msg' => __( 'Typography options resets to default.', 'better-studio' )
		) );

		return array(
			'status'  => 'succeed',
			'msg'	  => __( 'Typography resets to default.', 'better-studio' ),
			'refresh' => true
		);

	} // reset_typography_options


	/**
	 * Resets color options to default
	 *
	 * Callback
	 *
	 * @return array
	 */
	public static function reset_color_options(){

		$lang = bf_get_current_language_option_code();

		$theme_options = get_option( better_theme_panel_id() . $lang );

		$fields = BF()->options()->options[better_theme_panel_id()]['fields'];

		// General
		$theme_options['theme_color'] = $fields['theme_color']['std'] ;
		$theme_options['site_bg_color'] = $fields['site_bg_color']['std'] ;
		$theme_options['site_bg_image'] = $fields['site_bg_image']['std'] ;

		// Header
		$theme_options['header_color_scheme'] = $fields['header_color_scheme']['std'] ;
		$theme_options['resp_scheme'] = $fields['resp_scheme']['std'] ;
		$theme_options['header_bg_color'] = $fields['header_bg_color']['std'] ;
		$theme_options['header_bg_image'] = $fields['header_bg_image']['std'] ;

		// Footers
		$theme_options['footer_scheme'] = $fields['footer_scheme']['std'] ;
		$theme_options['footer_bg_color'] = $fields['footer_bg_color']['std'] ;
		$theme_options['footer_bg_image'] = $fields['footer_bg_image']['std'] ;

		// Updates option
		update_option( better_theme_panel_id() . $lang, $theme_options );

		// clear caches
		delete_transient( '__better_framework__panel_css' );
		delete_transient( '__better_framework__final_fe_css' );
		delete_transient( '__better_framework__final_fe_css_version' );

		BF()->admin_notices()->add_notice( array(
			'msg' => __( 'All color options resets to default.', 'better-studio' )
		) );

		return array(
			'status'  => 'succeed',
			'msg'	  => __( 'Color options resets to default.', 'better-studio' ),
			'refresh' => true
		);

	} // reset_color_options


	/**
	 * Filter Callback: adds theme update data to Better Studio Theme Updater
	 *
	 * @param $data
	 * @return array
	 */
	public function filter_theme_update_manager_data( $data ){

		return array(
			'theme_name'    =>  'Patricia',
			'theme_slug'    =>  'patricia',
			'theme_id'      =>  '13226491',
			'user_name'     =>  better_get_option( 'themeforest_user_name' ),
			'api_key'       =>  better_get_option( 'themeforest_api_key' ),
		);

	} // filter_theme_update_manager_data


	/**
	 * Callback: Used for changing WP_Query, specifically for posts per page in archives
	 *
	 * @param   WP_Query    $query      WP_Query instance
	 */
	function pre_get_posts( $query ) {

		// This is only for front end and main query
		if( ! is_admin() && $query->is_main_query() ){

			// Homepage customize query
			if( $query->is_home() ){

				// Home posts count
				if( better_get_option( 'home_posts_count' ) != '' ){
					$query->set( 'posts_per_page', better_get_option( 'home_posts_count' ) );
					$query->set( 'paged', bf_get_query_var_paged() );
				}

				// Home category filters
				if( better_get_option( 'home_cat_include' ) != '' ){
					$query->set( 'cat', better_get_option( 'home_cat_include' ) );
				}

				// Home exclude category filters
				if( better_get_option( 'home_cat_exclude' ) != '' ){
					$query->set( 'category__not_in', better_get_option( 'home_cat_exclude' ) );
				}

				// Home tag filters
				if( better_get_option( 'home_tag_include' ) != '' ){
					$query->set( 'tag__in', better_get_option( 'home_tag_include' ) );
				}

			}

			// Posts per page for categories
			elseif( $query->is_category() ){

				$term = get_category( $query->get_queried_object_id() );

				// Custom count per category
				if( bf_get_term_meta( 'term_posts_count', $term, '' ) != '' ){

					$query->set( 'posts_per_page', bf_get_term_meta( 'term_posts_count', $term, '' ) );
					$query->set( 'paged', bf_get_query_var_paged() );

				}
				// Custom count for all categories
				elseif( better_get_option( 'cat_posts_count' ) != '' && intval( better_get_option( 'cat_posts_count' ) ) > 0 ){

					$query->set( 'posts_per_page', better_get_option( 'cat_posts_count' ) );
					$query->set( 'paged', bf_get_query_var_paged() );

				}


			}
			// Posts per page for tags
			elseif( $query->is_tag() ){

				$term = get_term( $query->get_queried_object_id(), 'post_tag' );

				// Custom count per tag
				if( bf_get_term_meta( 'term_posts_count', $term, '' ) != '' ){

					$query->set( 'posts_per_page', bf_get_term_meta( 'term_posts_count', $term, '' ) );
					$query->set( 'paged', bf_get_query_var_paged() );

				}
				// Custom count for all tags
				elseif( better_get_option( 'tag_posts_count' ) != '' && intval( better_get_option( 'tag_posts_count' ) ) > 0 ){

					$query->set( 'posts_per_page', better_get_option( 'tag_posts_count' ) );
					$query->set( 'paged', bf_get_query_var_paged() );

				}

			}
			// Posts per page for authors
			elseif( $query->is_author() ){

				$current_user = $query->query_vars['author_name'];
				$current_user = get_user_by( 'slug', $current_user );

				// Custom count per author
				if( bf_get_user_meta( 'author_posts_count', $current_user, '' ) != '' && intval( bf_get_user_meta( 'author_posts_count', $current_user, '' ) ) > 0 ){

					$query->set( 'posts_per_page', bf_get_user_meta( 'author_posts_count', $current_user, '' ) );
					$query->set( 'paged', bf_get_query_var_paged() );

				}
				// Custom count for all tags
				elseif( better_get_option( 'author_posts_count' ) != '' && intval( better_get_option( 'author_posts_count' ) ) > 0 ){

					$query->set( 'posts_per_page', better_get_option( 'author_posts_count' ) );
					$query->set( 'paged', bf_get_query_var_paged() );

				}

			}
			// Posts per page for search
			elseif( $query->is_search() ){

				if( better_get_option( 'search_posts_count' ) != '' && intval( better_get_option( 'search_posts_count' ) ) > 0 ){

					$query->set( 'posts_per_page', better_get_option( 'search_posts_count' ) );
					$query->set( 'paged', bf_get_query_var_paged() );

				}

				// Customize search result content
				switch( better_get_option( 'search_result_content' ) ){

					case 'post':
						$query->set( 'post_type', 'post' );
						break;

					case 'page':
						$query->set( 'post_type', 'page' );
						break;

					case 'post-page':
						$query->set( 'post_type', array( 'post', 'page' ) );
						break;

				}// switch

			}// is_search

		}// if
	} // pre_get_posts


	/**
	 * Callback: Change Better Facebook Comments text
	 *
	 * Filter: better-facebook-comments/js/global-vars
	 *
	 * @param $vars
	 * @return mixed
	 */
	function better_facebook_comments_vars( $vars ){

		// todo check this
		$vars['text_0'] = Better_Translation()->_get( 'no_comment' );
		$vars['text_1'] = Better_Translation()->_get( 'one_comment' );
		$vars['text_2'] = sprintf( Better_Translation()->_get( 'more_comment' ), '%%NUMBER%%' );
		$vars['text_more'] = sprintf( Better_Translation()->_get( 'more_comment' ), '%%NUMBER%%' );

		return $vars;

	} // better_facebook_comments_vars

} // Patricia