<?php
/**
 * bs-theme-dribbble.php
 *---------------------------
 * [bs-theme-dribbble] short code & widget
 *
 */


/**
 * BetterStudio Dribbble Shortcode
 */
class BS_Theme_Dribbble_Shortcode extends BF_Shortcode{

	function __construct( $id, $options ){

		$id = 'bs-theme-dribbble';

		$_options = array(
			'defaults'  => array(
				'title'             =>  Better_Translation()->_get( 'widget_dribbble_shots' ),
				'show_title'        =>  1,
				'user_id'           =>  '',
				'photo_count'       =>  6,
				'style'             =>  3,
			),
			'have_widget'   => true,
		);


		$_options = wp_parse_args( $_options, $options );

		parent::__construct( $id , $_options );

	}


	/**
	 * Filter custom css codes for shortcode widget!
	 *
	 * @param $fields
	 * @return array
	 */
	function register_custom_css( $fields ){
		return $fields;
	}


	/**
	 * Handle displaying of shortcode
	 *
	 * @param array $atts
	 * @param string $content
	 * @return string
	 */
	function display( array $atts  , $content = '' ){

		ob_start();

		better_set_prop( 'shortcode-dribbble-atts', $atts );

		better_get_view( 'shortcodes', 'dribbble' );

		better_clear_prop();

		return ob_get_clean();

	}
}


if( ! function_exists( 'bs_theme_shortcode_dribbble_get_data' ) ){

	/**
	 * Wrapper ro getting Dribbble data with cache mechanism
	 *
	 * @param $atts
	 * @return array|bool|mixed|void
	 */
	function bs_theme_shortcode_dribbble_get_data( $atts ){

		$data_store  = 'bs-drb-' . $atts['user_id'];
		$back_store  = 'bs-drb-bk-' . $atts['user_id'];

		if( ( $data = get_transient( $data_store ) ) === false ){

			$data = bs_theme_shortcode_dribbble_fetch_data( $atts );

			if( $data ){

				$cache_time = HOUR_IN_SECONDS * 6;

				// save a transient to expire in $cache_time and a permanent backup option ( fallback )
				set_transient( $data_store, $data, $cache_time );
				update_option( $back_store, $data );

			}
			// fallback to permanent backup store
			else {
				$data = get_option( $back_store );
			}
		}

		return $data;
	}
}


if( ! function_exists( 'bs_theme_shortcode_dribbble_fetch_data' ) ){
	/**
	 * Retrieve Dribbble fresh data
	 *
	 * @param $atts
	 * @return array|bool
	 */
	function bs_theme_shortcode_dribbble_fetch_data( $atts ){

		require_once bf_get_theme_dir( 'includes/libs/dribbble-api/Client.php' );

		$client = new Dribbble_API_Client();

		try{
			$shots = $client->getPlayerShots( $atts['user_id'] );
			$shots = $shots->shots;
		}
		catch( Exception $e ){
			$shots = array();
		}

		return $shots;
	}
}


/**
 * BetterStudio Themes Dribbble Widget
 */
class BS_Theme_Dribbble_Widget extends BF_Widget{

	/**
	 * Register widget with WordPress.
	 */
	function __construct(){

		// Back end form fields
		$this->fields = array(
			array(
				'name'          =>  __( 'Title', 'better-studio' ),
				'attr_id'       =>  'title',
				'type'          =>  'text',
			),
			array(
				'name'          =>  __( 'Dribbble ID', 'better-studio' ),
				'attr_id'       =>  'user_id',
				'type'          =>  'text',
			),
			array(
				'name'          =>  __( 'Number of Shots', 'better-studio' ),
				'attr_id'       =>  'photo_count',
				'type'          =>  'text',
			),
			array(
				'name'          =>  __( 'Columns', 'better-studio' ),
				'attr_id'       =>  'style',
				'type'          =>  'select',
				'options'       =>  array(
					2       =>  __( '2 Column', 'better-studio' ),
					3       =>  __( '3 Column', 'better-studio' ),
					'slider'=>  __( 'Slider', 'better-studio' ),
				),
			),
		);

		parent::__construct(
			'bs-theme-dribbble',
			__( 'BetterStudio - Dribbble', 'better-studio' ),
			array(
				'description'   =>  __( 'Display latest shots from Dribbble.', 'better-studio' )
			)
		);
	}
}