<?php
/**
 * bs-theme-flickr.php
 *---------------------------
 * [bs-theme-flickr] short code & widget
 *
 */

/**
 * BS Theme Flickr Shortcode
 */
class BS_Theme_Flickr_Shortcode extends BF_Shortcode{

	function __construct( $id, $options ){

		$id = 'bs-theme-flickr';

		$_options = array(
			'defaults'          => array(
				'title'             =>  Better_Translation()->_get( 'widget_flickr_photos' ),
				'show_title'        =>  1,
				'user_id'           =>  '',
				'photo_count'       =>  6,
				'style'             =>  3,
				'tags'              =>  '',
			),
			'have_widget'       => true,
		);

		$_options = wp_parse_args( $_options, $options );

		parent::__construct( $id , $_options );

	}


	/**
	 * Filter custom css codes for shortcode widget!
	 *
	 * @param $fields
	 * @return array
	 */
	function register_custom_css( $fields ){
		return $fields;
	}


	/**
	 * Handle displaying of shortcode
	 *
	 * @param array $atts
	 * @param string $content
	 * @return string
	 */
	function display( array $atts  , $content = '' ){

		ob_start();

		better_set_prop( 'shortcode-flickr-atts', $atts );

		better_get_view( 'shortcodes', 'flickr' );

		better_clear_prop();

		return ob_get_clean();

	}

} // BS_Theme_Flickr_Shortcode


if( ! function_exists( 'bs_shortcode_flickr_get_data' ) ){
	/**
	 * Wrapper ro getting Flickr data with cache mechanism
	 *
	 * @param $atts
	 * @return array|bool|mixed|void
	 */
	function bs_shortcode_flickr_get_data( $atts ){

		$data_store  = 'bs-fk-' . $atts['user_id'];
		$back_store  = 'bs-fk-bk-' . $atts['user_id'];
		$cache_time  =  HOUR_IN_SECONDS * 6;

		if( ( $images_list = get_transient( $data_store ) ) === false ){

			$images_list = bs_shortcode_flickr_fetch_data( $atts );

			if( is_wp_error( $images_list ) && is_user_logged_in() ){
				return $images_list;
			}elseif( ! is_wp_error( $images_list ) ){

				// Save a transient to expire in $cache_time and a permanent backup option ( fallback )
				set_transient( $data_store, $images_list, $cache_time );
				update_option( $back_store, $images_list );

			}
			// Fall to permanent backup store
			else {
				$images_list = get_option( $back_store );
			}
		}

		return $images_list;
	} // bs_shortcode_flickr_get_data
} // if


if( ! function_exists( 'bs_shortcode_flickr_fetch_data' ) ){
	/**
	 * Retrieve Flickr fresh data
	 *
	 * @param $atts
	 * @return array|bool
	 */
	function bs_shortcode_flickr_fetch_data( $atts ){

		$remote_response = wp_remote_get( 'http://api.flickr.com/services/feeds/photos_public.gne?format=json&id='. urlencode( $atts['user_id'] ) .'&nojsoncallback=1&tags=' . urlencode( $atts['tags'] ) );

		if( is_wp_error( $remote_response ) || 200 != wp_remote_retrieve_response_code( $remote_response ) ){
			return new WP_Error( 'invalid_response', __( 'Flickr did not return a 200.', 'betterstudio' ) );
		}

		// Fix Flickr JSON escape bug
		$remote_body = wp_remote_retrieve_body( $remote_response );
		$remote_body = str_replace( "\\'", "'", $remote_body );

		$json = json_decode( $remote_body, true );

		if( ! is_array( $json ) ){
			return new WP_Error( 'bad_array', __( 'Flickr has returned invalid data.', 'betterstudio' ) );
		}

		$images_list = $json['items'];

		// Replace medium with small square image
		foreach( $images_list as $key => $item ){
			$images_list[$key]['media']['xs']  = preg_replace('/_m\.(jp?g|png|gif)$/', '_s.\\1', $item['media']['m']);
			$images_list[$key]['media']['s']  = preg_replace('/_m\.(jp?g|png|gif)$/', '_q_d.\\1', $item['media']['m']);
		}

		return $images_list;
	} // bs_shortcode_flickr_fetch_data
} // if



/**
 * BS Theme Flickr Widget
 */
class BS_Theme_Flickr_Widget extends BF_Widget{

	/**
	 * Register widget with WordPress.
	 */
	function __construct(){

		// Back end form fields
		$this->fields = array(
			array(
				'name'          =>  __( 'Instructions', 'better-studio' ),
				'attr_id'       =>  'help',
				'type'          =>  'info',
				'std'           =>  __('<p>You need to get the user id from your Flickr account.</p>
                <ol>
                    <li>Attain your user id using <a href="http://goo.gl/pHx7LV" target="_blank">this tool</a></li>
                    <li>Copy the user id</li>
                    <li>Paste it in the "Flickr ID" input box below</li>
                </ol>
                ', 'better-studio' ),
				'state'         =>  'open',
				'info-type'     =>  'help',
			),
			array(
				'name'          =>  __( 'Title:', 'better-studio' ),
				'attr_id'       =>  'title',
				'type'          =>  'text',
			),
			array(
				'name'          =>  __( 'Flickr ID:', 'better-studio' ),
				'attr_id'       =>  'user_id',
				'type'          =>  'text',
			),
			array(
				'name'          =>  __( 'Columns', 'better-studio' ),
				'attr_id'       =>  'style',
				'type'          =>  'select',
				'options'       =>  array(
					2       =>  __( '2 Column', 'better-studio' ),
					3       =>  __( '3 Column', 'better-studio' ),
					'slider'=>  __( 'Slider', 'better-studio' ),
				),
			),
			array(
				'name'          =>  __( 'Number of Photos:', 'better-studio' ),
				'attr_id'       =>  'photo_count',
				'type'          =>  'text',
			),
			array(
				'name'          =>  __( 'Tags (comma separated, optional):', 'better-studio' ),
				'attr_id'       =>  'tags',
				'type'          =>  'text',
			),
		);

		parent::__construct(
			'bs-theme-flickr',
			__( 'BetterStudio - Flickr', 'better-studio' ),
			array(
				'description'   =>  __( 'Display latest photos from Flickr.', 'better-studio' )
			)
		);
	}
}