<?php
/**
 * bs-theme-instagram.php
 *---------------------------
 * [bs-theme-instagram] short code & widget
 *
 */

/**
 * BS Theme Instagram Shortcode
 */
class BS_Theme_Instagram_Shortcode extends BF_Shortcode{

	function __construct( $id, $options ){

		$id = 'bs-theme-instagram';

		$_options = array(
			'defaults'          => array(
				'title'             =>  Better_Translation()->_get( 'widget_instagram' ),
				'show_title'        =>  1,
				'user_id'           =>  '',
				'photo_count'       =>  6,
				'style'             =>  3,
			),
			'have_widget'       => true,
		);

		$_options = wp_parse_args( $_options, $options );

		parent::__construct( $id , $_options );

	}


	/**
	 * Filter custom css codes for shortcode widget!
	 *
	 * @param $fields
	 * @return array
	 */
	function register_custom_css( $fields ){
		return $fields;
	}


	/**
	 * Handle displaying of shortcode
	 *
	 * @param array $atts
	 * @param string $content
	 * @return string
	 */
	function display( array $atts  , $content = '' ){

		ob_start();

		better_set_prop( 'shortcode-instagram-atts', $atts );

		better_get_view( 'shortcodes', 'instagram' );

		better_clear_prop();

		return ob_get_clean();

	}

} // BS_Theme_Instagram_Shortcode


if( ! function_exists( 'bs_shortcode_instagram_get_data' ) ){
	/**
	 * Wrapper ro getting Instagram data with cache mechanism
	 *
	 * @param $atts
	 * @return array|bool|mixed|void
	 */
	function bs_shortcode_instagram_get_data( $atts ){

		$atts['user_id'] = sanitize_title_with_dashes( $atts['user_id'] );

		$data_store  = 'bs-insta-' . $atts['user_id'];
		$back_store  = 'bs-insta-bk-' . $atts['user_id'];
		$cache_time  =  HOUR_IN_SECONDS * 6;

		if( ( $images_list = get_transient( $data_store ) ) === false ){

			$images_list = bs_shortcode_instagram_fetch_data( $atts );

			if( is_wp_error( $images_list ) && is_user_logged_in() ){
				return $images_list;
			}
			elseif( ! is_wp_error( $images_list ) ){

				// Save a transient to expire in $cache_time and a permanent backup option ( fallback )
				set_transient( $data_store, $images_list, $cache_time );
				update_option( $back_store, $images_list );

			}
			// Fall to permanent backup store
			else {
				$images_list = get_option( $back_store );
			}
		}

		return $images_list;
	} // bs_shortcode_instagram_get_data
} // if


if( ! function_exists( 'bs_shortcode_instagram_fetch_data' ) ){
	/**
	 * Retrieve Instagram fresh data
	 *
	 * Based on https://gist.github.com/cosmocatalano/4544576
	 *
	 * @param $atts
	 *
	 * @return array|bool
	 */
	function bs_shortcode_instagram_fetch_data( $atts ){

		$remote_response = wp_remote_get( 'http://instagram.com/' . strtolower( trim( $atts['user_id'] ) ) );

		if( is_wp_error( $remote_response ) ){
			return new WP_Error( 'site_down', __( 'Unable to communicate with Instagram.', 'betterstudio' ) );
		}

		if( 200 != wp_remote_retrieve_response_code( $remote_response ) )
			return new WP_Error( 'invalid_response', __( 'Instagram did not return a 200.', 'betterstudio' ) );

		// Extract JSON From Response
		$response_shared_data = explode( 'window._sharedData = ', wp_remote_retrieve_body( $remote_response ) );
		$response_json = explode( ';</script>', $response_shared_data[1] );

		// Decode Response JSON TO Array
		$response_array = json_decode( $response_json[0], TRUE );

		if( ! $response_array )
			return new WP_Error( 'bad_json', __( 'Instagram has returned invalid data.', 'betterstudio' ) );

		// Old Style
		if( isset( $response_array['entry_data']['UserProfile'][0]['userMedia'] ) ){
			$images_list = $response_array['entry_data']['UserProfile'][0]['userMedia'];
			$type = 'old';
		}
		// New Style
		elseif( isset( $response_array['entry_data']['ProfilePage'][0]['user']['media']['nodes'] ) ){
			$images_list = $response_array['entry_data']['ProfilePage'][0]['user']['media']['nodes'];
			$type = 'new';
		}
		else{
			return new WP_Error( 'bad_json_2', __( 'Instagram has returned invalid data.', 'betterstudio' ) );
		}

		if( ! is_array( $images_list ) )
			return new WP_Error( 'bad_array', __( 'Instagram has returned invalid data.', 'betterstudio' ) );

		$result = array();

		switch ( $type ) {

			case 'old':
				foreach( $images_list as $image ) {

					if ( $image['user']['username'] == $atts['user_id'] ) {

						$image['link']						    = preg_replace( "/^http:/i", "", $image['link'] );
						$image['images']['thumbnail']		    = preg_replace( "/^http:/i", "", $image['images']['thumbnail'] );
						if( isset( $image['thumbnail_src'] ) ){
							$image['images']['thumbnail'] =  $image['thumbnail_src'];
						}

						$image['images']['standard_resolution'] = preg_replace( "/^http:/i", "", $image['images']['standard_resolution'] );
						$image['images']['low_resolution']	    = preg_replace( "/^http:/i", "", $image['images']['low_resolution'] );

						$result[] = array(
							'description'   => $image['caption']['text'],
							'link'		  	=> $image['link'],
							'time'		  	=> $image['created_time'],
							'comments'	  	=> $image['comments']['count'],
							'likes'		 	=> $image['likes']['count'],
							'thumbnail'	 	=> $image['images']['thumbnail'],
							'large'		 	=> $image['images']['standard_resolution'],
							'small'		 	=> $image['images']['low_resolution'],
							'type'		  	=> $image['type']
						);
					}
				}

				break;

			default:

				foreach( $images_list as $image ){

					$image['display_src'] = preg_replace( "/^http:/i", "", $image['display_src'] );

					if( $image['is_video']  == true ) {
						$type = 'video';
					} else {
						$type = 'image';
					}

					$result[] = array(
						'description'   =>  __( 'Instagram Image', 'betterstudio' ),
						'link'		  	=>  '//instagram.com/p/' . $image['code'],
						'time'		  	=>  $image['date'],
						'comments'	  	=>  $image['comments']['count'],
						'likes'		 	=>  $image['likes']['count'],
						'thumbnail'	 	=>  isset( $image['thumbnail_src'] ) ? $image['thumbnail_src'] : $image['display_src'],
						'type'		  	=>  $type
					);
				}
				break;
		}
		return $result;
	} // bs_shortcode_instagram_fetch_data
} // if



/**
 * BS Theme Instagram Widget
 */
class BS_Theme_Instagram_Widget extends BF_Widget{

	/**
	 * Register widget with WordPress.
	 */
	function __construct(){

		// Back end form fields
		$this->fields = array(
			array(
				'name'          =>  __( 'Title:', 'better-studio' ),
				'attr_id'       =>  'title',
				'type'          =>  'text',
			),
			array(
				'name'          =>  __( 'Instagram  Username:', 'better-studio' ),
				'attr_id'       =>  'user_id',
				'type'          =>  'text',
			),
			array(
				'name'          =>  __( 'Number of Photos:', 'better-studio' ),
				'attr_id'       =>  'photo_count',
				'type'          =>  'text',
			),
			array(
				'name'          =>  __( 'Columns', 'better-studio' ),
				'attr_id'       =>  'style',
				'type'          =>  'select',
				'options'       =>  array(
					2       =>  __( '2 Column', 'better-studio' ),
					3       =>  __( '3 Column', 'better-studio' ),
					'slider'=>  __( 'Slider', 'better-studio' ),
				),
			),
		);

		parent::__construct(
			'bs-theme-instagram',
			__( 'BetterStudio - Instagram', 'better-studio' ),
			array(
				'description'   =>  __( 'Display latest photos from Instagram.', 'better-studio' )
			)
		);
	} // __construct
} // BS_Theme_Instagram_Widget