<?php
/**
 * bs-theme-likebox.php
 *---------------------------
 * [bs-theme-likebox] short code & widget
 *
 */

/**
 * BS Theme Likebox Shortcode
 */
class BS_Theme_Likebox_Shortcode extends BF_Shortcode{


	/**
	 * Flag used to determine print Facebook SDK in footer
	 *
	 * @var bool
	 */
	public static $print_footer_sdk = false;


	function __construct( $id, $options ){

		$id = 'bs-theme-likebox';

		$_options = array(
			'defaults'          => array(
				'title'             =>  '',
				'show_title'        =>  0,
				'url'               =>  '',
				'show_faces'        =>  1,
				'show_posts'        =>  0,
			),
			'have_widget'   => true,
		);

		$_options = wp_parse_args( $_options, $options );

		parent::__construct( $id , $_options );

		// Hooked to print Facebook JS SDK
		add_action( 'wp_footer', array( $this, 'wp_footer' ) );

	}


	/**
	 * Callback: used to print Facebook SDK in footer
	 *
	 * Action filter: wp_footer
	 */
	public static function wp_footer(){

		// print footer if needed


		if( self::$print_footer_sdk ){

			?>
<div id="fb-root"></div>
<script>(function(d, s, id) {
		var js, fjs = d.getElementsByTagName(s)[0];
		if (d.getElementById(id)) return;
		js = d.createElement(s); js.id = id;
		js.src = "//connect.facebook.net/en_GB/sdk.js#xfbml=1&version=v2.4";
		fjs.parentNode.insertBefore(js, fjs);
	}(document, 'script', 'facebook-jssdk'));</script>
		<?php

		}

	}


	/**
	 * Filter custom css codes for shortcode widget!
	 *
	 * @param $fields
	 * @return array
	 */
	function register_custom_css( $fields ){
		return $fields;
	}


	/**
	 * Handle displaying of shortcode
	 *
	 * @param array $atts
	 * @param string $content
	 * @return string
	 */
	function display( array $atts  , $content = '' ){

		self::$print_footer_sdk = true;

		ob_start();

		better_set_prop( 'shortcode-likebox-atts', $atts );

		better_get_view( 'shortcodes', 'likebox' );

		better_clear_prop();

		return ob_get_clean();

	}
}



/**
 * BetterStudio Themes Likebox Widget
 */
class BS_Theme_Likebox_Widget extends BF_Widget{

	/**
	 * Register widget with WordPress.
	 */
	function __construct(){

		// Back end form fields
		$this->fields = array(
			array(
				'name'          =>  __( 'Title (Optional)', 'better-studio' ),
				'attr_id'       =>  'title',
				'type'          =>  'text',
			),
			array(
				'name'          =>  __( 'Facebook Page Link', 'better-studio' ),
				'attr_id'       =>  'url',
				'desc'          =>  __( 'EG. http://www.facebook.com/envato', 'betterstudio' ),
				'type'          =>  'text',
			),
			array(
				'name'          =>  __( 'Show Posts', 'better-studio' ),
				'attr_id'       =>  'show_posts',
				'id'            =>  'show_posts',
				'type'          =>  'switch',
				'on-label'      =>  __( 'Show', 'better-studio' ),
				'off-label'     =>  __( 'Hide', 'better-studio' ),
			),
			array(
				'name'          =>  __( 'Show Faces', 'better-studio' ),
				'attr_id'       =>  'show_faces',
				'id'            =>  'show_faces',
				'type'          =>  'switch',
				'on-label'      =>  __( 'Show', 'better-studio' ),
				'off-label'     =>  __( 'Hide', 'better-studio' ),
			),
		);

		parent::__construct(
			'bs-theme-likebox',
			__( 'BetterStudio - Like Box', 'better-studio' ),
			array(
				'description'   =>  __( 'Display a Facebook Like Box', 'better-studio' )
			)
		);
	}
}