<?php
/**
 * bs-theme-social-share.php
 *---------------------------
 * [bs-theme-social-share] short code & widget
 *
 */

/**
 * BetterFramework Social Share Shortcode
 */
class BS_Theme_Social_Share_Shortcode extends BF_Shortcode{

    function __construct( $id, $options ){

        $id =                 'bs-theme-social-share';

        $_options = array(
            'defaults'          =>  array(
                'title'                 =>  Better_Translation()->_get( 'widget_share' ),
                'show_title'            =>  1,
                'show-section-title'    =>  true,
                'style'                 =>  'button',
                'colored'               =>  true,
                'sites'                 =>  array(
                    'facebook'      =>  true,
                    'twitter'       =>  true,
                    'google_plus'   =>  true,
                    'pinterest'     =>  false,
                    'linkedin'      =>  false,
                    'tumblr'        =>  false,
                    'email'         =>  true,
                ),
            ),
            'have_widget'       =>  true,
            'have_vc_add_on'    =>  false,
        );

        $_options = wp_parse_args( $_options, $options );

        parent::__construct( $id , $_options );

    }


    /**
     * Filter custom css codes for shortcode widget!
     *
     * @param $fields
     * @return array
     */
    function register_custom_css( $fields ){
        return $fields;
    }


    /**
     * Handle displaying of shortcode
     *
     * @param array $atts
     * @param string $content
     * @return string
     */
    function display( array $atts  , $content = ''   ){

        ob_start();

        better_set_prop( 'shortcode-social-share-atts', $atts );

        better_get_view( 'shortcodes', 'social-share' );

        better_clear_prop();

        return ob_get_clean();

    }
} // BS_Theme_Social_Share_Shortcode

//class WPBakeryShortCode_bf_social_share extends BF_VC_Shortcode_Extender { }


if( ! function_exists( 'bs_shortcode_social_share_get_li' ) ){
    /**
     * Used for generating lis for social share list
     *
     * @param string $id
     * @param $show_title
     * @return string
     */
    function bs_shortcode_social_share_get_li( $id = '', $show_title = true ){

        if( empty($id) ) return '';

        switch( $id ){

            case 'facebook':
                $link  =    "javascript: window.open('http://www.facebook.com/sharer.php?u=" . esc_url( get_permalink( get_the_ID() ) ) ."','_blank', 'width=900, height=450');" ;
                $title =    __( 'Facebook', 'better-studio' );
                $icon  =    '<i class="fa fa-facebook"></i>';
                break;

            case 'twitter':
                $link  =    "javascript: window.open('http://twitter.com/home?status=" . esc_url( get_permalink( get_the_ID() ) ) ."','_blank', 'width=900, height=450');" ;
                $title =    __( 'Twitter', 'better-studio' );
                $icon  =    '<i class="fa fa-twitter"></i>';
                break;

            case 'google_plus':
                $link  =    "javascript: window.open('http://plus.google.com/share?url=" . esc_url( get_permalink( get_the_ID() ) ) ."','_blank', 'width=500, height=450');" ;
                $title =    __( 'Google+', 'better-studio' );
                $icon  =    '<i class="fa fa-google-plus"></i>';
                break;

            case 'pinterest':
                $_img_src = wp_get_attachment_image_src( get_post_thumbnail_id(), 'full');
                $link  =    "javascript: window.open('http://pinterest.com/pin/create/button/?url=" . esc_url( get_permalink( get_the_ID() ) ) . '&media=' . esc_url( $_img_src[0] ) . "&description=" . esc_attr( get_the_title() ) ."','_blank', 'width=900, height=450');" ;
                $title =    __( 'Pinterest', 'better-studio' );
                $icon  =    '<i class="fa fa-pinterest"></i>';
                break;

            case 'linkedin':
                $link  =    "javascript: window.open('http://www.linkedin.com/shareArticle?mini=true&url=" . esc_url( get_permalink( get_the_ID() ) ) . "&title=" . esc_attr( get_the_title() ) . "','_blank', 'width=500, height=450');" ;
                $title =    __( 'Linkedin', 'better-studio' );
                $icon  =    '<i class="fa fa-linkedin"></i>';
                break;

            case 'tumblr':
                $link  =    "javascript: window.open('http://www.tumblr.com/share/link?url=" . esc_url( get_permalink( get_the_ID() ) ) . "&name=" . esc_attr( get_the_title() ) . "','_blank', 'width=500, height=450');" ;
                $title =    __( 'Tumblr', 'better-studio' );
                $icon  =    '<i class="fa fa-tumblr"></i>';
                break;

            case 'email':
                $link  =    "mailto:?subject=" . get_the_title() . "&body=" . esc_url( get_permalink( get_the_ID() ) ) ;
                $title =    Better_Translation()->_get( 'widget_email' );
                $icon  =    '<i class="fa fa-envelope"></i>';
                break;


            default:
                return '';
        }

        $output = '<li class="social-item '.$id.'"><a href="' . $link . '" target="_blank">';
        $output .= $icon ;
        if( $show_title )
            $output .= '<span class="item-title">'. $title .'</span></a>';
        $output .= '</a></li>';

        return $output;

    }// bs_shortcode_social_share_get_li
}// if


/**
 * BetterStudio Theme Social Share Widget
 */
class BS_Theme_Social_Share_Widget extends BF_Widget{

    /**
     * Register widget with WordPress.
     */
    function __construct(){

        // haven't title in any location
        $this->with_title = true;

        // Back end form fields
        $this->fields = array(
            array(
                'name'          =>  __( 'Title', 'better-studio'),
                'attr_id'       =>  'title',
                'type'          =>  'text',
            ),

            array(
                'name'          =>  __( 'Buttons Style', 'better-studio'),
                'attr_id'       =>  'style',
                'type'          =>  'image_select',
                'section_class' =>  'style-floated-left',
                'value'         =>  'clean',
                'options'       =>  array(
                    'button' => array(
                        'label'     => __( 'Button Style' , 'better-studio' ),
                        'img'       => bf_get_theme_uri( 'includes/admin-assets/images/vc-social-share-button.png' )
                    ),
                    'button-no-text' => array(
                        'label'     => __( 'Icon Button Style' , 'better-studio' ),
                        'img'       => bf_get_theme_uri( 'includes/admin-assets/images/vc-social-share-button-no-text.png' )
                    ),
                    'outline-button' => array(
                        'label'     => __( 'Outline Style' , 'better-studio' ),
                        'img'       => bf_get_theme_uri( 'includes/admin-assets/images/vc-social-share-outline-button.png' )
                    ),
                    'outline-button-no-text' => array(
                        'label'     => __( 'Icon Outline Style' , 'better-studio' ),
                        'img'       => bf_get_theme_uri( 'includes/admin-assets/images/vc-social-share-outline-button-no-text.png' )
                    ),
                ),
            ),

            array(
                'name'          =>  __( 'Colored Style', 'better-studio' ),
                'attr_id'       =>  'colored',
                'type'          =>  'switch',
                'on-label'      =>  __( 'Yes', 'better-studio' ),
                'off-label'     =>  __( 'No', 'better-studio' ),
            ),

            array(
                'name'          =>  __( 'Active Sites', 'better-studio' ),
                'attr_id'       =>  'sites',
                'type'          =>  'sorter_checkbox',
                'options'       =>  array(
                    'facebook'      => array(
                        'label'     => '<i class="fa fa-facebook"></i> ' . __( 'Facebook', 'better-studio' ),
                        'css-class' => 'active-item'
                    ),
                    'twitter'  => array(
                        'label'     => '<i class="fa fa-twitter"></i> ' . __( 'Twitter', 'better-studio' ),
                        'css-class' => 'active-item'
                    ),
                    'google_plus'  => array(
                        'label'     => '<i class="fa fa-google-plus"></i> ' . __( 'Google+', 'better-studio' ),
                        'css-class' => 'active-item'
                    ),
                    'pinterest'  => array(
                        'label'     => '<i class="fa fa-pinterest"></i> ' . __( 'Pinterest', 'better-studio' ),
                        'css-class' => 'active-item'
                    ),
                    'linkedin'  => array(
                        'label'     => '<i class="fa fa-linkedin"></i> ' . __( 'Linkedin', 'better-studio' ),
                        'css-class' => 'active-item'
                    ),
                    'tumblr'  => array(
                        'label'     => '<i class="fa fa-tumblr"></i> ' . __( 'Tumblr', 'better-studio' ),
                        'css-class' => 'active-item'
                    ),
                    'email'  => array(
                        'label'     => '<i class="fa fa-envelope "></i> ' . __( 'Email', 'better-studio' ),
                        'css-class' => 'active-item'
                    ),
                ),
                'section_class' =>  'bs-theme-social-share-sorter',
            ),
        );

        parent::__construct(
            'bs-theme-social-share',
            __( 'BetterStudio - Social Share', 'better-studio' ),
            array( 'description' => __( 'Social Share Widget', 'better-studio' ) )
        );
    } // __construct

} // BS_Theme_Social_Share_Widget class