<?php
/**
 * _mobile-header.php
 *---------------------------
 * Responsive menu and header template
 *
 */

$site_name  = get_bloginfo( 'name' );                           // Site name
$logo       = better_get_option( 'resp_logo_image' );           // Site logo
$logo2x     = better_get_option( 'resp_logo_image_retina' );    // Site 2X logo

// Default logos as fallback for resp logos
if( $logo == '' ){
	$logo       = better_get_option( 'logo_image' );        // Site logo
	$logo2x     = better_get_option( 'logo_image_retina' ); // Site 2X logo

	// Custom logo for categories
	if( is_category() && bf_get_term_meta( 'logo_image' ) != '' ){
		$logo       = bf_get_term_meta( 'logo_image' );
		$logo2x     = bf_get_term_meta( 'logo_image_retina' );
	}
}

// prepare retina logo tags
if( $logo2x != '' ){
	$logo2x = ' data-at2x="' . $logo2x . '" ';
}

// Final menu code
$menu_code  = '';

// Final theme menu location id
$menu_id    = '';

// If specific menu was defined for responsive header
if( has_nav_menu( 'resp-menu' ) ){
	$menu_id = 'resp-menu';
}
// In header style 5 & 6 the html code should printed from back-end because there is no code in front-end
elseif( better_get_option( 'header_style' ) == 'style-5' || better_get_option( 'header_style' ) == 'style-6' ){
	if( has_nav_menu( 'main-menu' ) ){
		$menu_id = 'main-menu';
	}elseif( has_nav_menu( 'top-menu' ) ){
		$menu_id = 'top-menu';
	}
}
// If main menu is not defined but the top menu is, then get top menu as resp menu
else{
	if( ! has_nav_menu( 'main-menu' ) && has_nav_menu( 'top-menu' ) ){
		$menu_id = 'top-menu';
	}
}

// Create final menu code
if( $menu_id != '' ){

	$menu_args = array(
		'theme_location'    => $menu_id,
		'container'         => false,
		'items_wrap'        => '%3$s',
		'fallback_cb'       => 'BF_Menu_Walker',
		'echo'              => false,
	);

	$menu_code = '<ul id="resp-navigation" class="resp-menu menu clearfix">' . wp_nav_menu( $menu_args ) . '</ul>';
}

?>
<div class="responsive-header clearfix <?php echo esc_attr( better_get_option( 'resp_scheme' ) ); ?>">
	<div class="responsive-header-container clearfix">

		<div class="menu-container close">
			<span class="menu-handler">
				<span class="lines"></span>
			</span>

			<div class="menu-box clearfix"><?php echo $menu_code; ?></div>
		</div><!-- .menu-container -->

		<div class="logo-container">
			<a href="<?php echo esc_url( home_url( '/' ) ); ?>" <?php better_attr( 'site-url' ); ?>>
				<?php

				// Site logo
				if( ! empty( $logo ) ){ ?>
					<img src="<?php echo esc_url( $logo ); ?>" alt="<?php echo esc_attr( $site_name ); ?>" <?php better_attr( 'site-logo' ); echo $logo2x; ?> />
				<?php }

				// Site title as text logo
				else{
					echo $site_name;
				}

				?>
			</a>
		</div><!-- .logo-container -->

		<div class="search-container close">
			<span class="search-handler">
				<i class="fa fa-search"></i>
			</span>

			<div class="search-box clearfix">
				<?php better_get_view( 'wp', 'searchform' ); ?>
			</div>
		</div><!-- .search-container -->

	</div><!-- .responsive-header-container -->
</div><!-- .responsive-header -->